import { n as __esmMin, r as __exportAll } from "./rolldown-runtime-CE-6LUnI.js";
//#region ../../node_modules/.pnpm/prettier@3.9.6/node_modules/prettier/plugins/postcss.mjs
var postcss_exports = /* @__PURE__ */ __exportAll({
	default: () => Ml,
	languages: () => Fi,
	options: () => $i,
	parsers: () => cn,
	printers: () => gg
});
function zl(t) {
	return this[t < 0 ? this.length + t : t];
}
function mn(t, e, s) {
	if (!t.has(e)) {
		let r = s(e);
		t.set(e, r);
	}
	return t.get(e);
}
function Ql(t) {
	if (typeof t == "string") return Ke;
	if (Array.isArray(t)) return Xe;
	if (!t) return;
	let { type: e } = t;
	if (Nt.has(e)) return e;
}
function Xl(t) {
	let e = t === null ? "null" : typeof t;
	if (e !== "string" && e !== "object") return `Unexpected doc '${e}', 
Expected it to be 'string' or 'object'.`;
	if (ae(t)) throw new Error("doc is valid.");
	let s = Object.prototype.toString.call(t);
	if (s !== "[object Object]") return `Unexpected doc '${s}'.`;
	let r = Kl([...Nt].map((n) => `'${n}'`));
	return `Unexpected doc.type '${t.type}'.
Expected it to be ${r}.`;
}
function yn(t, e) {
	if (typeof t == "string") return e(t);
	let s = /* @__PURE__ */ new Map();
	return r(t);
	function r(i) {
		return mn(s, i, n);
	}
	function n(i) {
		switch (ae(i)) {
			case Xe: return e(i.map(r));
			case oe: return e({
				...i,
				parts: i.parts.map(r)
			});
			case ge: return e({
				...i,
				breakContents: r(i.breakContents),
				flatContents: r(i.flatContents)
			});
			case ie: {
				let { expandedStates: o, contents: u } = i;
				return o ? (o = o.map(r), u = o[0]) : u = r(u), e({
					...i,
					contents: u,
					expandedStates: o
				});
			}
			case Pe:
			case ne:
			case At:
			case Ct:
			case Re: return e({
				...i,
				contents: r(i.contents)
			});
			case Ke:
			case kt:
			case Ot:
			case Ie:
			case H:
			case Le: return e(i);
			default: throw new dn(i);
		}
	}
}
function Jl(t) {
	return t.type === H && !t.hard ? t.soft ? "" : " " : t.type === ge ? t.flatContents : t;
}
function gn(t) {
	return yn(t, Jl);
}
function wn(t, e = vn) {
	return yn(t, (s) => typeof s == "string" ? Y(e, s.split(`
`)) : s);
}
function R(t) {
	return F(t), {
		type: ne,
		contents: t
	};
}
function Zl(t, e) {
	return _n(t), F(e), {
		type: Pe,
		contents: e,
		n: t
	};
}
function ue(t) {
	return Zl(-1, t);
}
function qe(t) {
	return xn(t), {
		type: oe,
		parts: t
	};
}
function D(t, e = {}) {
	return F(t), we(e.expandedStates, !0), {
		type: ie,
		id: e.id,
		contents: t,
		break: !!e.shouldBreak,
		expandedStates: e.expandedStates
	};
}
function Pt(t, e = "", s = {}) {
	return F(t), e !== "" && F(e), {
		type: ge,
		breakContents: t,
		flatContents: e,
		groupId: s.groupId
	};
}
function Y(t, e) {
	F(t), we(e);
	let s = [];
	for (let r = 0; r < e.length; r++) r !== 0 && s.push(t), s.push(e[r]);
	return s;
}
function Rt(t) {
	return F(t), {
		type: Re,
		contents: t
	};
}
function tc(t) {
	return Array.isArray(t) && t.length > 0;
}
function Tn(t, e) {
	let { preferred: s, alternate: r } = e === !0 || e === "'" ? rc : sc, { length: n } = t, i = 0, o = 0;
	for (let u = 0; u < n; u++) {
		let a = t.charCodeAt(u);
		a === s.codePoint ? i++ : a === r.codePoint && o++;
	}
	return (i > o ? r : s).character;
}
function ic(t, e) {
	let s = e === "\"" ? "'" : "\"";
	return e + T(0, t, nc, (n, i, o) => i ? i === s ? s : n : o === e ? "\\" + o : o) + e;
}
function oc(t, e) {
	G(/^(?<quote>["']).*\k<quote>$/s.test(t));
	let s = t.slice(1, -1), r;
	return e.parser === "json" || e.parser === "jsonc" || e.parser === "json-stringify" || e.parser === "json5" && e.quoteProps === "preserve" && !e.singleQuote ? r = "\"" : e.__isInHtmlAttribute ? r = "'" : r = Tn(s, e.singleQuote), t.charAt(0) === r ? t : On(s, r);
}
function Cn() {}
function Ze(t) {
	if (Je !== null && typeof Je.property) {
		let e = Je;
		return Je = Ze.prototype = null, e;
	}
	return Je = Ze.prototype = t ?? Object.create(null), new Ze();
}
function es(t) {
	return Ze(t);
}
function uc(t, e = "type") {
	es(t);
	function s(r) {
		let n = r[e], i = t[n];
		if (!Array.isArray(i)) throw Object.assign(/* @__PURE__ */ new Error(`Missing visitor keys for '${n}'.`), { node: r });
		return i;
	}
	return s;
}
function cc(t, e) {
	let s = 0;
	for (let r = 0; r < t.line - 1; ++r) s = e.indexOf(`
`, s) + 1;
	return s + t.column;
}
function qt(t) {
	return (e, s, r) => {
		if (s === !1) return !1;
		let n = !!r?.backwards, { length: i } = e, o = s;
		for (; o >= 0 && o < i;) {
			let u = e.charAt(o);
			if (t instanceof RegExp) {
				if (!t.test(u)) return o;
			} else if (!t.includes(u)) return o;
			n ? o-- : o++;
		}
		return o === -1 || o === i ? o : !1;
	};
}
function qn(t, e) {
	let { value: s } = t;
	return s === "-" || s === "--" || s.charAt(0) !== "-" ? e : e - (s.charAt(1) === "-" ? 2 : 1);
}
function Dn(t, e) {
	if (typeof t.source?.start?.offset == "number") return t.source.start.offset;
	if (typeof t.sourceIndex == "number") return t.type === "value-word" ? qn(t, t.sourceIndex) : t.sourceIndex;
	if (t.source?.start) return ts(t.source.start, e);
	throw Object.assign(/* @__PURE__ */ new Error("Can not locate node."), { node: t });
}
function Mn(t, e) {
	if (t.type === "css-comment" && t.inline) return Mt(e, t.source.startOffset);
	if (t.type === "value-paren" && typeof t.sourceIndex == "number") return t.sourceIndex + (t.value === ")" ? t.value.length : 0);
	if (typeof t.source?.end?.offset == "number") return t.source.end.offset;
	if (t.source) {
		if (t.source.end) {
			let s = ts(t.source.end, e);
			return t.type === "value-word" ? qn(t, s) : s;
		}
		if (le(t.nodes)) return Mn($(0, t.nodes, -1), e);
		if (t.type === "css-atrule" && typeof t.name == "string") return Dn(t, e) + 1 + t.name.length + t.raws.afterName.length + t.raws.params.length;
	}
	return typeof t.sourceIndex == "number" && typeof t.value == "string" ? t.sourceIndex + t.value.length : null;
}
function Bn(t, e) {
	ss(t, e, 0, !1);
}
function ss(t, e, s, r) {
	if (r && typeof t.type == "string") t.source ?? (t.source = {}), t.source.startOffset = s, t.source.endOffset = s + e.length;
	else if (!(typeof t.source?.startOffset == "number" && typeof t.source?.endOffset == "number")) {
		if (t.source || typeof t.sourceIndex == "number") {
			t.source ?? (t.source = {});
			let n = s + e.length;
			t.source.startOffset = Math.min(Dn(t, e) + s, n);
			let i = Mn(t, e);
			t.source.endOffset = typeof i == "number" ? Math.min(i + s, n) : i;
		}
	}
	for (let n in t) {
		let i = t[n];
		if (n === "source" || !i || typeof i != "object") continue;
		let o = Array.isArray(i) ? i : [i];
		for (let u of o) {
			if (!u || typeof u != "object") continue;
			let a = fc(t, u, s);
			a ? ss(u, a.text, a.rootOffset, !0) : ss(u, e, s, !1), Wn(u, t);
		}
	}
	mc(t), dc(t);
}
function fc(t, e, s) {
	if (e.type === "value-root" || e.type === "value-unknown") return {
		rootOffset: Un(t),
		text: e.text || e.value || ""
	};
	if (e.type === "media-query-list" || t.params === e) return {
		rootOffset: Fn(t),
		text: t.raws?.params || e.value || ""
	};
	if (e.type?.startsWith("selector-")) {
		let r = pc(t, e);
		if (typeof r == "string") return {
			rootOffset: hc(t, e, r, s),
			text: r
		};
	}
}
function Un(t) {
	let e = t.source.startOffset;
	return typeof t.prop == "string" && (e += t.prop.length), t.type === "css-atrule" && typeof t.name == "string" && (e += 1 + t.name.length + t.raws.afterName.match(/^\s*:?\s*/)[0].length), t.type !== "css-atrule" && typeof t.raws?.between == "string" && (e += t.raws.between.length), e;
}
function Fn(t) {
	let e = t.source.startOffset;
	return t.type === "css-atrule" && typeof t.name == "string" && (e += 1 + t.name.length + t.raws.afterName.match(/^\s*:?\s*/)[0].length), e;
}
function pc(t, e) {
	if (typeof e.raws?.selector == "string") return e.raws.selector;
	if (t.selector === e) {
		if (t.mixin) return t.raws.identifier + t.name + t.raws.afterName + t.raws.params;
		if (typeof t.raws?.selector == "string") return t.raws.selector;
		if (t.customSelector && typeof t.raws?.params == "string") return t.raws.params.slice(t.customSelector.length).trim();
		if (typeof t.raws?.params == "string") return t.raws.params;
		if (t.type === "css-decl" && typeof t.raws?.value == "string") {
			let { value: s } = t.raws;
			return t.extend && s.startsWith("extend(") ? s.slice(7, -1) : s;
		}
	}
}
function hc(t, e, s, r) {
	return typeof e.sourceIndex == "number" && typeof e.raws?.selector == "string" ? r + e.sourceIndex : t.mixin ? t.source.startOffset : typeof t.raws?.selector == "string" ? t.source.startOffset + rs(t.raws.selector, s) : typeof t.raws?.params == "string" ? Fn(t) + rs(t.raws.params, s) : t.type === "css-decl" && typeof t.raws?.value == "string" ? Un(t) + rs(t.raws.value, s) : r;
}
function rs(t, e) {
	let s = t.indexOf(e);
	return s === -1 ? 0 : s;
}
function mc(t) {
	var u, a;
	if (typeof t.type != "string") return;
	let e = typeof t.source?.startOffset == "number" && typeof t.source?.endOffset == "number", s = t.source?.start && t.source.end;
	if (e && s) return;
	let r = Number.POSITIVE_INFINITY, n = Number.NEGATIVE_INFINITY, i, o;
	for (let c in t) {
		if (c === "source" || c === "raws" || c === "spaces") continue;
		let f = t[c], h = Array.isArray(f) ? f : [f];
		for (let l of h) !l || typeof l != "object" || typeof l.source?.startOffset != "number" || typeof l.source?.endOffset != "number" || (l.source.startOffset < r && (r = l.source.startOffset, i = l.source.start), l.source.endOffset > n && (n = l.source.endOffset, o = l.source.end));
	}
	r !== Number.POSITIVE_INFINITY && (t.source ?? (t.source = {}), e || (t.source.startOffset = r, t.source.endOffset = n), (u = t.source).start ?? (u.start = i), (a = t.source).end ?? (a.end = o));
}
function Wn(t, e) {
	typeof t.type != "string" || t.source || typeof e.source?.startOffset != "number" || typeof e.source?.endOffset != "number" || !yc(t) || (t.source = {
		startOffset: e.source.startOffset,
		endOffset: e.source.startOffset,
		start: e.source.start,
		end: e.source.start
	});
}
function dc(t) {
	if (!(typeof t.source?.startOffset != "number" || typeof t.source?.endOffset != "number")) for (let e in t) {
		if (e === "source" || e === "raws" || e === "spaces") continue;
		let s = t[e], r = Array.isArray(s) ? s : [s];
		for (let n of r) n && typeof n == "object" && Wn(n, t);
	}
}
function yc(t) {
	return Array.isArray(t.nodes) && t.nodes.length === 0 || Array.isArray(t.groups) && t.groups.length === 0;
}
function $n(t) {
	let e = "initial", s = "initial", r, n = !1, i = [];
	for (let o = 0; o < t.length; o++) {
		let u = t[o];
		switch (e) {
			case "initial":
				if (u === "'") {
					e = "single-quotes";
					continue;
				}
				if (u === "\"") {
					e = "double-quotes";
					continue;
				}
				if ((u === "u" || u === "U") && t.slice(o, o + 4).toLowerCase() === "url(") {
					e = "url", o += 3;
					continue;
				}
				if (u === "/") {
					let a = t[o + 1];
					a === "*" ? (e = "comment-block", o++) : a === "/" && (e = "comment-inline", r = o, o++);
					continue;
				}
				continue;
			case "single-quotes":
				if (u === "'" && t[o - 1] !== "\\" && (e = s, s = "initial"), u === `
` || u === "\r") return t;
				continue;
			case "double-quotes":
				if (u === "\"" && t[o - 1] !== "\\" && (e = s, s = "initial"), u === `
` || u === "\r") return t;
				continue;
			case "url":
				if (u === ")") e = "initial";
				else if (u === `
` || u === "\r") return t;
				if (u === "'") {
					e = "single-quotes", s = "url";
					continue;
				}
				if (u === "\"") {
					e = "double-quotes", s = "url";
					continue;
				}
				continue;
			case "comment-block":
				u === "/" && t[o - 1] === "*" && (e = "initial");
				continue;
			case "comment-inline":
				u === "\"" || u === "'" || u === "*" ? n = !0 : (u === `
` || u === "\r") && (n && i.push([r, o]), e = "initial", n = !1);
				continue;
		}
	}
	for (let [o, u] of i) t = t.slice(0, o) + T(0, t.slice(o, u), /["'*]/g, " ") + t.slice(u);
	return t;
}
function gc(t) {
	return !!t?.[Bt];
}
function wc(t) {
	return T(0, t, /[^\n]/g, " ");
}
function vc(t) {
	let e = t.slice(0, et);
	if (e !== "---" && e !== "+++") return;
	let s = t.indexOf(`
`, et);
	if (s === -1) return;
	let r = t.slice(et, s).trim(), n = t.indexOf(`
${e}`, s), i = r;
	if (i || (i = e === "+++" ? "toml" : "yaml"), n === -1 && e === "---" && i === "yaml" && (n = t.indexOf(`
...`, s)), n === -1) return;
	let o = n + 1 + et, u = t.charAt(o + 1);
	if (!/\s?/.test(u)) return;
	let a = t.slice(0, o), c;
	return {
		language: i,
		explicitLanguage: r || null,
		value: t.slice(s + 1, n),
		startDelimiter: e,
		endDelimiter: a.slice(-et),
		raw: a,
		start: {
			line: 1,
			column: 0,
			index: 0
		},
		end: {
			index: a.length,
			get line() {
				return c ?? (c = a.split(`
`)), c.length;
			},
			get column() {
				return c ?? (c = a.split(`
`)), $(0, c, -1).length;
			}
		},
		[Bt]: !0
	};
}
function xc(t) {
	let e = vc(t);
	return e ? {
		frontMatter: e,
		get content() {
			let { raw: s } = e;
			return Ut(s) + t.slice(s.length);
		}
	} : { content: t };
}
function ns(t, e, s) {
	if (t.type === "css-comment" && s.type === "css-root" && s.nodes.length > 0 && ((s.nodes[0] === t || De(s.nodes[0]) && s.nodes[1] === t) && (delete e.text, /^\*\s*@(?:format|prettier)\s*$/.test(t.text)) || s.type === "css-root" && $(0, s.nodes, -1) === t)) return null;
	if (t.type === "value-root" && delete e.text, (t.type === "media-query" || t.type === "media-query-list" || t.type === "media-feature-expression") && delete e.value, t.type === "css-rule" && (delete e.params, t.extend && Ec(t.selector) && delete e.extend), (t.type === "media-feature" || t.type === "media-keyword" || t.type === "media-type" || t.type === "media-unknown" || t.type === "media-url" || t.type === "media-value" || t.type === "selector-attribute" || t.type === "selector-string" || t.type === "selector-class" || t.type === "selector-combinator" || t.type === "value-string") && t.value && (e.value = bc(t.value)), t.type === "selector-combinator" && (e.value = T(0, e.value, /\s+/g, " ")), t.type === "media-feature" && (e.value = T(0, e.value, " ", "")), (t.type === "value-word" && (t.isColor && t.isHex || [
		"initial",
		"inherit",
		"unset",
		"revert"
	].includes(t.value.toLowerCase())) || t.type === "media-feature" || t.type === "selector-root-invalid" || t.type === "selector-pseudo") && (e.value = e.value.toLowerCase()), t.type === "css-decl" && (e.prop = t.prop.toLowerCase()), (t.type === "css-atrule" || t.type === "css-import") && (e.name = t.name.toLowerCase()), t.type === "value-number" && (e.unit = t.unit.toLowerCase()), t.type === "value-unknown" && (e.value = T(0, e.value, /;$/g, "")), t.type === "selector-attribute" && (e.attribute = t.attribute.trim(), t.namespace && typeof t.namespace == "string" && (e.namespace = t.namespace.trim() || !0), t.value)) {
		let { value: r } = e;
		/\s[a-z]$/i.test(r) && (e.__prettier_attribute_selector_flag = $(0, r, -1), r = r.slice(0, -1)), r = r.trim(), r = r.replace(/^(?<quote>["'])(?<value>.*?)\k<quote>$/, "$<value>"), e.value = r, delete e.quoted;
	}
	if ((t.type === "media-value" || t.type === "media-type" || t.type === "value-number" || t.type === "selector-root-invalid" || t.type === "selector-class" || t.type === "selector-combinator" || t.type === "selector-tag") && t.value && (e.value = T(0, e.value, /([\d+.e-]+)([a-z]*)/gi, (r, n, i) => {
		let o = Number(n);
		return Number.isNaN(o) ? r : o + i.toLowerCase();
	})), t.type === "selector-tag") {
		let r = e.value.toLowerCase();
		["from", "to"].includes(r) && (e.value = r);
	}
	if (t.type === "css-atrule" && t.name.toLowerCase() === "supports" && delete e.value, t.type === "selector-unknown" && delete e.value, t.type === "value-comma_group") {
		let r = t.groups.findIndex((n) => n.type === "value-number" && n.unit === "...");
		r !== -1 && (e.groups[r].unit = "", e.groups.splice(r + 1, 0, {
			type: "value-word",
			value: "...",
			isColor: !1,
			isHex: !1
		}));
	}
	if (t.type === "value-comma_group" && t.groups.some((r) => r.type === "value-atword" && (r.value.endsWith("[") || r.value.endsWith("]")) || r.type === "value-word" && (r.value.startsWith("]") || r.value.startsWith("[")))) return {
		type: "value-atword",
		value: t.groups.map((r) => r.value).join("")
	};
	if (t.type === "value-func" && t.value === "if" && t.group.type === "value-paren_group" && t.group.groups.length === 1 && t.group.groups[0].type === "value-comma_group") {
		let r = t.group.groups[0].groups, n = e.group.groups[0].groups;
		for (let i = r.length - 1; i >= 0; i--) {
			let o = r[i];
			if (o.type === "value-word" && typeof o.value == "string" && o.value.endsWith(";")) {
				if (o.value === ";") {
					r[i - 1]?.type === "value-number" && n.splice(i - 1, 2, { type: "#node-placeholder" });
					continue;
				}
				n[i] = { type: "#node-placeholder" };
			}
		}
	}
}
function bc(t) {
	return T(0, T(0, t, "'", "\""), /\\([^\da-f])/gi, "$1");
}
function Ec(t) {
	return t?.nodes?.some((e) => e.nodes?.some((s) => s.type === "selector-pseudo" && s.value === ":extend"));
}
function Hn(t) {
	let e = t.match(zn);
	return e ? e[0].trimStart() : "";
}
function Qn(t) {
	let s = t.match(zn)?.[0];
	return s == null ? t : t.slice(s.length);
}
function Kn(t) {
	t = T(0, t.replace(kc, "").replace(Tc, ""), Cc, "$1");
	let s = "";
	for (; s !== t;) s = t, t = T(0, t, Ac, `
$1 $2
`);
	t = t.replace(Gn, "").trimEnd();
	let r = Object.create(null), n = T(0, t, Yn, "").replace(Gn, "").trimEnd(), i;
	for (; i = Yn.exec(t);) {
		let o = T(0, i[2], Oc, "");
		if (typeof r[i[1]] == "string" || Array.isArray(r[i[1]])) {
			let u = r[i[1]];
			r[i[1]] = [
				...jn,
				...Array.isArray(u) ? u : [u],
				o
			];
		} else r[i[1]] = o;
	}
	return {
		comments: n,
		pragmas: r
	};
}
function Xn({ comments: t = "", pragmas: e = {} }) {
	let o = Object.keys(e), u = o.flatMap((c) => Vn(c, e[c])).map((c) => ` * ${c}
`).join("");
	if (!t) {
		if (o.length === 0) return "";
		if (o.length === 1 && !Array.isArray(e[o[0]])) {
			let c = e[o[0]];
			return `/** ${Vn(o[0], c)[0]} */`;
		}
	}
	let a = t.split(`
`).map((c) => ` * ${c}`).join(`
`) + `
`;
	return `/**
` + (t ? a : "") + (t && o.length > 0 ? ` *
` : "") + u + " */";
}
function Vn(t, e) {
	return [...jn, ...Array.isArray(e) ? e : [e]].map((s) => `@${t} ${s}`.trim());
}
function Nc(t) {
	if (!t.startsWith("#!")) return "";
	let e = t.indexOf(`
`);
	return e === -1 ? t : t.slice(0, e);
}
function os(t) {
	let e = ti(t);
	e && (t = t.slice(e.length + 1));
	let { pragmas: r, comments: n } = Kn(Hn(t));
	return {
		shebang: e,
		text: t,
		pragmas: r,
		comments: n
	};
}
function ri(t) {
	let { pragmas: e } = os(t);
	return Zn.some((s) => is(e, s));
}
function si(t) {
	let { pragmas: e } = os(t);
	return Jn.some((s) => is(e, s));
}
function ni(t) {
	let { shebang: e, text: s, pragmas: r, comments: n } = os(t), i = Qn(s), o = Xn({
		pragmas: {
			[ei]: "",
			...r
		},
		comments: n.trimStart()
	});
	return (e ? `${e}
` : "") + o + (i.startsWith(`
`) ? `
` : `

`) + i;
}
function ui(t) {
	return t.findAncestor((e) => e.type === "css-decl")?.prop?.toLowerCase();
}
function li(t) {
	return Rc.has(t.toLowerCase());
}
function ci(t, e) {
	return t.findAncestor((r) => r.type === "css-atrule")?.name?.toLowerCase().endsWith("keyframes") && ["from", "to"].includes(e.toLowerCase());
}
function Me(t) {
	return t.includes("$") || t.includes("@") || t.includes("#") || t.startsWith("%") || t.startsWith("--") || t.startsWith(":--") || t.includes("(") && t.includes(")") ? t : t.toLowerCase();
}
function _e(t, e) {
	return t.findAncestor((r) => r.type === "value-func")?.value?.toLowerCase() === e;
}
function fi(t) {
	return t.hasAncestor((e) => {
		if (e.type !== "css-rule") return !1;
		let s = e.raws?.selector;
		return s && (s.startsWith(":import") || s.startsWith(":export"));
	});
}
function be(t, e) {
	let s = Array.isArray(e) ? e : [e], r = t.findAncestor((n) => n.type === "css-atrule");
	return r && s.includes(r.name.toLowerCase());
}
function pi(t) {
	let { node: e } = t;
	return e.groups[0]?.value === "url" && e.groups.length === 2 && t.findAncestor((s) => s.type === "css-atrule")?.name === "import";
}
function hi(t) {
	return t.type === "value-func" && t.value.toLowerCase() === "url";
}
function mi(t) {
	return t.type === "value-func" && t.value.toLowerCase() === "var";
}
function di(t) {
	let { selector: e } = t;
	return e ? typeof e == "string" && /^@.+:.*$/.test(e) || e.value && /^@.+:.*$/.test(e.value) : !1;
}
function yi(t) {
	return t.type === "value-word" && [
		"from",
		"through",
		"end"
	].includes(t.value);
}
function gi(t) {
	return t.type === "value-word" && [
		"and",
		"or",
		"not"
	].includes(t.value);
}
function wi(t) {
	return t.type === "value-word" && t.value === "in";
}
function Ft(t) {
	return t.type === "value-operator" && t.value === "*";
}
function Ee(t) {
	return t?.type === "value-operator" && t.value === "/";
}
function K(t) {
	return t.type === "value-operator" && t.value === "+";
}
function Se(t) {
	return t.type === "value-operator" && t.value === "-";
}
function Ic(t) {
	return t.type === "value-operator" && t.value === "%";
}
function tt(t) {
	return Ft(t) || Ee(t) || K(t) || Se(t) || Ic(t);
}
function vi(t) {
	return t.type === "value-word" && ["==", "!="].includes(t.value);
}
function xi(t) {
	return t.type === "value-word" && [
		"<",
		">",
		"<=",
		">="
	].includes(t.value);
}
function rt(t, e) {
	return e.parser === "scss" && t.type === "css-atrule" && [
		"if",
		"else",
		"for",
		"each",
		"while"
	].includes(t.name);
}
function us(t) {
	return t.raws?.params && /^\(\s*\)$/.test(t.raws.params);
}
function Wt(t) {
	return t.name.startsWith("prettier-placeholder");
}
function _i(t) {
	return t.prop.startsWith("@prettier-placeholder");
}
function bi(t, e) {
	return t.value === "$$" && t.type === "value-func" && e?.type === "value-word" && !e.raws.before;
}
function Ei(t) {
	return t.value?.type === "value-root" && t.value.group?.type === "value-value" && t.prop.toLowerCase() === "composes";
}
function Si(t) {
	return t.value?.group?.group?.type === "value-paren_group" && t.value.group.group.open !== null && t.value.group.group.close !== null;
}
function X(t) {
	return t?.raws?.before === "";
}
function $t(t) {
	return t.type === "value-comma_group" && t.groups?.[1]?.type === "value-colon";
}
function as(t) {
	return t.type === "value-paren_group" && t.groups?.[0] && $t(t.groups[0]);
}
function ls(t, e) {
	if (e.parser !== "scss") return !1;
	let { node: s } = t;
	if (s.groups.length === 0 || s.type === "value-paren_group" && s.open && s.close && s.groups.length === 1 && s.groups[0].type !== "value-comma_group") return !1;
	let r = t.parent;
	if (r && r.type === "value-func" && r.value === "if") return !1;
	let n = t.grandparent;
	return !as(s) && !(n && as(n)) ? !1 : t.findAncestor((o) => o.type === "css-decl")?.prop?.startsWith("$") ? !0 : as(n) ? !r.groups.some((o) => tt(o)) : n.type === "value-func";
}
function st(t) {
	return t.type === "value-comment" && t.inline;
}
function Gt(t) {
	return t.type === "value-word" && t.value === "#";
}
function cs(t) {
	return t.type === "value-word" && t.value === "{";
}
function Yt(t) {
	return t.type === "value-word" && t.value === "}";
}
function nt(t) {
	return ["value-word", "value-atword"].includes(t.type);
}
function Vt(t) {
	return t?.type === "value-colon";
}
function Ti(t, e) {
	if (!$t(e)) return !1;
	let { groups: s } = e, r = s.indexOf(t);
	return r === -1 ? !1 : Vt(s[r + 1]);
}
function ki(t) {
	return t.value && [
		"not",
		"and",
		"or"
	].includes(t.value.toLowerCase());
}
function Oi(t) {
	return t.type !== "value-func" ? !1 : Pc.has(t.value.toLowerCase());
}
function Be(t) {
	return /\/\//.test(t.split(/[\n\r]/).pop());
}
function ce(t) {
	return t?.type === "value-atword" && t.value.startsWith("prettier-placeholder-");
}
function Ai(t, e) {
	if (t.open?.value !== "(" || t.close?.value !== ")" || t.groups.some((s) => s.type !== "value-comma_group")) return !1;
	if (e.type === "value-comma_group") {
		let s = e.groups.indexOf(t) - 1, r = e.groups[s];
		if (r?.type === "value-word" && r.value === "with") return !0;
	}
	return !1;
}
function it(t) {
	return t.type === "value-paren_group" && t.open?.value === "(" && t.close?.value === ")";
}
function Lc(t, e, s) {
	let { node: r } = t, n = t.parent, i = t.grandparent, o = ui(t), u = o && n.type === "value-value" && (o === "grid" || o.startsWith("grid-template")), a = t.findAncestor((p) => p.type === "css-atrule"), c = a && rt(a, e), f = r.groups.some((p) => st(p)), h = t.map(s, "groups"), l = [""], d = _e(t, "url"), x = !1, m = !1;
	for (let p = 0; p < r.groups.length; ++p) {
		let y = r.groups[p - 1], g = r.groups[p], v = r.groups[p + 1];
		if (st(g) && !v) {
			l.push([l.pop(), Rt([" ", h[p]])]);
			continue;
		}
		if (l.push([l.pop(), h[p]]), d) {
			(v && K(v) || K(g)) && l.push([l.pop(), " "]);
			continue;
		}
		if (be(t, "forward") && g.type === "value-word" && g.value && y !== void 0 && y.type === "value-word" && y.value === "as" && v.type === "value-operator" && v.value === "*" || be(t, "utility") && g.type === "value-word" && v && v.type === "value-operator" && v.value === "*" || !v || e.parser === "scss" && v.type === "value-word" && v.value === ";" && t.match(void 0, (b, S) => S === "groups" && b.type === "value-paren_group", (b, S) => S === "group" && b.type === "value-func" && b.value === "if") || g.type === "value-word" && ce(v) && P(g) === N(v)) continue;
		if (g.type === "value-string" && g.quoted) {
			let b = g.value.lastIndexOf("#{"), S = g.value.lastIndexOf("}");
			b !== -1 && S !== -1 ? x = b > S : b !== -1 ? x = !0 : S !== -1 && (x = !1);
		}
		if (x || Vt(g) || Vt(v) || g.type === "value-atword" && (g.value === "" || g.value.endsWith("[")) || v.type === "value-word" && v.value.startsWith("]") || g.value === "~") continue;
		if (e.parser === "less") {
			if (v?.type === "value-word" && v.value === "[") continue;
			if (g.type === "value-word" && g.value.endsWith("[") && (v?.type === "value-atword" || v?.type === "value-word")) {
				G(r.groups.some((b, S) => S > p && (b.value?.startsWith("]") || b.value?.endsWith("]"))));
				continue;
			}
		}
		if (g.type !== "value-string" && g.value && g.value.includes("\\") && v && v.type !== "value-comment" || y?.value && y.value.indexOf("\\") === y.value.length - 1 && g.type === "value-operator" && g.value === "/" || g.value === "\\" || bi(g, v) || Gt(g) || cs(g) || Yt(v) || cs(v) && X(v) || Yt(g) && X(v) || g.value === "--" && Gt(v)) continue;
		let C = tt(g), q = tt(v);
		if ((C && Gt(v) || q && Yt(g)) && X(v) || K(v) && _e(t, "type") && X(v) || !y && Ee(g) || _e(t, "calc") && (K(g) || K(v) || Se(g) || Se(v)) && X(v)) continue;
		if (e.parser === "scss" && C && g.value === "-" && v.type === "value-func" && P(g) !== N(v)) {
			l.push([l.pop(), " "]);
			continue;
		}
		let W = r.groups[p + 2], se = (K(g) || Se(g)) && p === 0 && (v.type === "value-number" || v.isHex) && i && Oi(i) && !X(v), ye = W?.type === "value-func" || W && nt(W) || g.type === "value-func" || nt(g), k = v.type === "value-func" || nt(v) || y?.type === "value-func" || y && nt(y);
		if (!(!(Ft(v) || Ft(g)) && !_e(t, "calc") && !se && (Ee(v) && !ye || Ee(g) && !k || K(v) && !ye || K(g) && !k || Se(v) || Se(g)) && (X(v) || C && (!y || y && tt(y)))) && !((e.parser === "scss" || e.parser === "less") && C && g.value === "-" && it(v) && P(g) === N(v.open) && v.open.value === "(")) {
			if (st(g)) {
				if (n.type === "value-paren_group") {
					l.push(ue(O), "");
					continue;
				}
				l.push(O, "");
				continue;
			}
			if (c && (vi(v) || xi(v) || gi(v) || wi(g) || yi(g))) {
				l.push([l.pop(), " "]);
				continue;
			}
			if (a && a.name.toLowerCase() === "namespace") {
				l.push([l.pop(), " "]);
				continue;
			}
			if (u) {
				g.source && v.source && g.source.start.line !== v.source.start.line ? (l.push(O, ""), m = !0) : l.push([l.pop(), " "]);
				continue;
			}
			if (!(o && (o === "font" || o.startsWith("--")) && (Ee(v) && X(v) && Ci(g) || Ee(g) && X(g) && Ci(y)))) {
				if (q) {
					l.push([l.pop(), " "]);
					continue;
				}
				if (v?.value !== "..." && !(ce(g) && ce(v) && P(g) === N(v))) {
					if (ce(g) && it(v) && P(g) === N(v.open)) {
						l.push(I, "");
						continue;
					}
					if (g.value === "with" && it(v)) {
						l = [[qe(l), " "]];
						continue;
					}
					if (!(g.value?.endsWith("#") && v.value === "{" && it(v.group)) && !(st(v) && !W)) {
						if (!a && g.type === "value-comment" && !g.inline && r.groups.slice(0, p).every((b) => b.type === "value-comment")) {
							l.push(ue(A), "");
							continue;
						}
						l.push(A, "");
					}
				}
			}
		}
	}
	return f && l.push([l.pop(), ve]), m && l.unshift("", O), c ? D(R(l)) : pi(t) ? D(qe(l)) : D(R(qe(l)));
}
function Ci(t) {
	if (t?.type === "value-number") return !0;
	if (t?.type !== "value-func") return !1;
	let e = t.value.toLowerCase();
	return e === "var" || e === "calc" || e === "min" || e === "max" || e === "clamp" || e.startsWith("--");
}
function qc(t) {
	return t.length === 1 ? t : t.toLowerCase().replace(/^([+-]?[\d.]+e)(?:\+|(-))?0*(?=\d)/, "$1$2").replace(/^([+-]?[\d.]+)e[+-]?0+$/, "$1").replace(/^([+-])?\./, "$10.").replace(/(\.\d+?)0+(?=e|$)/, "$1").replace(/\.(?=e|$)/, "");
}
function fs(t) {
	let e = t.toLowerCase();
	return zt.has(e) ? zt.get(e) : t;
}
function V(t, e) {
	return T(0, t, Ri, (s) => Lt(s, e));
}
function Ii(t, e) {
	let s = e.singleQuote ? "'" : "\"", r = "", n = t.match(/^(?<value>.+?)\s+(?<flag>[a-z])$/i);
	return n && ({value: t, flag: r} = n.groups), (t.includes("\"") || t.includes("'") ? t : s + t + s) + (r ? ` ${r}` : "");
}
function Te(t) {
	return T(0, t, Uc, (e, s, r, n, i) => !r && n && (i ?? (i = ""), i = i.toLowerCase(), !i || i === "n" || zt.has(i)) ? ps(n) + (i ? fs(i) : "") : e);
}
function ps(t) {
	return Pi(t).replace(/\.0(?=$|e)/, "");
}
function Li(t) {
	return t.trailingComma === "es5" || t.trailingComma === "all";
}
function Fc(t, e, s) {
	if (e === !1) return !1;
	let r = !!s?.backwards, n = t.charAt(e);
	if (r) {
		if (t.charAt(e - 1) === "\r" && n === `
`) return e - 2;
		if (qi(n)) return e - 1;
	} else {
		if (n === "\r" && t.charAt(e + 1) === `
`) return e + 2;
		if (qi(n)) return e + 1;
	}
	return e;
}
function Wc(t, e, s = {}) {
	let r = Dt(t, s.backwards ? e - 1 : e, s);
	return r !== jt(t, r, s);
}
function $c(t, e) {
	if (e === !1) return !1;
	if (t.charAt(e) === "/" && t.charAt(e + 1) === "*") {
		for (let s = e + 2; s < t.length; ++s) if (t.charAt(s) === "*" && t.charAt(s + 1) === "/") return s + 2;
	}
	return e;
}
function Gc(t, e) {
	return e === !1 ? !1 : t.charAt(e) === "/" && t.charAt(e + 1) === "/" ? Mt(t, e) : e;
}
function Yc(t, e) {
	let s = null, r = e;
	for (; r !== s;) s = r, r = Ln(t, r), r = Di(t, r), r = Dt(t, r);
	return r = Mi(t, r), r = jt(t, r), r !== !1 && Ht(t, r);
}
function Vc({ node: t, parent: e }, s) {
	return !!(t.source && s.originalText.slice(N(t), N(e.close)).trimEnd().endsWith(","));
}
function zc(t, e) {
	return mi(t.grandparent) && Vc(t, e) ? "," : t.node.type !== "value-comment" && !(t.node.type === "value-comma_group" && t.node.groups.every((s) => s.type === "value-comment")) && Li(e) && t.callParent(() => ls(t, e)) ? Pt(",") : "";
}
function Bi(t, e, s) {
	let { node: r, parent: n } = t, i = t.map(({ node: d }) => typeof d == "string" ? d : s(), "groups");
	if (n && hi(n) && (r.groups.length === 1 || r.groups.length > 0 && r.groups[0].type === "value-comma_group" && r.groups[0].groups.length > 0 && r.groups[0].groups[0].type === "value-word" && r.groups[0].groups[0].value.startsWith("data:"))) return [
		r.open ? s("open") : "",
		Y(",", i),
		r.close ? s("close") : ""
	];
	if (!r.open) {
		let d = hs(t);
		we(i);
		let x = Hc(Y(",", i), 2), m = Y(d ? O : A, x);
		return R(d ? [O, m] : D([jc(t) ? I : "", qe(m)]));
	}
	let o = t.map(({ node: d, isLast: x, index: m }) => {
		let p = i[m];
		$t(d) && d.type === "value-comma_group" && d.groups && d.groups[0].type !== "value-paren_group" && d.groups[2]?.type === "value-paren_group" && ae(p) === ie && ae(p.contents) === ne && ae(p.contents.contents) === oe && (p = D(ue(p)));
		let y = [p, x ? zc(t, e) : ","];
		if (!x && d.type === "value-comma_group" && le(d.groups)) {
			let g = $(0, d.groups, -1);
			!g.source && g.close && (g = g.close), g.source && Qt(e.originalText, P(g)) && y.push(O);
		}
		return y;
	}, "groups"), u = Ti(r, n), a = Ai(r, n), c = ls(t, e), f = a || c && !u, h = a || u, l = D([
		r.open ? s("open") : "",
		R([I, Y(A, o)]),
		I,
		It,
		r.close ? s("close") : ""
	], { shouldBreak: f });
	return h ? ue(l) : l;
}
function hs(t) {
	return t.match((e) => e.type === "value-paren_group" && !e.open && e.groups.some((s) => s.type === "value-comma_group"), (e, s) => s === "group" && e.type === "value-value", (e, s) => s === "group" && e.type === "value-root", (e, s) => s === "value" && (e.type === "css-decl" && !e.prop.startsWith("--") || e.type === "css-atrule" && e.variable));
}
function jc(t) {
	return t.match((e) => e.type === "value-paren_group" && !e.open, (e, s) => s === "group" && e.type === "value-value", (e, s) => s === "group" && e.type === "value-root", (e, s) => s === "value" && e.type === "css-decl");
}
function Hc(t, e) {
	let s = [];
	for (let r = 0; r < t.length; r += e) s.push(t.slice(r, r + e));
	return s;
}
function Qc(t, e, s) {
	let r = [];
	return t.each(() => {
		let { node: n, previous: i } = t;
		if (i?.type === "css-comment" && i.text.trim() === "prettier-ignore" ? r.push(e.originalText.slice(N(n), P(n))) : r.push(s()), t.isLast) return;
		let { next: o } = t;
		o.type === "css-comment" && !Ht(e.originalText, N(o), { backwards: !0 }) && !De(n) || o.type === "css-atrule" && o.name === "else" && n.type !== "css-comment" ? r.push(" ") : (r.push(e.__isHTMLStyleAttribute ? A : O), Qt(e.originalText, P(n)) && !De(n) && r.push(O));
	}, "nodes"), r;
}
function Kc(t, e, s) {
	let { node: r } = t;
	switch (r.type) {
		case "css-root": {
			let n = Ue(t, e, s), i = r.raws.after.trim();
			return i.startsWith(";") && (i = i.slice(1).trim()), [
				r.frontMatter ? [
					s("frontMatter"),
					O,
					r.nodes.length > 0 ? O : ""
				] : "",
				n,
				i ? ` ${i}` : "",
				r.nodes.length > 0 ? O : ""
			];
		}
		case "css-comment": {
			let n = r.inline || r.raws.inline, i = e.originalText.slice(N(r), P(r));
			return n ? i.trimEnd() : i;
		}
		case "css-rule": return [
			s("selector"),
			r.important ? " !important" : "",
			r.nodes ? [
				r.selector?.type === "selector-unknown" && Be(r.selector.value) ? A : r.selector ? " " : "",
				"{",
				r.nodes.length > 0 ? R([O, Ue(t, e, s)]) : "",
				O,
				"}",
				di(r) ? ";" : ""
			] : ";"
		];
		case "css-decl": {
			let n = t.parent, { between: i } = r.raws, o = i.trim(), u = o === ":", a = i.endsWith(" ") && u, c = typeof r.value == "string" && /^ *$/.test(r.value), f = typeof r.value == "string" ? r.value : s("value");
			return f = Ei(r) ? gn(f) : f, !u && Be(o) && !t.call(() => hs(t), "value", "group", "group") && (f = R([O, ue(f)])), [
				T(0, r.raws.before, /[\s;]/g, ""),
				n.type === "css-atrule" && n.variable || fi(t) ? r.prop : Me(r.prop),
				o.startsWith("//") ? " " : "",
				o,
				r.extend || c || !a && r.isNested && (ce(r.value.group.group) || ce(r.value.group.group.groups?.[0])) ? "" : " ",
				e.parser === "less" && r.extend && r.selector ? r.selector.nodes.length > 1 ? D([
					"extend(",
					R([I, s("selector")]),
					I,
					")"
				]) : [
					"extend(",
					s("selector"),
					")"
				] : "",
				f,
				r.raws.important ? r.raws.important.replace(/\s*!\s*important/i, " !important") : r.important ? " !important" : "",
				r.raws.scssDefault ? r.raws.scssDefault.replace(/\s*!default/i, " !default") : r.scssDefault ? " !default" : "",
				r.raws.scssGlobal ? r.raws.scssGlobal.replace(/\s*!global/i, " !global") : r.scssGlobal ? " !global" : "",
				r.nodes ? [
					" {",
					r.nodes.length > 0 ? R([I, Ue(t, e, s)]) : "",
					I,
					"}"
				] : _i(r) && !n.raws.semicolon && e.originalText[P(r) - 1] !== ";" ? "" : e.__isHTMLStyleAttribute && t.isLast ? Pt(";") : ";"
			];
		}
		case "css-atrule": {
			let n = t.parent, i = Wt(r) && !n.raws.semicolon && e.originalText[P(r) - 1] !== ";";
			if (e.parser === "less") {
				if (r.mixin) return [
					s("selector"),
					r.important ? " !important" : "",
					i ? "" : ";"
				];
				if (r.function) return [
					r.name,
					typeof r.params == "string" ? r.params : s("params"),
					i ? "" : ";"
				];
				if (r.variable) return [
					"@",
					r.name,
					": ",
					r.value ? [s("value"), It] : "",
					r.raws.between.trim() ? r.raws.between.trim() + " " : "",
					r.nodes ? [
						"{",
						r.nodes.length > 0 ? R([I, Ue(t, e, s)]) : "",
						I,
						"}"
					] : "",
					i ? "" : ";"
				];
			}
			let o = r.name === "import" && r.params?.type === "value-unknown" && r.params.value.endsWith(";");
			return [
				"@",
				us(r) || r.name.endsWith(":") || Wt(r) ? r.name : Me(r.name),
				r.params ? [us(r) ? "" : Wt(r) ? r.raws.afterName === "" ? "" : r.name.endsWith(":") ? " " : /^\s*\n\s*\n/.test(r.raws.afterName) ? [O, O] : /^\s*\n/.test(r.raws.afterName) ? O : " " : " ", typeof r.params == "string" ? r.params : s("params")] : "",
				r.selector ? R([" ", s("selector")]) : "",
				r.value ? D([
					" ",
					s("value"),
					rt(r, e) ? Si(r) ? " " : A : ""
				]) : r.name === "else" ? " " : "",
				r.nodes ? [
					rt(r, e) ? "" : r.selector && !r.selector.nodes && typeof r.selector.value == "string" && Be(r.selector.value) || !r.selector && typeof r.params == "string" && Be(r.params) ? A : " ",
					"{",
					r.nodes.length > 0 ? R([I, Ue(t, e, s)]) : "",
					I,
					"}"
				] : i || o ? "" : ";"
			];
		}
		case "media-query-list": {
			let n = [];
			return t.each(({ node: i }) => {
				i.type === "media-query" && i.value === "" || n.push(s());
			}, "nodes"), D(R(Y(A, n)));
		}
		case "media-query": return [Y(" ", t.map(s, "nodes")), t.isLast ? "" : ","];
		case "media-type": return Te(V(r.value, e));
		case "media-feature-expression": return r.nodes ? [
			"(",
			...t.map(s, "nodes"),
			")"
		] : r.value;
		case "media-feature": return Me(V(T(0, r.value, / +/g, " "), e));
		case "media-colon": return [r.value, " "];
		case "media-value": return Te(V(r.value, e));
		case "media-keyword": return V(r.value, e);
		case "media-url": return V(T(0, T(0, r.value, /^url\(\s+/gi, "url("), /\s+\)$/g, ")"), e);
		case "media-unknown": return r.value;
		case "selector-root": return D([be(t, "custom-selector") ? [t.findAncestor((n) => n.type === "css-atrule").customSelector, A] : "", Y([",", be(t, [
			"extend",
			"custom-selector",
			"nest"
		]) ? A : O], t.map(s, "nodes"))]);
		case "selector-selector": return D((r.nodes.length > 2 ? R : (i) => i)(t.map(s, "nodes")));
		case "selector-comment": return r.value;
		case "selector-string": return V(r.value, e);
		case "selector-tag": return [r.namespace ? [r.namespace === !0 ? "" : r.namespace.trim(), "|"] : "", t.previous?.type === "selector-nesting" ? r.value : Te(ci(t, r.value) ? r.value.toLowerCase() : r.value)];
		case "selector-id": return ["#", r.value];
		case "selector-class": return [".", Te(V(r.value, e))];
		case "selector-attribute": return [
			"[",
			r.namespace ? [r.namespace === !0 ? "" : r.namespace.trim(), "|"] : "",
			r.attribute.trim(),
			r.operator ?? "",
			r.value ? wn(Ii(V(r.value.trim(), e), e), Xr) : "",
			r.insensitive ? " i" : "",
			"]"
		];
		case "selector-combinator":
			if (r.value === "+" || r.value === ">" || r.value === "~" || r.value === ">>>") {
				let o = t.parent;
				return [
					o.type === "selector-selector" && o.nodes[0] === r ? "" : A,
					r.value,
					t.isLast ? "" : " "
				];
			}
			return [r.value.trimStart().startsWith("(") ? A : "", Te(V(r.value.trim(), e)) || A];
		case "selector-universal": return [r.namespace ? [r.namespace === !0 ? "" : r.namespace.trim(), "|"] : "", r.value];
		case "selector-pseudo": return [Me(r.value), le(r.nodes) ? D([
			"(",
			R([I, Y([",", A], t.map(s, "nodes"))]),
			I,
			")"
		]) : ""];
		case "selector-nesting": return r.value;
		case "selector-unknown": {
			if (t.findAncestor((u) => u.type === "css-rule")?.isScssNestedProperty) return Te(V(Me(r.value), e));
			let i = t.parent;
			if (i.raws?.selector) {
				let u = N(i), a = u + i.raws.selector.length;
				return e.originalText.slice(u, a).trim();
			}
			let o = t.grandparent;
			if (i.type === "value-paren_group" && o?.type === "value-func" && o.value === "selector") {
				let u = P(i.open) + 1, a = N(i.close), c = e.originalText.slice(u, a).trim();
				return Be(c) ? [ve, c] : c;
			}
			return r.value;
		}
		case "value-value":
		case "value-root": return s("group");
		case "value-comment": {
			let n = e.originalText.slice(N(r), P(r));
			return r.inline ? Rt(n.trimEnd()) : n;
		}
		case "value-comma_group": return Ni(t, e, s);
		case "value-paren_group": return Bi(t, e, s);
		case "value-func": return [
			r.value,
			be(t, "supports") && ki(r) ? " " : "",
			s("group")
		];
		case "value-paren": return r.value;
		case "value-number": return [ps(r.value), fs(r.unit)];
		case "value-operator": return r.value;
		case "value-word": return r.isColor && r.isHex || li(r.value) ? r.value.toLowerCase() : r.value;
		case "value-colon": {
			let { previous: n } = t;
			return D([r.value, typeof n?.value == "string" && n.value.endsWith("\\") || _e(t, "url") ? "" : A]);
		}
		case "value-string": return Lt(r.raws.quote + r.value + r.raws.quote, e);
		case "value-atword": return ["@", r.value];
		case "value-unicode-range": return r.value;
		case "value-unknown": return r.value;
		default: throw new An(r, "PostCSS");
	}
}
function Fp(t, e) {
	let s = /* @__PURE__ */ new SyntaxError(t + " (" + e.loc.start.line + ":" + e.loc.start.column + ")");
	return Object.assign(s, e);
}
function Wp(t) {
	return t !== null && typeof t == "object";
}
function ee(t, e, s) {
	if (Ae(t)) {
		delete t.parent;
		for (let r in t) ee(t[r], e, s), r === "type" && typeof t[r] == "string" && !t[r].startsWith(e) && (!s || !s.test(t[r])) && (t[r] = e + t[r]);
	}
	return t;
}
function js(t) {
	if (Ae(t)) {
		delete t.parent;
		for (let e in t) js(t[e]);
		!Array.isArray(t) && t.value && !t.type && (t.type = "unknown");
	}
	return t;
}
function eh(t) {
	let e;
	try {
		e = Zp(t);
	} catch {
		return {
			type: "selector-unknown",
			value: t
		};
	}
	return ee(js(e), "media-");
}
function my(t) {
	if (/\/[/*]/.test(T(0, t, /"[^"]+"|'[^']+'/g, ""))) return {
		type: "selector-unknown",
		value: t.trim()
	};
	let e;
	try {
		new Iu.default((s) => {
			e = s;
		}).process(t);
	} catch {
		return {
			type: "selector-unknown",
			value: t
		};
	}
	return ee(e, "selector-");
}
function sg(t) {
	return jr(t).text.slice(t.group.open.sourceIndex + 1, t.group.close.sourceIndex).trim();
}
function ng(t) {
	if (le(t)) {
		for (let e = t.length - 1; e > 0; e--) if (t[e].type === "word" && t[e].value === "{" && t[e - 1].type === "word" && t[e - 1].value.endsWith("#")) return !0;
	}
	return !1;
}
function ig(t) {
	return t.some((e) => e.type === "string" || e.type === "func" && !e.value.endsWith("\\"));
}
function og(t, e) {
	return !!(e.parser === "scss" && t?.type === "word" && t.value.startsWith("$"));
}
function ag(t, e) {
	let { nodes: s } = t, r = {
		open: null,
		close: null,
		groups: [],
		type: "paren_group"
	}, n = [r], i = r, o = {
		groups: [],
		type: "comma_group"
	}, u = [o];
	for (let a = 0; a < s.length; ++a) {
		let c = s[a];
		if (e.parser === "scss" && c.type === "number" && c.unit === ".." && c.value.endsWith(".") && (c.value = c.value.slice(0, -1), c.unit = "..."), c.type === "func" && c.value === "selector") {
			let f = jr(t).text.slice(c.group.open.sourceIndex + 1, c.group.close.sourceIndex), h = re(f);
			h.sourceIndex = c.group.open.sourceIndex + 1, h.raws ?? (h.raws = {}), h.raws.selector = f, c.group.groups = [h];
		}
		if (c.type === "func" && c.value === "url") {
			let f = c.group?.groups ?? [], h = [];
			for (let l = 0; l < f.length; l++) {
				let d = f[l];
				d.type === "comma_group" ? h = [...h, ...d.groups] : h.push(d);
			}
			(bl(h) || !El(h) && !Sl(h[0], e)) && (c.group.groups = [_l(c)]);
		}
		if (c.type === "paren" && c.value === "(") r = {
			open: c,
			close: null,
			groups: [],
			type: "paren_group"
		}, n.push(r), o = {
			groups: [],
			type: "comma_group"
		}, u.push(o);
		else if (Tl(c)) {
			if (o.groups.length > 0 && r.groups.push(o), r.close = c, u.length === 1) throw new Error("Unbalanced parenthesis");
			u.pop(), o = $(0, u, -1), o.groups.push(r), n.pop(), r = $(0, n, -1);
		} else if (c.type === "comma") {
			if (a === s.length - 3 && s[a + 1].type === "comment" && Tl(s[a + 2])) continue;
			r.groups.push(o), o = {
				groups: [],
				type: "comma_group"
			}, u[u.length - 1] = o;
		} else o.groups.push(c);
	}
	return o.groups.length > 0 && r.groups.push(o), i;
}
function Hr(t) {
	return t.type === "paren_group" && !t.open && !t.close && t.groups.length === 1 || t.type === "comma_group" && t.groups.length === 1 ? Hr(t.groups[0]) : t.type === "paren_group" || t.type === "comma_group" ? {
		...t,
		groups: t.groups.map(Hr)
	} : t;
}
function Ol(t, e) {
	if (Ae(t)) for (let s in t) s !== "parent" && (Ol(t[s], e), s === "nodes" && (t.type === "atword" && t.nodes.length === 0 || (t.group = Hr(ag(t, e))), delete t[s]));
	return t;
}
function ug(t, e) {
	if (e.parser === "less" && t.startsWith("~`")) return {
		type: "value-unknown",
		value: t
	};
	let s;
	try {
		s = new kl.default(t, { loose: !0 }).parse();
	} catch {
		return {
			type: "value-unknown",
			value: t
		};
	}
	s.text = t;
	return ee(Ol(s, e), "value-", /^selector-/);
}
function cg(t) {
	return lg.has(t);
}
function fg(t, e) {
	return e.parser !== "scss" || !t.selector ? !1 : t.selector.replace(/\/\*.*?\*\//, "").replace(/\/\/.*\n/, "").trimEnd().endsWith(":");
}
function Il(t, e) {
	if (Ae(t)) {
		delete t.parent;
		for (let i in t) Il(t[i], e);
		if (!t.type) return t;
		if (t.raws ?? (t.raws = {}), t.type === "css-decl" && typeof t.prop == "string" && t.prop.startsWith("--") && typeof t.value == "string" && t.value.startsWith("{")) {
			let i;
			if (t.value.trimEnd().endsWith("}")) {
				let o = e.originalText.slice(0, t.source.start.offset), u = "a".repeat(t.prop.length) + e.originalText.slice(t.source.start.offset + t.prop.length, t.source.end.offset), a = Ut(o) + u, c;
				e.parser === "scss" ? c = Dl : e.parser === "less" ? c = ql : c = Ll;
				let f;
				try {
					f = c(a, { ...e });
				} catch {}
				f?.nodes?.length === 1 && f.nodes[0].type === "css-rule" && (i = f.nodes[0].nodes);
			}
			return i ? t.value = {
				type: "css-rule",
				nodes: i
			} : t.value = {
				type: "value-unknown",
				value: t.raws.value.raw
			}, t;
		}
		let s = "";
		typeof t.selector == "string" && (s = t.raws.selector ? t.raws.selector.scss ?? t.raws.selector.raw : t.selector, t.raws.between && t.raws.between.trim().length > 0 && (s += t.raws.between), t.raws.selector = s);
		let r = "";
		typeof t.value == "string" && (r = t.raws.value ? t.raws.value.scss ?? t.raws.value.raw : t.value, t.raws.value = r.trim());
		let n = "";
		if (typeof t.params == "string" && (n = t.raws.params ? t.raws.params.scss ?? t.raws.params.raw : t.params, t.raws.afterName && t.raws.afterName.trim().length > 0 && (n = t.raws.afterName + n), t.raws.between && t.raws.between.trim().length > 0 && (n += t.raws.between), n = n.trim(), t.raws.params = n), s.trim().length > 0) return s.startsWith("@") && s.endsWith(":") ? t : t.mixin ? (t.selector = de(s, e), t) : (Cl(t, e) && (t.isScssNestedProperty = !0), t.selector = re(s), t);
		if (r.trim().length > 0) {
			let i = r.match(pg);
			i && (r = r.slice(0, i.index), t.scssDefault = !0, i[0].trim() !== "!default" && (t.raws.scssDefault = i[0]));
			let o = r.match(hg);
			if (o && (r = r.slice(0, o.index), t.scssGlobal = !0, o[0].trim() !== "!global" && (t.raws.scssGlobal = o[0])), r.startsWith("progid:")) return {
				type: "value-unknown",
				value: r
			};
			t.value = de(r, e);
		}
		if (e.parser === "less" && t.type === "css-decl" && typeof t.prop == "string" && /^\s*\+\s*:/.test(t.raws.between) && (t.prop += "+", t.raws.between = t.raws.between.replace("+", "")), e.parser === "less" && t.type === "css-decl" && r.startsWith("extend(") && (t.extend || (t.extend = t.raws.between === ":"), t.extend && !t.selector && (delete t.value, t.selector = re(r.slice(7, -1)))), t.type === "css-atrule") {
			if (e.parser === "less") {
				if (t.mixin) return t.selector = re(t.raws.identifier + t.name + t.raws.afterName + t.raws.params), delete t.params, t;
				if (t.function) return t;
			}
			if (e.parser === "css" && t.name === "custom-selector") {
				let i = t.params.match(/:--\S+\s+/)[0].trim();
				return t.customSelector = i, t.selector = re(t.params.slice(i.length).trim()), delete t.params, t;
			}
			if (e.parser === "less") {
				if (t.name.includes(":")) {
					t.variable = !0;
					let i = t.name.split(":");
					t.name = i[0];
					let o = i.slice(1).join(":");
					t.params && (o += t.params), t.value = de(o, e);
				}
				if (![
					"page",
					"nest",
					"keyframes"
				].includes(t.name) && t.params?.[0] === ":") {
					t.variable = !0;
					let i = t.params.slice(1);
					i && (t.value = de(i, e)), t.raws.afterName += ":";
				}
				if (t.variable) return delete t.params, t.value || delete t.value, t;
			}
		}
		if (t.type === "css-atrule" && n.length > 0) {
			let { name: i } = t;
			if (i === "warn" || i === "error") return t.params = {
				type: "media-unknown",
				value: n
			}, t;
			if (i === "extend" || i === "nest") return t.selector = re(n), delete t.params, t;
			if (i === "at-root") return /^\(\s*(?:without|with)\s*:.+\)$/s.test(n) ? t.params = de(n, e) : (t.selector = re(n), delete t.params), t;
			let o = i.toLowerCase();
			return Al(o) ? (t.import = !0, delete t.filename, t.params = de(n, e), t) : [
				"namespace",
				"supports",
				"if",
				"else",
				"for",
				"each",
				"while",
				"debug",
				"mixin",
				"include",
				"function",
				"return",
				"define-mixin",
				"add-mixin"
			].includes(i) ? (n = n.replace(/(\$\S+?)(\s+)?\.{3}/, "$1...$2"), n = n.replace(/^(?!if)([^"'\s(]+)(\s+)\(/, "$1($2"), t.value = de(n, e), delete t.params, t) : ["media", "custom-media"].includes(o) ? n.includes("#{") ? {
				type: "media-unknown",
				value: n
			} : (t.params = Ua(n), t) : (t.params = n, t);
		}
	}
	return t;
}
function un(t, e, s) {
	let { frontMatter: r, content: n } = xe(e), i;
	try {
		i = t(n, { map: !1 });
	} catch (o) {
		let { name: u, reason: a, line: c, column: f } = o;
		throw typeof c != "number" ? o : Pa(`${u}: ${a}`, {
			loc: { start: {
				line: c,
				column: f
			} },
			cause: o
		});
	}
	return s.originalText = e, i = Il(ee(i, "css-"), s), Bn(i, e), r && (i.frontMatter = {
		...r,
		type: "front-matter",
		source: {
			startOffset: r.start.index,
			endOffset: r.end.index
		}
	}), i;
}
function Ll(t, e = {}) {
	return un(Nl.default.default, t, e);
}
function ql(t, e = {}) {
	return un((s) => Pl.default.parse($n(s)), t, e);
}
function Dl(t, e = {}) {
	return un(Rl.default, t, e);
}
var Bl, Qr, Ul, Fl, Wl, $l, w, hn, Gl, Ne, Yi, ds, Kt, Xt, ut, Jt, ft, Fe, mt, pe, co, fo, _s, $e, er, Ye, ks, tr, nr, ir, yt, Lo, Do, Bo, Fo, Yo, jo, Qo, Ko, ar, ta, Ps, Rs, ur, Is, Ds, pa, ma, lr, Ea, ka, Aa, Na, Ws, Gs, Da, Ma, Hs, Qs, Ks, Ce, M, dr, ja, Qa, je, Ja, eu, ru, nu, ou, uu, cu, pu, mu, yu, wu, Ou, Nu, Ru, j, U, Mu, Uu, $u, Yu, zu, Hu, Xu, Zu, tl, sl, il, al, ll, fl, ml, yl, xl, Ml, Tt, Yl, T, $, Hl, G, Ke, Xe, kt, ne, Pe, Ot, ie, oe, ge, At, Re, Ie, H, Ct, Le, Nt, ae, Kl, Kr, dn, F, we, xn, _n, ve, A, I, O, Xr, vn, It, le, En, Sn, rc, sc, nc, On, Lt, Zr, An, Nn, Je, ac, Pn, Q, In, ts, Dt, Ln, Mt, N, P, Bt, De, Ut, et, xe, _c, is, Tc, kc, zn, Oc, Gn, Ac, Yn, Cc, jn, Jn, Zn, ei, ti, ii, oi, ai, Pc, Rc, Ni, Pi, zt, Ri, Uc, qi, jt, Ht, Di, Mi, Qt, Ue, Ui, Fi, $i, cn, Nl, Pl, Rl, Pa, Ae, Ba, Zp, Ua, Iu, re, kl, rg, jr, _l, bl, El, Sl, Tl, de, lg, Al, Cl, pg, hg, ln, mg, dg, yg, gg;
var init_postcss = __esmMin((() => {
	Bl = Object.create;
	Qr = Object.defineProperty;
	Ul = Object.getOwnPropertyDescriptor;
	Fl = Object.getOwnPropertyNames;
	Wl = Object.getPrototypeOf;
	$l = Object.prototype.hasOwnProperty;
	w = (t, e) => () => {
		try {
			return e || t((e = { exports: {} }).exports, e), e.exports;
		} catch (s) {
			throw e = 0, s;
		}
	};
	hn = (t, e) => {
		for (var s in e) Qr(t, s, {
			get: e[s],
			enumerable: !0
		});
	};
	Gl = (t, e, s, r) => {
		if (e && typeof e == "object" || typeof e == "function") for (let n of Fl(e)) !$l.call(t, n) && n !== s && Qr(t, n, {
			get: () => e[n],
			enumerable: !(r = Ul(e, n)) || r.enumerable
		});
		return t;
	};
	Ne = (t, e, s) => (s = t != null ? Bl(Wl(t)) : {}, Gl(e || !t || !t.__esModule ? Qr(s, "default", {
		value: t,
		enumerable: !0
	}) : s, t));
	Yi = w((Bx, ms) => {
		var _ = String, Gi = function() {
			return {
				isColorSupported: !1,
				reset: _,
				bold: _,
				dim: _,
				italic: _,
				underline: _,
				inverse: _,
				hidden: _,
				strikethrough: _,
				black: _,
				red: _,
				green: _,
				yellow: _,
				blue: _,
				magenta: _,
				cyan: _,
				white: _,
				gray: _,
				bgBlack: _,
				bgRed: _,
				bgGreen: _,
				bgYellow: _,
				bgBlue: _,
				bgMagenta: _,
				bgCyan: _,
				bgWhite: _,
				blackBright: _,
				redBright: _,
				greenBright: _,
				yellowBright: _,
				blueBright: _,
				magentaBright: _,
				cyanBright: _,
				whiteBright: _,
				bgBlackBright: _,
				bgRedBright: _,
				bgGreenBright: _,
				bgYellowBright: _,
				bgBlueBright: _,
				bgMagentaBright: _,
				bgCyanBright: _,
				bgWhiteBright: _
			};
		};
		ms.exports = Gi();
		ms.exports.createColors = Gi;
	});
	ds = w(() => {});
	Kt = w((Wx, ji) => {
		"use strict";
		var Vi = Yi(), zi = ds(), ot = class t extends Error {
			constructor(e, s, r, n, i, o) {
				super(e), this.name = "CssSyntaxError", this.reason = e, i && (this.file = i), n && (this.source = n), o && (this.plugin = o), typeof s < "u" && typeof r < "u" && (typeof s == "number" ? (this.line = s, this.column = r) : (this.line = s.line, this.column = s.column, this.endLine = r.line, this.endColumn = r.column)), this.setMessage(), Error.captureStackTrace && Error.captureStackTrace(this, t);
			}
			setMessage() {
				this.message = this.plugin ? this.plugin + ": " : "", this.message += this.file ? this.file : "<css input>", typeof this.line < "u" && (this.message += ":" + this.line + ":" + this.column), this.message += ": " + this.reason;
			}
			showSourceCode(e) {
				if (!this.source) return "";
				let s = this.source;
				e ??= Vi.isColorSupported;
				let r = (f) => f, n = (f) => f, i = (f) => f;
				if (e) {
					let { bold: f, gray: h, red: l } = Vi.createColors(!0);
					n = (d) => f(l(d)), r = (d) => h(d), zi && (i = (d) => zi(d));
				}
				let o = s.split(/\r?\n/), u = Math.max(this.line - 3, 0), a = Math.min(this.line + 2, o.length), c = String(a).length;
				return o.slice(u, a).map((f, h) => {
					let l = u + 1 + h, d = " " + (" " + l).slice(-c) + " | ";
					if (l === this.line) {
						if (f.length > 160) {
							let m = 20, p = Math.max(0, this.column - m), y = Math.max(this.column + m, this.endColumn + m), g = f.slice(p, y), v = r(d.replace(/\d/g, " ")) + f.slice(0, Math.min(this.column - 1, m - 1)).replace(/[^\t]/g, " ");
							return n(">") + r(d) + i(g) + `
 ` + v + n("^");
						}
						let x = r(d.replace(/\d/g, " ")) + f.slice(0, this.column - 1).replace(/[^\t]/g, " ");
						return n(">") + r(d) + i(f) + `
 ` + x + n("^");
					}
					return " " + r(d) + i(f);
				}).join(`
`);
			}
			toString() {
				let e = this.showSourceCode();
				return e && (e = `

` + e + `
`), this.name + ": " + this.message + e;
			}
		};
		ji.exports = ot;
		ot.default = ot;
	});
	Xt = w(($x, Qi) => {
		"use strict";
		var Zc = /(<)(\/?style\b)/gi, ef = /(<)(!--)/g;
		function fe(t) {
			return typeof t != "string" || !t.includes("<") ? t : t.replace(Zc, "\\3c $2").replace(ef, "\\3c $2");
		}
		var Hi = {
			after: `
`,
			beforeClose: `
`,
			beforeComment: `
`,
			beforeDecl: `
`,
			beforeOpen: " ",
			beforeRule: `
`,
			colon: ": ",
			commentLeft: " ",
			commentRight: " ",
			emptyBody: "",
			indent: "    ",
			semicolon: !1
		};
		function tf(t) {
			return t[0].toUpperCase() + t.slice(1);
		}
		var at = class {
			constructor(e) {
				this.builder = e;
			}
			atrule(e, s) {
				let r = e.raws, n = "@" + e.name, i = e.params ? this.rawValue(e, "params") : "";
				if (typeof r.afterName < "u" ? n += r.afterName : i && (n += " "), e.nodes) this.block(e, n + i);
				else {
					let o = (r.between || "") + (s ? ";" : "");
					this.builder(fe(n + i + o), e);
				}
			}
			beforeAfter(e, s) {
				let r;
				e.type === "decl" ? r = this.raw(e, null, "beforeDecl") : e.type === "comment" ? r = this.raw(e, null, "beforeComment") : s === "before" ? r = this.raw(e, null, "beforeRule") : r = this.raw(e, null, "beforeClose");
				let n = e.parent, i = 0;
				for (; n && n.type !== "root";) i += 1, n = n.parent;
				if (r.includes(`
`)) {
					let o = this.raw(e, null, "indent");
					if (o.length) for (let u = 0; u < i; u++) r += o;
				}
				return r;
			}
			block(e, s) {
				let r = this.raw(e, "between", "beforeOpen");
				this.builder(fe(s + r) + "{", e, "start");
				let n;
				e.nodes && e.nodes.length ? (this.body(e), n = this.raw(e, "after")) : n = this.raw(e, "after", "emptyBody"), n && this.builder(fe(n)), this.builder("}", e, "end");
			}
			body(e) {
				let s = e.nodes, r = s.length - 1;
				for (; r > 0 && s[r].type === "comment";) r -= 1;
				let n = this.raw(e, "semicolon"), i = e.type === "document";
				for (let o = 0; o < s.length; o++) {
					let u = s[o], a = this.raw(u, "before");
					a && this.builder(i ? a : fe(a)), this.stringify(u, r !== o || n);
				}
			}
			comment(e) {
				let s = this.raw(e, "left", "commentLeft"), r = this.raw(e, "right", "commentRight");
				this.builder(fe("/*" + s + e.text + r + "*/"), e);
			}
			decl(e, s) {
				let r = e.raws, n = this.raw(e, "between", "colon"), i = e.prop + n + this.rawValue(e, "value");
				e.important && (i += r.important || " !important"), s && (i += ";"), this.builder(fe(i), e);
			}
			document(e) {
				this.body(e);
			}
			raw(e, s, r) {
				let n;
				if (r || (r = s), s && (n = e.raws[s], typeof n < "u")) return n;
				let i = e.parent;
				if (r === "before" && (!i || i.type === "root" && i.first === e || i && i.type === "document")) return "";
				if (!i) return Hi[r];
				let o = e.root(), u = o.rawCache || (o.rawCache = {});
				if (typeof u[r] < "u") return u[r];
				if (r === "before" || r === "after") return this.beforeAfter(e, r);
				{
					let a = "raw" + tf(r);
					this[a] ? n = this[a](o, e) : o.walk((c) => {
						if (n = c.raws[s], typeof n < "u") return !1;
					});
				}
				return typeof n > "u" && (n = Hi[r]), u[r] = n, n;
			}
			rawBeforeClose(e) {
				let s;
				return e.walk((r) => {
					if (r.nodes && r.nodes.length > 0 && typeof r.raws.after < "u") return s = r.raws.after, s.includes(`
`) && (s = s.replace(/[^\n]+$/, "")), !1;
				}), s && (s = s.replace(/\S/g, "")), s;
			}
			rawBeforeComment(e, s) {
				let r;
				return e.walkComments((n) => {
					if (typeof n.raws.before < "u") return r = n.raws.before, r.includes(`
`) && (r = r.replace(/[^\n]+$/, "")), !1;
				}), typeof r > "u" ? r = this.raw(s, null, "beforeDecl") : r && (r = r.replace(/\S/g, "")), r;
			}
			rawBeforeDecl(e, s) {
				let r;
				return e.walkDecls((n) => {
					if (typeof n.raws.before < "u") return r = n.raws.before, r.includes(`
`) && (r = r.replace(/[^\n]+$/, "")), !1;
				}), typeof r > "u" ? r = this.raw(s, null, "beforeRule") : r && (r = r.replace(/\S/g, "")), r;
			}
			rawBeforeOpen(e) {
				let s;
				return e.walk((r) => {
					if (r.type !== "decl" && (s = r.raws.between, typeof s < "u")) return !1;
				}), s;
			}
			rawBeforeRule(e) {
				let s;
				return e.walk((r) => {
					if (r.nodes && (r.parent !== e || e.first !== r) && typeof r.raws.before < "u") return s = r.raws.before, s.includes(`
`) && (s = s.replace(/[^\n]+$/, "")), !1;
				}), s && (s = s.replace(/\S/g, "")), s;
			}
			rawColon(e) {
				let s;
				return e.walkDecls((r) => {
					if (typeof r.raws.between < "u") return s = r.raws.between.replace(/[^\s:]/g, ""), !1;
				}), s;
			}
			rawEmptyBody(e) {
				let s;
				return e.walk((r) => {
					if (r.nodes && r.nodes.length === 0 && (s = r.raws.after, typeof s < "u")) return !1;
				}), s;
			}
			rawIndent(e) {
				if (e.raws.indent) return e.raws.indent;
				let s;
				return e.walk((r) => {
					let n = r.parent;
					if (n && n !== e && n.parent && n.parent === e && typeof r.raws.before < "u") {
						let i = r.raws.before.split(`
`);
						return s = i[i.length - 1], s = s.replace(/\S/g, ""), !1;
					}
				}), s;
			}
			rawSemicolon(e) {
				let s;
				return e.walk((r) => {
					if (r.nodes && r.nodes.length && r.last.type === "decl" && (s = r.raws.semicolon, typeof s < "u")) return !1;
				}), s;
			}
			rawValue(e, s) {
				let r = e[s], n = e.raws[s];
				return n && n.value === r ? n.raw : r;
			}
			root(e) {
				if (this.body(e), e.raws.after) {
					let s = e.raws.after, r = e.parent && e.parent.type === "document";
					this.builder(r ? s : fe(s));
				}
			}
			rule(e) {
				this.block(e, this.rawValue(e, "selector")), e.raws.ownSemicolon && this.builder(fe(e.raws.ownSemicolon), e, "end");
			}
			stringify(e, s) {
				if (!this[e.type]) throw new Error("Unknown AST node type " + e.type + ". Maybe you need to change PostCSS stringifier.");
				this[e.type](e, s);
			}
		};
		Qi.exports = at;
		at.default = at;
	});
	ut = w((Gx, Ki) => {
		"use strict";
		var rf = Xt();
		function ys(t, e) {
			new rf(e).stringify(t);
		}
		Ki.exports = ys;
		ys.default = ys;
	});
	Jt = w((Yx, gs) => {
		"use strict";
		gs.exports.isClean = Symbol("isClean");
		gs.exports.my = Symbol("my");
	});
	ft = w((Vx, Xi) => {
		"use strict";
		var sf = Kt(), nf = Xt(), of = ut(), { isClean: lt, my: af } = Jt();
		function ws(t, e) {
			let s = new t.constructor();
			for (let r in t) {
				if (!Object.prototype.hasOwnProperty.call(t, r) || r === "proxyCache") continue;
				let n = t[r], i = typeof n;
				r === "parent" && i === "object" ? e && (s[r] = e) : r === "source" ? s[r] = n : Array.isArray(n) ? s[r] = n.map((o) => ws(o, s)) : (i === "object" && n !== null && (n = ws(n)), s[r] = n);
			}
			return s;
		}
		function J(t, e) {
			if (e && typeof e.offset < "u") return e.offset;
			let s = 1, r = 1, n = 0;
			for (let i = 0; i < t.length; i++) {
				if (r === e.line && s === e.column) {
					n = i;
					break;
				}
				t[i] === `
` ? (s = 1, r += 1) : s += 1;
			}
			return n;
		}
		var ct = class {
			get proxyOf() {
				return this;
			}
			constructor(e = {}) {
				this.raws = {}, this[lt] = !1, this[af] = !0;
				for (let s in e) if (s === "nodes") {
					this.nodes = [];
					for (let r of e[s]) typeof r.clone == "function" && r.parent ? this.append(r.clone()) : this.append(r);
				} else this[s] = e[s];
			}
			addToError(e) {
				if (e.postcssNode = this, e.stack && this.source && /\n\s{4}at /.test(e.stack)) {
					let s = this.source;
					e.stack = e.stack.replace(/\n\s{4}at /, `$&${s.input.from}:${s.start.line}:${s.start.column}$&`);
				}
				return e;
			}
			after(e) {
				return this.parent.insertAfter(this, e), this;
			}
			assign(e = {}) {
				for (let s in e) this[s] = e[s];
				return this;
			}
			before(e) {
				return this.parent.insertBefore(this, e), this;
			}
			cleanRaws(e) {
				delete this.raws.before, delete this.raws.after, e || delete this.raws.between;
			}
			clone(e = {}) {
				let s = ws(this);
				for (let r in e) s[r] = e[r];
				return s;
			}
			cloneAfter(e = {}) {
				let s = this.clone(e);
				return this.parent.insertAfter(this, s), s;
			}
			cloneBefore(e = {}) {
				let s = this.clone(e);
				return this.parent.insertBefore(this, s), s;
			}
			error(e, s = {}) {
				if (this.source) {
					let { end: r, start: n } = this.rangeBy(s);
					return this.source.input.error(e, {
						column: n.column,
						line: n.line
					}, {
						column: r.column,
						line: r.line
					}, s);
				}
				return new sf(e);
			}
			getProxyProcessor() {
				return {
					get(e, s) {
						return s === "proxyOf" ? e : s === "root" ? () => e.root().toProxy() : e[s];
					},
					set(e, s, r) {
						return e[s] === r || (e[s] = r, (s === "prop" || s === "value" || s === "name" || s === "params" || s === "important" || s === "text") && e.markDirty()), !0;
					}
				};
			}
			markClean() {
				this[lt] = !0;
			}
			markDirty() {
				if (this[lt]) {
					this[lt] = !1;
					let e = this;
					for (; e = e.parent;) e[lt] = !1;
				}
			}
			next() {
				if (!this.parent) return;
				let e = this.parent.index(this);
				return this.parent.nodes[e + 1];
			}
			positionBy(e = {}) {
				let s = "document" in this.source.input ? this.source.input.document : this.source.input.css, r = {
					column: this.source.start.column,
					line: this.source.start.line,
					offset: J(s, this.source.start)
				};
				if (e.index) r = this.positionInside(e.index);
				else if (e.word) {
					let i = s.slice(J(s, this.source.start), J(s, this.source.end)).indexOf(e.word);
					i !== -1 && (r = this.positionInside(i));
				}
				return r;
			}
			positionInside(e) {
				let s = this.source.start.column, r = this.source.start.line, n = "document" in this.source.input ? this.source.input.document : this.source.input.css, i = J(n, this.source.start), o = i + e;
				for (let u = i; u < o; u++) n[u] === `
` ? (s = 1, r += 1) : s += 1;
				return {
					column: s,
					line: r,
					offset: o
				};
			}
			prev() {
				if (!this.parent) return;
				let e = this.parent.index(this);
				return this.parent.nodes[e - 1];
			}
			rangeBy(e = {}) {
				let s = "document" in this.source.input ? this.source.input.document : this.source.input.css, r = {
					column: this.source.start.column,
					line: this.source.start.line,
					offset: J(s, this.source.start)
				}, n = this.source.end ? {
					column: this.source.end.column + 1,
					line: this.source.end.line,
					offset: typeof this.source.end.offset == "number" ? this.source.end.offset : J(s, this.source.end) + 1
				} : {
					column: r.column + 1,
					line: r.line,
					offset: r.offset + 1
				};
				if (e.word) {
					let o = s.slice(J(s, this.source.start), J(s, this.source.end)).indexOf(e.word);
					o !== -1 && (r = this.positionInside(o), n = this.positionInside(o + e.word.length));
				} else e.start ? r = {
					column: e.start.column,
					line: e.start.line,
					offset: J(s, e.start)
				} : typeof e.index == "number" && (r = this.positionInside(e.index)), e.end ? n = {
					column: e.end.column,
					line: e.end.line,
					offset: J(s, e.end)
				} : typeof e.endIndex == "number" ? n = this.positionInside(e.endIndex) : typeof e.index == "number" && (n = this.positionInside(e.index + 1));
				return (n.line < r.line || n.line === r.line && n.column <= r.column) && (n = {
					column: r.column + 1,
					line: r.line,
					offset: r.offset + 1
				}), {
					end: n,
					start: r
				};
			}
			raw(e, s) {
				return new nf().raw(this, e, s);
			}
			remove() {
				return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
			}
			replaceWith(...e) {
				if (this.parent) {
					let s = this, r = !1;
					for (let n of e) n === this ? r = !0 : r ? (this.parent.insertAfter(s, n), s = n) : this.parent.insertBefore(s, n);
					r || this.remove();
				}
				return this;
			}
			root() {
				let e = this;
				for (; e.parent && e.parent.type !== "document";) e = e.parent;
				return e;
			}
			toJSON(e, s) {
				let r = {}, n = s == null;
				s = s || /* @__PURE__ */ new Map();
				let i = 0;
				for (let o in this) {
					if (!Object.prototype.hasOwnProperty.call(this, o) || o === "parent" || o === "proxyCache") continue;
					let u = this[o];
					if (Array.isArray(u)) r[o] = u.map((a) => typeof a == "object" && a.toJSON ? a.toJSON(null, s) : a);
					else if (typeof u == "object" && u.toJSON) r[o] = u.toJSON(null, s);
					else if (o === "source") {
						if (u == null) continue;
						let a = s.get(u.input);
						a ?? (a = i, s.set(u.input, i), i++), r[o] = {
							end: u.end,
							inputId: a,
							start: u.start
						};
					} else r[o] = u;
				}
				return n && (r.inputs = [...s.keys()].map((o) => o.toJSON())), r;
			}
			toProxy() {
				return this.proxyCache || (this.proxyCache = new Proxy(this, this.getProxyProcessor())), this.proxyCache;
			}
			toString(e = of) {
				e.stringify && (e = e.stringify);
				let s = "";
				return e(this, (r) => {
					s += r;
				}), s;
			}
			warn(e, s, r = {}) {
				let n = { node: this };
				for (let i in r) n[i] = r[i];
				return e.warn(s, n);
			}
		};
		Xi.exports = ct;
		ct.default = ct;
	});
	Fe = w((zx, Ji) => {
		"use strict";
		var uf = ft(), pt = class extends uf {
			constructor(e) {
				super(e), this.type = "comment";
			}
		};
		Ji.exports = pt;
		pt.default = pt;
	});
	mt = w((jx, Zi) => {
		"use strict";
		var lf = ft(), ht = class extends lf {
			get variable() {
				return this.prop.startsWith("--") || this.prop[0] === "$";
			}
			constructor(e) {
				e && typeof e.value < "u" && typeof e.value != "string" && (e = {
					...e,
					value: String(e.value)
				}), super(e), this.type = "decl";
			}
		};
		Zi.exports = ht;
		ht.default = ht;
	});
	pe = w((Hx, uo) => {
		"use strict";
		var eo = Fe(), to = mt(), cf = ft(), { isClean: ro, my: so } = Jt(), vs, no, io, xs;
		function oo(t) {
			return t.map((e) => (e.nodes && (e.nodes = oo(e.nodes)), delete e.source, e));
		}
		function ao(t) {
			if (t[ro] = !1, t.proxyOf.nodes) for (let e of t.proxyOf.nodes) ao(e);
		}
		var z = class t extends cf {
			get first() {
				if (this.proxyOf.nodes) return this.proxyOf.nodes[0];
			}
			get last() {
				if (this.proxyOf.nodes) return this.proxyOf.nodes[this.proxyOf.nodes.length - 1];
			}
			append(...e) {
				for (let s of e) {
					let r = this.normalize(s, this.last);
					for (let n of r) this.proxyOf.nodes.push(n);
				}
				return this.markDirty(), this;
			}
			cleanRaws(e) {
				if (super.cleanRaws(e), this.nodes) for (let s of this.nodes) s.cleanRaws(e);
			}
			each(e) {
				if (!this.proxyOf.nodes) return;
				let s = this.getIterator(), r, n;
				for (; this.indexes[s] < this.proxyOf.nodes.length && (r = this.indexes[s], n = e(this.proxyOf.nodes[r], r), n !== !1);) this.indexes[s] += 1;
				return delete this.indexes[s], n;
			}
			every(e) {
				return this.nodes.every(e);
			}
			getIterator() {
				this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach += 1;
				let e = this.lastEach;
				return this.indexes[e] = 0, e;
			}
			getProxyProcessor() {
				return {
					get(e, s) {
						return s === "proxyOf" ? e : e[s] ? s === "each" || typeof s == "string" && s.startsWith("walk") ? (...r) => e[s](...r.map((n) => typeof n == "function" ? (i, o) => n(i.toProxy(), o) : n)) : s === "every" || s === "some" ? (r) => e[s]((n, ...i) => r(n.toProxy(), ...i)) : s === "root" ? () => e.root().toProxy() : s === "nodes" ? e.nodes.map((r) => r.toProxy()) : s === "first" || s === "last" ? e[s].toProxy() : e[s] : e[s];
					},
					set(e, s, r) {
						return e[s] === r || (e[s] = r, (s === "name" || s === "params" || s === "selector") && e.markDirty()), !0;
					}
				};
			}
			index(e) {
				return typeof e == "number" ? e : (e.proxyOf && (e = e.proxyOf), this.proxyOf.nodes.indexOf(e));
			}
			insertAfter(e, s) {
				let r = this.index(e), n = this.normalize(s, this.proxyOf.nodes[r]).reverse();
				r = this.index(e);
				for (let o of n) this.proxyOf.nodes.splice(r + 1, 0, o);
				let i;
				for (let o in this.indexes) i = this.indexes[o], r < i && (this.indexes[o] = i + n.length);
				return this.markDirty(), this;
			}
			insertBefore(e, s) {
				let r = this.index(e), n = r === 0 ? "prepend" : !1, i = this.normalize(s, this.proxyOf.nodes[r], n).reverse();
				r = this.index(e);
				for (let u of i) this.proxyOf.nodes.splice(r, 0, u);
				let o;
				for (let u in this.indexes) o = this.indexes[u], r <= o && (this.indexes[u] = o + i.length);
				return this.markDirty(), this;
			}
			normalize(e, s) {
				if (typeof e == "string") e = oo(no(e).nodes);
				else if (typeof e > "u") e = [];
				else if (Array.isArray(e)) {
					e = e.slice(0);
					for (let n of e) n.parent && n.parent.removeChild(n, "ignore");
				} else if (e.type === "root" && this.type !== "document") {
					e = e.nodes.slice(0);
					for (let n of e) n.parent && n.parent.removeChild(n, "ignore");
				} else if (e.type) e = [e];
				else if (e.prop) {
					if (typeof e.value > "u") throw new Error("Value field is missed in node creation");
					typeof e.value != "string" && (e.value = String(e.value)), e = [new to(e)];
				} else if (e.selector || e.selectors) e = [new xs(e)];
				else if (e.name) e = [new vs(e)];
				else if (e.text) e = [new eo(e)];
				else throw new Error("Unknown node type in node creation");
				return e.map((n) => (n[so] || t.rebuild(n), n = n.proxyOf, n.parent && n.parent.removeChild(n), n[ro] && ao(n), n.raws || (n.raws = {}), typeof n.raws.before > "u" && s && typeof s.raws.before < "u" && (n.raws.before = s.raws.before.replace(/\S/g, "")), n.parent = this.proxyOf, n));
			}
			prepend(...e) {
				e = e.reverse();
				for (let s of e) {
					let r = this.normalize(s, this.first, "prepend").reverse();
					for (let n of r) this.proxyOf.nodes.unshift(n);
					for (let n in this.indexes) this.indexes[n] = this.indexes[n] + r.length;
				}
				return this.markDirty(), this;
			}
			push(e) {
				return e.parent = this, this.proxyOf.nodes.push(e), this;
			}
			removeAll() {
				for (let e of this.proxyOf.nodes) e.parent = void 0;
				return this.proxyOf.nodes = [], this.markDirty(), this;
			}
			removeChild(e) {
				e = this.index(e), this.proxyOf.nodes[e].parent = void 0, this.proxyOf.nodes.splice(e, 1);
				let s;
				for (let r in this.indexes) s = this.indexes[r], s >= e && (this.indexes[r] = s - 1);
				return this.markDirty(), this;
			}
			replaceValues(e, s, r) {
				return r || (r = s, s = {}), this.walkDecls((n) => {
					s.props && !s.props.includes(n.prop) || s.fast && !n.value.includes(s.fast) || (n.value = n.value.replace(e, r));
				}), this.markDirty(), this;
			}
			some(e) {
				return this.nodes.some(e);
			}
			walk(e) {
				return this.each((s, r) => {
					let n;
					try {
						n = e(s, r);
					} catch (i) {
						throw s.addToError(i);
					}
					return n !== !1 && s.walk && (n = s.walk(e)), n;
				});
			}
			walkAtRules(e, s) {
				return s ? e instanceof RegExp ? this.walk((r, n) => {
					if (r.type === "atrule" && e.test(r.name)) return s(r, n);
				}) : this.walk((r, n) => {
					if (r.type === "atrule" && r.name === e) return s(r, n);
				}) : (s = e, this.walk((r, n) => {
					if (r.type === "atrule") return s(r, n);
				}));
			}
			walkComments(e) {
				return this.walk((s, r) => {
					if (s.type === "comment") return e(s, r);
				});
			}
			walkDecls(e, s) {
				return s ? e instanceof RegExp ? this.walk((r, n) => {
					if (r.type === "decl" && e.test(r.prop)) return s(r, n);
				}) : this.walk((r, n) => {
					if (r.type === "decl" && r.prop === e) return s(r, n);
				}) : (s = e, this.walk((r, n) => {
					if (r.type === "decl") return s(r, n);
				}));
			}
			walkRules(e, s) {
				return s ? e instanceof RegExp ? this.walk((r, n) => {
					if (r.type === "rule" && e.test(r.selector)) return s(r, n);
				}) : this.walk((r, n) => {
					if (r.type === "rule" && r.selector === e) return s(r, n);
				}) : (s = e, this.walk((r, n) => {
					if (r.type === "rule") return s(r, n);
				}));
			}
		};
		z.registerParse = (t) => {
			no = t;
		};
		z.registerRule = (t) => {
			xs = t;
		};
		z.registerAtRule = (t) => {
			vs = t;
		};
		z.registerRoot = (t) => {
			io = t;
		};
		uo.exports = z;
		z.default = z;
		z.rebuild = (t) => {
			t.type === "atrule" ? Object.setPrototypeOf(t, vs.prototype) : t.type === "rule" ? Object.setPrototypeOf(t, xs.prototype) : t.type === "decl" ? Object.setPrototypeOf(t, to.prototype) : t.type === "comment" ? Object.setPrototypeOf(t, eo.prototype) : t.type === "root" && Object.setPrototypeOf(t, io.prototype), t[so] = !0, t.nodes && t.nodes.forEach((e) => {
				z.rebuild(e);
			});
		};
	});
	co = w((Qx, lo) => {
		var ff = "useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict", pf = (t, e = 21) => (s = e) => {
			let r = "", n = s | 0;
			for (; n--;) r += t[Math.random() * t.length | 0];
			return r;
		}, hf = (t = 21) => {
			let e = "", s = t | 0;
			for (; s--;) e += ff[Math.random() * 64 | 0];
			return e;
		};
		lo.exports = {
			nanoid: hf,
			customAlphabet: pf
		};
	});
	fo = w(() => {});
	_s = w((Jx, po) => {
		po.exports = class {};
	});
	$e = w((e_, wo) => {
		"use strict";
		var { nanoid: mf } = co(), { isAbsolute: Ss, resolve: Ts } = {}, { SourceMapConsumer: df, SourceMapGenerator: yf } = fo(), { fileURLToPath: ho, pathToFileURL: Zt } = {}, mo = Kt(), gf = _s(), bs = ds(), Es = Symbol("lineToIndexCache"), wf = !!(df && yf), yo = !!(Ts && Ss);
		function go(t) {
			if (t[Es]) return t[Es];
			let e = t.css.split(`
`), s = new Array(e.length), r = 0;
			for (let n = 0, i = e.length; n < i; n++) s[n] = r, r += e[n].length + 1;
			return t[Es] = s, s;
		}
		var We = class {
			get from() {
				return this.file || this.id;
			}
			constructor(e, s = {}) {
				if (e === null || typeof e > "u" || typeof e == "object" && !e.toString) throw new Error(`PostCSS received ${e} instead of CSS string`);
				if (this.css = e.toString(), this.css[0] === "﻿" || this.css[0] === "" ? (this.hasBOM = !0, this.css = this.css.slice(1)) : this.hasBOM = !1, this.document = this.css, s.document && (this.document = s.document.toString()), s.from && (!yo || /^\w+:\/\//.test(s.from) || Ss(s.from) ? this.file = s.from : this.file = Ts(s.from)), yo && wf) {
					let r = new gf(this.css, s);
					if (r.text) {
						this.map = r;
						let n = r.consumer().file;
						!this.file && n && (this.file = this.mapResolve(n));
					}
				}
				this.file || (this.id = "<input css " + mf(6) + ">"), this.map && (this.map.file = this.from);
			}
			error(e, s, r, n = {}) {
				let i, o, u, a, c;
				if (s && typeof s == "object") {
					let h = s, l = r;
					if (typeof h.offset == "number") {
						a = h.offset;
						let d = this.fromOffset(a);
						s = d.line, r = d.col;
					} else s = h.line, r = h.column, a = this.fromLineAndColumn(s, r);
					if (typeof l.offset == "number") {
						u = l.offset;
						let d = this.fromOffset(u);
						o = d.line, i = d.col;
					} else o = l.line, i = l.column, u = this.fromLineAndColumn(l.line, l.column);
				} else if (r) a = this.fromLineAndColumn(s, r);
				else {
					a = s;
					let h = this.fromOffset(a);
					s = h.line, r = h.col;
				}
				let f = this.origin(s, r, o, i);
				return f ? c = new mo(e, f.endLine === void 0 ? f.line : {
					column: f.column,
					line: f.line
				}, f.endLine === void 0 ? f.column : {
					column: f.endColumn,
					line: f.endLine
				}, f.source, f.file, n.plugin) : c = new mo(e, o === void 0 ? s : {
					column: r,
					line: s
				}, o === void 0 ? r : {
					column: i,
					line: o
				}, this.css, this.file, n.plugin), c.input = {
					column: r,
					endColumn: i,
					endLine: o,
					endOffset: u,
					line: s,
					offset: a,
					source: this.css
				}, this.file && (Zt && (c.input.url = Zt(this.file).toString()), c.input.file = this.file), c;
			}
			fromLineAndColumn(e, s) {
				return go(this)[e - 1] + s - 1;
			}
			fromOffset(e) {
				let s = go(this), r = s[s.length - 1], n = 0;
				if (e >= r) n = s.length - 1;
				else {
					let i = s.length - 2, o;
					for (; n < i;) if (o = n + (i - n >> 1), e < s[o]) i = o - 1;
					else if (e >= s[o + 1]) n = o + 1;
					else {
						n = o;
						break;
					}
				}
				return {
					col: e - s[n] + 1,
					line: n + 1
				};
			}
			mapResolve(e) {
				return /^\w+:\/\//.test(e) ? e : Ts(this.map.consumer().sourceRoot || this.map.root || ".", e);
			}
			origin(e, s, r, n) {
				if (!this.map) return !1;
				let i = this.map.consumer(), o = i.originalPositionFor({
					column: s - 1,
					line: e
				});
				if (!o.source) return !1;
				let u;
				typeof r == "number" && (u = i.originalPositionFor({
					column: n - 1,
					line: r
				}));
				let a;
				Ss(o.source) ? a = Zt(o.source) : a = new URL(o.source, this.map.consumer().sourceRoot || Zt(this.map.mapFile));
				let c = {
					column: o.column + 1,
					endColumn: u && u.column + 1,
					endLine: u && u.line,
					line: o.line,
					url: a.toString()
				};
				if (a.protocol === "file:") if (ho) c.file = ho(a);
				else throw new Error("file: protocol is not available in this PostCSS build");
				let f = i.sourceContentFor(o.source);
				return f && (c.source = f), c;
			}
			toJSON() {
				let e = {};
				for (let s of [
					"hasBOM",
					"css",
					"file",
					"id"
				]) this[s] != null && (e[s] = this[s]);
				return this.map && (e.map = { ...this.map }, e.map.consumerCache && (e.map.consumerCache = void 0)), e;
			}
		};
		wo.exports = We;
		We.default = We;
		bs && bs.registerInput && bs.registerInput(We);
	});
	er = w((t_, xo) => {
		"use strict";
		var vo = pe(), Ge = class extends vo {
			constructor(e) {
				super(e), this.type = "atrule";
			}
			append(...e) {
				return this.proxyOf.nodes || (this.nodes = []), super.append(...e);
			}
			prepend(...e) {
				return this.proxyOf.nodes || (this.nodes = []), super.prepend(...e);
			}
		};
		xo.exports = Ge;
		Ge.default = Ge;
		vo.registerAtRule(Ge);
	});
	Ye = w((r_, So) => {
		"use strict";
		var _o = pe(), bo, Eo, he = class extends _o {
			constructor(e) {
				super(e), this.type = "root", this.nodes || (this.nodes = []);
			}
			normalize(e, s, r) {
				let n = super.normalize(e);
				if (s) {
					if (r === "prepend") this.nodes.length > 1 ? s.raws.before = this.nodes[1].raws.before : delete s.raws.before;
					else if (this.first !== s) for (let i of n) i.raws.before = s.raws.before;
				}
				return n;
			}
			removeChild(e, s) {
				let r = this.index(e);
				return !s && r === 0 && this.nodes.length > 1 && (this.nodes[1].raws.before = this.nodes[r].raws.before), super.removeChild(e);
			}
			toResult(e = {}) {
				return new bo(new Eo(), this, e).stringify();
			}
		};
		he.registerLazyResult = (t) => {
			bo = t;
		};
		he.registerProcessor = (t) => {
			Eo = t;
		};
		So.exports = he;
		he.default = he;
		_o.registerRoot(he);
	});
	ks = w((s_, To) => {
		"use strict";
		var dt = {
			comma(t) {
				return dt.split(t, [","], !0);
			},
			space(t) {
				return dt.split(t, [
					" ",
					`
`,
					"	"
				]);
			},
			split(t, e, s) {
				let r = [], n = "", i = !1, o = 0, u = !1, a = "", c = !1;
				for (let f of t) c ? c = !1 : f === "\\" ? c = !0 : u ? f === a && (u = !1) : f === "\"" || f === "'" ? (u = !0, a = f) : f === "(" ? o += 1 : f === ")" ? o > 0 && (o -= 1) : o === 0 && e.includes(f) && (i = !0), i ? (n !== "" && r.push(n.trim()), n = "", i = !1) : n += f;
				return (s || n !== "") && r.push(n.trim()), r;
			}
		};
		To.exports = dt;
		dt.default = dt;
	});
	tr = w((n_, Oo) => {
		"use strict";
		var ko = pe(), vf = ks(), Ve = class extends ko {
			get selectors() {
				return vf.comma(this.selector);
			}
			set selectors(e) {
				let s = this.selector ? this.selector.match(/,\s*/) : null, r = s ? s[0] : "," + this.raw("between", "beforeOpen");
				this.selector = e.join(r);
			}
			constructor(e) {
				super(e), this.type = "rule", this.nodes || (this.nodes = []);
			}
		};
		Oo.exports = Ve;
		Ve.default = Ve;
		ko.registerRule(Ve);
	});
	nr = w((i_, Co) => {
		"use strict";
		var rr = /[\t\n\f\r "#'()/;[\\\]{}]/g, sr = /[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g, xf = /.[\r\n"'(/\\]/, Ao = /[\da-f]/i;
		Co.exports = function(e, s = {}) {
			let r = e.css.valueOf(), n = s.ignoreErrors, i, o, u, a, c, f, h, l, d, x, m = r.length, p = 0, y = [], g = [], v = -1;
			function C() {
				return p;
			}
			function q(k) {
				throw e.error("Unclosed " + k, p);
			}
			function W() {
				return g.length === 0 && p >= m;
			}
			function se(k) {
				if (g.length) return g.pop();
				if (p >= m) return;
				let b = k ? k.ignoreUnclosed : !1;
				switch (i = r.charCodeAt(p), i) {
					case 10:
					case 32:
					case 9:
					case 13:
					case 12:
						a = p;
						do
							a += 1, i = r.charCodeAt(a);
						while (i === 32 || i === 10 || i === 9 || i === 13 || i === 12);
						f = ["space", r.slice(p, a)], p = a - 1;
						break;
					case 91:
					case 93:
					case 123:
					case 125:
					case 58:
					case 59:
					case 41: {
						let S = String.fromCharCode(i);
						f = [
							S,
							S,
							p
						];
						break;
					}
					case 40:
						if (x = y.length ? y.pop()[1] : "", d = r.charCodeAt(p + 1), x === "url" && d !== 39 && d !== 34 && d !== 32 && d !== 10 && d !== 9 && d !== 12 && d !== 13) {
							a = p;
							do {
								if (h = !1, a = r.indexOf(")", a + 1), a === -1) if (n || b) {
									a = p;
									break;
								} else q("bracket");
								for (l = a; r.charCodeAt(l - 1) === 92;) l -= 1, h = !h;
							} while (h);
							f = [
								"brackets",
								r.slice(p, a + 1),
								p,
								a
							], p = a;
						} else p <= v ? f = [
							"(",
							"(",
							p
						] : (a = r.indexOf(")", p + 1), o = r.slice(p, a + 1), a === -1 || xf.test(o) ? (v = a === -1 ? m : a, f = [
							"(",
							"(",
							p
						]) : (f = [
							"brackets",
							o,
							p,
							a
						], p = a));
						break;
					case 39:
					case 34:
						c = i === 39 ? "'" : "\"", a = p;
						do {
							if (h = !1, a = r.indexOf(c, a + 1), a === -1) if (n || b) {
								a = p + 1;
								break;
							} else q("string");
							for (l = a; r.charCodeAt(l - 1) === 92;) l -= 1, h = !h;
						} while (h);
						f = [
							"string",
							r.slice(p, a + 1),
							p,
							a
						], p = a;
						break;
					case 64:
						rr.lastIndex = p + 1, rr.test(r), rr.lastIndex === 0 ? a = r.length - 1 : a = rr.lastIndex - 2, f = [
							"at-word",
							r.slice(p, a + 1),
							p,
							a
						], p = a;
						break;
					case 92:
						for (a = p, u = !0; r.charCodeAt(a + 1) === 92;) a += 1, u = !u;
						if (i = r.charCodeAt(a + 1), u && i !== 47 && i !== 32 && i !== 10 && i !== 9 && i !== 13 && i !== 12 && (a += 1, Ao.test(r.charAt(a)))) {
							for (; Ao.test(r.charAt(a + 1));) a += 1;
							r.charCodeAt(a + 1) === 32 && (a += 1);
						}
						f = [
							"word",
							r.slice(p, a + 1),
							p,
							a
						], p = a;
						break;
					default:
						i === 47 && r.charCodeAt(p + 1) === 42 ? (a = r.indexOf("*/", p + 2) + 1, a === 0 && (n || b ? a = r.length : q("comment")), f = [
							"comment",
							r.slice(p, a + 1),
							p,
							a
						], p = a) : (sr.lastIndex = p + 1, sr.test(r), sr.lastIndex === 0 ? a = r.length - 1 : a = sr.lastIndex - 2, f = [
							"word",
							r.slice(p, a + 1),
							p,
							a
						], y.push(f), p = a);
						break;
				}
				return p++, f;
			}
			function ye(k) {
				g.push(k);
			}
			return {
				back: ye,
				endOfFile: W,
				nextToken: se,
				position: C
			};
		};
	});
	ir = w((o_, Ro) => {
		"use strict";
		var _f = er(), bf = Fe(), Ef = mt(), Sf = Ye(), No = tr(), Tf = nr(), Po = {
			empty: !0,
			space: !0
		};
		function kf(t) {
			for (let e = t.length - 1; e >= 0; e--) {
				let s = t[e], r = s[3] || s[2];
				if (r) return r;
			}
		}
		function Os(t, e, s) {
			let r = "";
			for (let n = e; n < s; n++) r += t[n][1];
			return r;
		}
		var As = class {
			constructor(e) {
				this.input = e, this.root = new Sf(), this.current = this.root, this.spaces = "", this.semicolon = !1, this.createTokenizer(), this.root.source = {
					input: e,
					start: {
						column: 1,
						line: 1,
						offset: 0
					}
				};
			}
			atrule(e) {
				let s = new _f();
				s.name = e[1].slice(1), s.name === "" && this.unnamedAtrule(s, e), this.init(s, e[2]);
				let r, n, i, o = !1, u = !1, a = [], c = [];
				for (; !this.tokenizer.endOfFile();) {
					if (e = this.tokenizer.nextToken(), r = e[0], r === "(" || r === "[" ? c.push(r === "(" ? ")" : "]") : r === "{" && c.length > 0 ? c.push("}") : r === c[c.length - 1] && c.pop(), c.length === 0) if (r === ";") {
						s.source.end = this.getPosition(e[2]), s.source.end.offset++, this.semicolon = !0;
						break;
					} else if (r === "{") {
						u = !0;
						break;
					} else if (r === "}") {
						if (a.length > 0) {
							for (i = a.length - 1, n = a[i]; n && n[0] === "space";) n = a[--i];
							n && (s.source.end = this.getPosition(n[3] || n[2]), s.source.end.offset++);
						}
						this.end(e);
						break;
					} else a.push(e);
					else a.push(e);
					if (this.tokenizer.endOfFile()) {
						o = !0;
						break;
					}
				}
				s.raws.between = this.spacesAndCommentsFromEnd(a), a.length ? (s.raws.afterName = this.spacesAndCommentsFromStart(a), this.raw(s, "params", a), o && (e = a[a.length - 1], s.source.end = this.getPosition(e[3] || e[2]), s.source.end.offset++, this.spaces = s.raws.between, s.raws.between = "")) : (s.raws.afterName = "", s.params = ""), u && (s.nodes = [], this.current = s);
			}
			checkMissedSemicolon(e) {
				let s = this.colon(e);
				if (s === !1) return;
				let r = 0, n;
				for (let i = s - 1; i >= 0 && (n = e[i], !(n[0] !== "space" && (r += 1, r === 2))); i--);
				throw this.input.error("Missed semicolon", n[0] === "word" ? n[3] + 1 : n[2]);
			}
			colon(e) {
				let s = 0, r, n, i;
				for (let [o, u] of e.entries()) {
					if (n = u, i = n[0], i === "(" && (s += 1), i === ")" && (s -= 1), s === 0 && i === ":") if (!r) this.doubleColon(n);
					else {
						if (r[0] === "word" && r[1] === "progid") continue;
						return o;
					}
					r = n;
				}
				return !1;
			}
			comment(e) {
				let s = new bf();
				this.init(s, e[2]), s.source.end = this.getPosition(e[3] || e[2]), s.source.end.offset++;
				let r = e[1].slice(2, -2);
				if (!r.trim()) s.text = "", s.raws.left = r, s.raws.right = "";
				else {
					let n = r.match(/^(\s*)([^]*\S)(\s*)$/);
					s.text = n[2], s.raws.left = n[1], s.raws.right = n[3];
				}
			}
			createTokenizer() {
				this.tokenizer = Tf(this.input);
			}
			decl(e, s) {
				let r = new Ef();
				this.init(r, e[0][2]);
				let n = e[e.length - 1];
				n[0] === ";" && (this.semicolon = !0, e.pop()), r.source.end = this.getPosition(n[3] || n[2] || kf(e)), r.source.end.offset++;
				let i = 0;
				for (; e[i][0] !== "word";) i === e.length - 1 && this.unknownWord([e[i]]), i++;
				r.raws.before += Os(e, 0, i), r.source.start = this.getPosition(e[i][2]);
				let o = i;
				for (; i < e.length;) {
					let l = e[i][0];
					if (l === ":" || l === "space" || l === "comment") break;
					i++;
				}
				r.prop = Os(e, o, i);
				let u = i, a;
				for (; i < e.length && (a = e[i], i++, a[0] !== ":");) a[0] === "word" && /\w/.test(a[1]) && this.unknownWord([a]);
				r.raws.between = Os(e, u, i), (r.prop[0] === "_" || r.prop[0] === "*") && (r.raws.before += r.prop[0], r.prop = r.prop.slice(1));
				let c = i;
				for (; i < e.length;) {
					let l = e[i][0];
					if (l !== "space" && l !== "comment") break;
					i++;
				}
				let f = e.slice(c, i);
				e = e.slice(i), this.precheckMissedSemicolon(e);
				for (let l = e.length - 1; l >= 0; l--) {
					if (a = e[l], a[1].toLowerCase() === "!important") {
						r.important = !0;
						let d = this.stringFrom(e, l);
						d = this.spacesFromEnd(e) + d, d !== " !important" && (r.raws.important = d);
						break;
					} else if (a[1].toLowerCase() === "important") {
						let d = e.slice(0), x = "";
						for (let m = l; m > 0; m--) {
							let p = d[m][0];
							if (x.trim().startsWith("!") && p !== "space") break;
							x = d.pop()[1] + x;
						}
						x.trim().startsWith("!") && (r.important = !0, r.raws.important = x, e = d);
					}
					if (a[0] !== "space" && a[0] !== "comment") break;
				}
				e.some((l) => l[0] !== "space" && l[0] !== "comment") && (r.raws.between += f.map((l) => l[1]).join(""), f = []), this.raw(r, "value", f.concat(e), s), r.value.includes(":") && !s && this.checkMissedSemicolon(e);
			}
			doubleColon(e) {
				throw this.input.error("Double colon", { offset: e[2] }, { offset: e[2] + e[1].length });
			}
			emptyRule(e) {
				let s = new No();
				this.init(s, e[2]), s.selector = "", s.raws.between = "", this.current = s;
			}
			end(e) {
				this.current.nodes && this.current.nodes.length && (this.current.raws.semicolon = this.semicolon), this.semicolon = !1, this.current.raws.after = (this.current.raws.after || "") + this.spaces, this.spaces = "", this.current.parent ? (this.current.source.end = this.getPosition(e[2]), this.current.source.end.offset++, this.current = this.current.parent) : this.unexpectedClose(e);
			}
			endFile() {
				this.current.parent && this.unclosedBlock(), this.current.nodes && this.current.nodes.length && (this.current.raws.semicolon = this.semicolon), this.current.raws.after = (this.current.raws.after || "") + this.spaces, this.root.source.end = this.getPosition(this.tokenizer.position());
			}
			freeSemicolon(e) {
				if (this.spaces += e[1], this.current.nodes) {
					let s = this.current.nodes[this.current.nodes.length - 1];
					s && s.type === "rule" && !s.raws.ownSemicolon && (s.raws.ownSemicolon = this.spaces, this.spaces = "", s.source.end = this.getPosition(e[2]), s.source.end.offset += s.raws.ownSemicolon.length);
				}
			}
			getPosition(e) {
				let s = this.input.fromOffset(e);
				return {
					column: s.col,
					line: s.line,
					offset: e
				};
			}
			init(e, s) {
				this.current.push(e), e.source = {
					input: this.input,
					start: this.getPosition(s)
				}, e.raws.before = this.spaces, this.spaces = "", e.type !== "comment" && (this.semicolon = !1);
			}
			other(e) {
				let s = !1, r = null, n = !1, i = null, o = [], u = e[1].startsWith("--"), a = [], c = e;
				for (; c;) {
					if (r = c[0], a.push(c), r === "(" || r === "[") i || (i = c), o.push(r === "(" ? ")" : "]");
					else if (u && n && r === "{") i || (i = c), o.push("}");
					else if (o.length === 0) if (r === ";") if (n) {
						this.decl(a, u);
						return;
					} else break;
					else if (r === "{") {
						this.rule(a);
						return;
					} else if (r === "}") {
						this.tokenizer.back(a.pop()), s = !0;
						break;
					} else r === ":" && (n = !0);
					else r === o[o.length - 1] && (o.pop(), o.length === 0 && (i = null));
					c = this.tokenizer.nextToken();
				}
				if (this.tokenizer.endOfFile() && (s = !0), o.length > 0 && this.unclosedBracket(i), s && n) {
					if (!u) for (; a.length && (c = a[a.length - 1][0], !(c !== "space" && c !== "comment"));) this.tokenizer.back(a.pop());
					this.decl(a, u);
				} else this.unknownWord(a);
			}
			parse() {
				let e;
				for (; !this.tokenizer.endOfFile();) switch (e = this.tokenizer.nextToken(), e[0]) {
					case "space":
						this.spaces += e[1];
						break;
					case ";":
						this.freeSemicolon(e);
						break;
					case "}":
						this.end(e);
						break;
					case "comment":
						this.comment(e);
						break;
					case "at-word":
						this.atrule(e);
						break;
					case "{":
						this.emptyRule(e);
						break;
					default:
						this.other(e);
						break;
				}
				this.endFile();
			}
			precheckMissedSemicolon() {}
			raw(e, s, r, n) {
				let i, o, u = r.length, a = "", c = !0, f, h;
				for (let l = 0; l < u; l += 1) i = r[l], o = i[0], o === "space" && l === u - 1 && !n ? c = !1 : o === "comment" ? (h = r[l - 1] ? r[l - 1][0] : "empty", f = r[l + 1] ? r[l + 1][0] : "empty", !Po[h] && !Po[f] ? a.slice(-1) === "," ? c = !1 : a += i[1] : c = !1) : a += i[1];
				if (!c) {
					let l = r.reduce((d, x) => d + x[1], "");
					e.raws[s] = {
						raw: l,
						value: a
					};
				}
				e[s] = a;
			}
			rule(e) {
				e.pop();
				let s = new No();
				this.init(s, e[0][2]), s.raws.between = this.spacesAndCommentsFromEnd(e), this.raw(s, "selector", e), this.current = s;
			}
			spacesAndCommentsFromEnd(e) {
				let s, r = "";
				for (; e.length && (s = e[e.length - 1][0], !(s !== "space" && s !== "comment"));) r = e.pop()[1] + r;
				return r;
			}
			spacesAndCommentsFromStart(e) {
				let s, r = "";
				for (; e.length && (s = e[0][0], !(s !== "space" && s !== "comment"));) r += e.shift()[1];
				return r;
			}
			spacesFromEnd(e) {
				let s, r = "";
				for (; e.length && (s = e[e.length - 1][0], s === "space");) r = e.pop()[1] + r;
				return r;
			}
			stringFrom(e, s) {
				let r = "";
				for (let n = s; n < e.length; n++) r += e[n][1];
				return e.splice(s, e.length - s), r;
			}
			unclosedBlock() {
				let e = this.current.source.start;
				throw this.input.error("Unclosed block", e.line, e.column);
			}
			unclosedBracket(e) {
				throw this.input.error("Unclosed bracket", { offset: e[2] }, { offset: e[2] + 1 });
			}
			unexpectedClose(e) {
				throw this.input.error("Unexpected }", { offset: e[2] }, { offset: e[2] + 1 });
			}
			unknownWord(e) {
				throw this.input.error("Unknown word " + e[0][1], { offset: e[0][2] }, { offset: e[0][2] + e[0][1].length });
			}
			unnamedAtrule(e, s) {
				throw this.input.error("At-rule without name", { offset: s[2] }, { offset: s[2] + s[1].length });
			}
		};
		Ro.exports = As;
	});
	yt = w((a_, Io) => {
		"use strict";
		var Of = pe(), Af = $e(), Cf = ir();
		function or(t, e) {
			let r = new Cf(new Af(t, e));
			try {
				r.parse();
			} catch (n) {
				throw n;
			}
			return r.root;
		}
		Io.exports = or;
		or.default = or;
		Of.registerParse(or);
	});
	Lo = w((u_, Cs) => {
		var Nf = nr(), Pf = $e();
		Cs.exports = { isInlineComment(t) {
			if (t[0] === "word" && t[1].slice(0, 2) === "//") {
				let e = t, s = [], r, n;
				for (; t;) {
					if (/\r?\n/.test(t[1])) {
						if (/['"].*\r?\n/.test(t[1])) {
							s.push(t[1].substring(0, t[1].indexOf(`
`))), n = t[1].substring(t[1].indexOf(`
`));
							let o = this.input.css.valueOf().substring(this.tokenizer.position());
							n += o, r = t[3] + o.length - n.length;
						} else this.tokenizer.back(t);
						break;
					}
					s.push(t[1]), r = t[2], t = this.tokenizer.nextToken({ ignoreUnclosed: !0 });
				}
				let i = [
					"comment",
					s.join(""),
					e[2],
					r
				];
				return this.inlineComment(i), n && (this.input = new Pf(n), this.tokenizer = Nf(this.input)), !0;
			} else if (t[1] === "/") {
				let e = this.tokenizer.nextToken({ ignoreUnclosed: !0 });
				if (e[0] === "comment" && /^\/\*/.test(e[1])) return e[0] = "word", e[1] = e[1].slice(1), t[1] = "//", this.tokenizer.back(e), Cs.exports.isInlineComment.bind(this)(t);
			}
			return !1;
		} };
	});
	Do = w((l_, qo) => {
		qo.exports = { interpolation(t) {
			let e = [t, this.tokenizer.nextToken()], s = ["word", "}"];
			if (e[0][1].length > 1 || e[1][0] !== "{") return this.tokenizer.back(e[1]), !1;
			for (t = this.tokenizer.nextToken(); t && s.includes(t[0]);) e.push(t), t = this.tokenizer.nextToken();
			let r = e.map((u) => u[1]), [n] = e, i = e.pop(), o = [
				"word",
				r.join(""),
				n[2],
				i[2]
			];
			return this.tokenizer.back(t), this.tokenizer.back(o), !0;
		} };
	});
	Bo = w((c_, Mo) => {
		var Rf = /^#[0-9a-fA-F]{6}$|^#[0-9a-fA-F]{3}$/, If = /\.[0-9]/, Lf = (t) => {
			let [, e] = t, [s] = e;
			return (s === "." || s === "#") && Rf.test(e) === !1 && If.test(e) === !1;
		};
		Mo.exports = { isMixinToken: Lf };
	});
	Fo = w((f_, Uo) => {
		var qf = nr(), Df = /^url\((.+)\)/;
		Uo.exports = (t) => {
			let { name: e, params: s = "" } = t;
			if (e === "import" && s.length) {
				t.import = !0;
				let r = qf({ css: s });
				for (t.filename = s.replace(Df, "$1"); !r.endOfFile();) {
					let [n, i] = r.nextToken();
					if (n === "word" && i === "url") return;
					if (n === "brackets") {
						t.options = i, t.filename = s.replace(i, "").trim();
						break;
					}
				}
			}
		};
	});
	Yo = w((p_, Go) => {
		var Wo = /:$/, $o = /^:(\s+)?/;
		Go.exports = (t) => {
			let { name: e, params: s = "" } = t;
			if (t.name.slice(-1) === ":") {
				if (Wo.test(e)) {
					let [r] = e.match(Wo);
					t.name = e.replace(r, ""), t.raws.afterName = r + (t.raws.afterName || ""), t.variable = !0, t.value = t.params;
				}
				if ($o.test(s)) {
					let [r] = s.match($o);
					t.value = s.replace(r, ""), t.raws.afterName = (t.raws.afterName || "") + r, t.variable = !0;
				}
			}
		};
	});
	jo = w((m_, zo) => {
		var Mf = Fe(), Bf = ir(), { isInlineComment: Uf } = Lo(), { interpolation: Vo } = Do(), { isMixinToken: Ff } = Bo(), Wf = Fo(), $f = Yo(), Gf = /(!\s*important)$/i;
		zo.exports = class extends Bf {
			constructor(...e) {
				super(...e), this.lastNode = null;
			}
			atrule(e) {
				Vo.bind(this)(e) || (super.atrule(e), Wf(this.lastNode), $f(this.lastNode));
			}
			decl(...e) {
				super.decl(...e), /extend\(.+\)/i.test(this.lastNode.value) && (this.lastNode.extend = !0);
			}
			each(e) {
				e[0][1] = ` ${e[0][1]}`;
				let s = e.findIndex((u) => u[0] === "("), r = e.reverse().find((u) => u[0] === ")"), n = e.reverse().indexOf(r), o = e.splice(s, n).map((u) => u[1]).join("");
				for (let u of e.reverse()) this.tokenizer.back(u);
				this.atrule(this.tokenizer.nextToken()), this.lastNode.function = !0, this.lastNode.params = o;
			}
			init(e, s, r) {
				super.init(e, s, r), this.lastNode = e;
			}
			inlineComment(e) {
				let s = new Mf(), r = e[1].slice(2);
				if (this.init(s, e[2]), s.source.end = this.getPosition(e[3] || e[2]), s.inline = !0, s.raws.begin = "//", /^\s*$/.test(r)) s.text = "", s.raws.left = r, s.raws.right = "";
				else {
					let n = r.match(/^(\s*)([^]*[^\s])(\s*)$/);
					[, s.raws.left, s.text, s.raws.right] = n;
				}
			}
			mixin(e) {
				let [s] = e, r = s[1].slice(0, 1), n = e.findIndex((c) => c[0] === "brackets"), i = e.findIndex((c) => c[0] === "("), o = "";
				if ((n < 0 || n > 3) && i > 0) {
					let c = e.reduce((v, C, q) => C[0] === ")" ? q : v), h = e.slice(i, c + i).map((v) => v[1]).join(""), [l] = e.slice(i), d = [l[2], l[3]], [x] = e.slice(c, c + 1), m = [x[2], x[3]], p = ["brackets", h].concat(d, m), y = e.slice(0, i), g = e.slice(c + 1);
					e = y, e.push(p), e = e.concat(g);
				}
				let u = [];
				for (let c of e) if ((c[1] === "!" || u.length) && u.push(c), c[1] === "important") break;
				if (u.length) {
					let [c] = u, f = e.indexOf(c), h = u[u.length - 1], l = [c[2], c[3]], d = [h[4], h[5]], m = ["word", u.map((p) => p[1]).join("")].concat(l, d);
					e.splice(f, u.length, m);
				}
				let a = e.findIndex((c) => Gf.test(c[1]));
				a > 0 && ([, o] = e[a], e.splice(a, 1));
				for (let c of e.reverse()) this.tokenizer.back(c);
				this.atrule(this.tokenizer.nextToken()), this.lastNode.mixin = !0, this.lastNode.raws.identifier = r, o && (this.lastNode.important = !0, this.lastNode.raws.important = o);
			}
			other(e) {
				Uf.bind(this)(e) || super.other(e);
			}
			rule(e) {
				let s = e[e.length - 1], r = e[e.length - 2];
				if (r[0] === "at-word" && s[0] === "{" && (this.tokenizer.back(s), Vo.bind(this)(r))) {
					let i = this.tokenizer.nextToken();
					e = e.slice(0, e.length - 2).concat([i]);
					for (let o of e.reverse()) this.tokenizer.back(o);
					return;
				}
				super.rule(e), /:extend\(.+\)/i.test(this.lastNode.selector) && (this.lastNode.extend = !0);
			}
			unknownWord(e) {
				let [s] = e;
				if (e[0][1] === "each" && e[1][0] === "(") {
					this.each(e);
					return;
				}
				if (Ff(s)) {
					this.mixin(e);
					return;
				}
				super.unknownWord(e);
			}
		};
	});
	Qo = w((y_, Ho) => {
		var Yf = Xt();
		Ho.exports = class extends Yf {
			atrule(e, s) {
				if (!e.mixin && !e.variable && !e.function) {
					super.atrule(e, s);
					return;
				}
				let n = `${e.function ? "" : e.raws.identifier || "@"}${e.name}`, i = e.params ? this.rawValue(e, "params") : "", o = e.raws.important || "";
				if (e.variable && (i = e.value), typeof e.raws.afterName < "u" ? n += e.raws.afterName : i && (n += " "), e.nodes) this.block(e, n + i + o);
				else {
					let u = (e.raws.between || "") + o + (s ? ";" : "");
					this.builder(n + i + u, e);
				}
			}
			comment(e) {
				if (e.inline) {
					let s = this.raw(e, "left", "commentLeft"), r = this.raw(e, "right", "commentRight");
					this.builder(`//${s}${e.text}${r}`, e);
				} else super.comment(e);
			}
		};
	});
	Ko = w((g_, Ns) => {
		var Vf = $e(), zf = jo(), jf = Qo();
		Ns.exports = {
			parse(t, e) {
				let s = new Vf(t, e), r = new zf(s);
				return r.parse(), r.root.walk((n) => {
					let i = s.css.lastIndexOf(n.source.input.css);
					if (i === 0) return;
					if (i + n.source.input.css.length !== s.css.length) throw new Error("Invalid state detected in postcss-less");
					let o = i + n.source.start.offset, u = s.fromOffset(i + n.source.start.offset);
					if (n.source.start = {
						offset: o,
						line: u.line,
						column: u.col
					}, n.source.end) {
						let a = i + n.source.end.offset, c = s.fromOffset(i + n.source.end.offset);
						n.source.end = {
							offset: a,
							line: c.line,
							column: c.col
						};
					}
				}), r.root;
			},
			stringify(t, e) {
				new jf(e).stringify(t);
			},
			nodeToString(t) {
				let e = "";
				return Ns.exports.stringify(t, (s) => {
					e += s;
				}), e;
			}
		};
	});
	ar = w((w_, Zo) => {
		"use strict";
		var Hf = pe(), Xo, Jo, ke = class extends Hf {
			constructor(e) {
				super({
					type: "document",
					...e
				}), this.nodes || (this.nodes = []);
			}
			toResult(e = {}) {
				return new Xo(new Jo(), this, e).stringify();
			}
		};
		ke.registerLazyResult = (t) => {
			Xo = t;
		};
		ke.registerProcessor = (t) => {
			Jo = t;
		};
		Zo.exports = ke;
		ke.default = ke;
	});
	ta = w((v_, ea) => {
		"use strict";
		var Qf = er(), Kf = Fe(), Xf = mt(), Jf = $e(), Zf = _s(), ep = Ye(), tp = tr();
		function gt(t, e) {
			if (Array.isArray(t)) return t.map((o) => gt(o));
			let { inputs: s, ...r } = t;
			if (s) {
				e = [];
				for (let o of s) {
					let u = {
						...o,
						__proto__: Jf.prototype
					};
					u.map && (u.map = {
						...u.map,
						__proto__: Zf.prototype
					}), e.push(u);
				}
			}
			let n;
			if (r.nodes && (n = t.nodes.map((o) => gt(o, e)), delete r.nodes), r.source) {
				let { inputId: o, ...u } = r.source;
				r.source = u, o != null && (r.source.input = e[o]);
			}
			let i;
			if (r.type === "root") i = new ep(r);
			else if (r.type === "decl") i = new Xf(r);
			else if (r.type === "rule") i = new tp(r);
			else if (r.type === "comment") i = new Kf(r);
			else if (r.type === "atrule") i = new Qf(r);
			else throw new Error("Unknown node type: " + t.type);
			if (n) {
				i.nodes = n;
				for (let o of n) o.parent = i;
			}
			return i;
		}
		ea.exports = gt;
		gt.default = gt;
	});
	Ps = w((x_, ra) => {
		ra.exports = class {
			generate() {}
		};
	});
	Rs = w((b_, sa) => {
		"use strict";
		var wt = class {
			constructor(e, s = {}) {
				if (this.type = "warning", this.text = e, s.node && s.node.source) {
					let r = s.node.rangeBy(s);
					this.line = r.start.line, this.column = r.start.column, this.endLine = r.end.line, this.endColumn = r.end.column;
				}
				for (let r in s) this[r] = s[r];
			}
			toString() {
				return this.node ? this.node.error(this.text, {
					index: this.index,
					plugin: this.plugin,
					word: this.word
				}).message : this.plugin ? this.plugin + ": " + this.text : this.text;
			}
		};
		sa.exports = wt;
		wt.default = wt;
	});
	ur = w((E_, na) => {
		"use strict";
		var rp = Rs(), vt = class {
			get content() {
				return this.css;
			}
			constructor(e, s, r) {
				this.processor = e, this.messages = [], this.root = s, this.opts = r, this.css = "", this.map = void 0;
			}
			toString() {
				return this.css;
			}
			warn(e, s = {}) {
				s.plugin || this.lastPlugin && this.lastPlugin.postcssPlugin && (s.plugin = this.lastPlugin.postcssPlugin);
				let r = new rp(e, s);
				return this.messages.push(r), r;
			}
			warnings() {
				return this.messages.filter((e) => e.type === "warning");
			}
		};
		na.exports = vt;
		vt.default = vt;
	});
	Is = w((S_, oa) => {
		"use strict";
		var ia = {};
		oa.exports = function(e) {
			ia[e] || (ia[e] = !0, typeof console < "u" && console.warn && console.warn(e));
		};
	});
	Ds = w((k_, ca) => {
		"use strict";
		var sp = pe(), np = ar(), ip = Ps(), op = yt(), aa = ur(), ap = Ye(), up = ut(), { isClean: Z, my: lp } = Jt();
		Is();
		var cp = {
			atrule: "AtRule",
			comment: "Comment",
			decl: "Declaration",
			document: "Document",
			root: "Root",
			rule: "Rule"
		}, fp = {
			AtRule: !0,
			AtRuleExit: !0,
			Comment: !0,
			CommentExit: !0,
			Declaration: !0,
			DeclarationExit: !0,
			Document: !0,
			DocumentExit: !0,
			Once: !0,
			OnceExit: !0,
			postcssPlugin: !0,
			prepare: !0,
			Root: !0,
			RootExit: !0,
			Rule: !0,
			RuleExit: !0
		}, pp = {
			Once: !0,
			postcssPlugin: !0,
			prepare: !0
		}, ze = 0;
		function xt(t) {
			return typeof t == "object" && typeof t.then == "function";
		}
		function la(t) {
			let e = !1, s = cp[t.type];
			return t.type === "decl" ? e = t.prop.toLowerCase() : t.type === "atrule" && (e = t.name.toLowerCase()), e && t.append ? [
				s,
				s + "-" + e,
				ze,
				s + "Exit",
				s + "Exit-" + e
			] : e ? [
				s,
				s + "-" + e,
				s + "Exit",
				s + "Exit-" + e
			] : t.append ? [
				s,
				ze,
				s + "Exit"
			] : [s, s + "Exit"];
		}
		function ua(t) {
			let e;
			return t.type === "document" ? e = [
				"Document",
				ze,
				"DocumentExit"
			] : t.type === "root" ? e = [
				"Root",
				ze,
				"RootExit"
			] : e = la(t), {
				eventIndex: 0,
				events: e,
				iterator: 0,
				node: t,
				visitorIndex: 0,
				visitors: []
			};
		}
		function Ls(t) {
			return t[Z] = !1, t.nodes && t.nodes.forEach((e) => Ls(e)), t;
		}
		var qs = {}, me = class t {
			get content() {
				return this.stringify().content;
			}
			get css() {
				return this.stringify().css;
			}
			get map() {
				return this.stringify().map;
			}
			get messages() {
				return this.sync().messages;
			}
			get opts() {
				return this.result.opts;
			}
			get processor() {
				return this.result.processor;
			}
			get root() {
				return this.sync().root;
			}
			get [Symbol.toStringTag]() {
				return "LazyResult";
			}
			constructor(e, s, r) {
				this.stringified = !1, this.processed = !1;
				let n;
				if (typeof s == "object" && s !== null && (s.type === "root" || s.type === "document")) n = Ls(s);
				else if (s instanceof t || s instanceof aa) n = Ls(s.root), s.map && (typeof r.map > "u" && (r.map = {}), r.map.inline || (r.map.inline = !1), r.map.prev = s.map);
				else {
					let i = op;
					r.syntax && (i = r.syntax.parse), r.parser && (i = r.parser), i.parse && (i = i.parse);
					try {
						n = i(s, r);
					} catch (o) {
						this.processed = !0, this.error = o;
					}
					n && !n[lp] && sp.rebuild(n);
				}
				this.result = new aa(e, n, r), this.helpers = {
					...qs,
					postcss: qs,
					result: this.result
				}, this.plugins = this.processor.plugins.map((i) => typeof i == "object" && i.prepare ? {
					...i,
					...i.prepare(this.result)
				} : i);
			}
			async() {
				return this.error ? Promise.reject(this.error) : this.processed ? Promise.resolve(this.result) : (this.processing || (this.processing = this.runAsync()), this.processing);
			}
			catch(e) {
				return this.async().catch(e);
			}
			finally(e) {
				return this.async().then(e, e);
			}
			getAsyncError() {
				throw new Error("Use process(css).then(cb) to work with async plugins");
			}
			handleError(e, s) {
				let r = this.result.lastPlugin;
				try {
					s && s.addToError(e), this.error = e, e.name === "CssSyntaxError" && !e.plugin ? (e.plugin = r.postcssPlugin, e.setMessage()) : r.postcssVersion;
				} catch (n) {
					console && console.error && console.error(n);
				}
				return e;
			}
			prepareVisitors() {
				this.listeners = {};
				let e = (s, r, n) => {
					this.listeners[r] || (this.listeners[r] = []), this.listeners[r].push([s, n]);
				};
				for (let s of this.plugins) if (typeof s == "object") for (let r in s) {
					if (!fp[r] && /^[A-Z]/.test(r)) throw new Error(`Unknown event ${r} in ${s.postcssPlugin}. Try to update PostCSS (${this.processor.version} now).`);
					if (!pp[r]) if (typeof s[r] == "object") for (let n in s[r]) n === "*" ? e(s, r, s[r][n]) : e(s, r + "-" + n.toLowerCase(), s[r][n]);
					else typeof s[r] == "function" && e(s, r, s[r]);
				}
				this.hasListener = Object.keys(this.listeners).length > 0;
			}
			async runAsync() {
				this.plugin = 0;
				for (let e = 0; e < this.plugins.length; e++) {
					let s = this.plugins[e], r = this.runOnRoot(s);
					if (xt(r)) try {
						await r;
					} catch (n) {
						throw this.handleError(n);
					}
				}
				if (this.prepareVisitors(), this.hasListener) {
					let e = this.result.root;
					for (; !e[Z];) {
						e[Z] = !0;
						let s = [ua(e)];
						for (; s.length > 0;) {
							let r = this.visitTick(s);
							if (xt(r)) try {
								await r;
							} catch (n) {
								let i = s[s.length - 1].node;
								throw this.handleError(n, i);
							}
						}
					}
					if (this.listeners.OnceExit) for (let [s, r] of this.listeners.OnceExit) {
						this.result.lastPlugin = s;
						try {
							if (e.type === "document") {
								let n = e.nodes.map((i) => r(i, this.helpers));
								await Promise.all(n);
							} else await r(e, this.helpers);
						} catch (n) {
							throw this.handleError(n);
						}
					}
				}
				return this.processed = !0, this.stringify();
			}
			runOnRoot(e) {
				this.result.lastPlugin = e;
				try {
					if (typeof e == "object" && e.Once) {
						if (this.result.root.type === "document") {
							let s = this.result.root.nodes.map((r) => e.Once(r, this.helpers));
							return xt(s[0]) ? Promise.all(s) : s;
						}
						return e.Once(this.result.root, this.helpers);
					} else if (typeof e == "function") return e(this.result.root, this.result);
				} catch (s) {
					throw this.handleError(s);
				}
			}
			stringify() {
				if (this.error) throw this.error;
				if (this.stringified) return this.result;
				this.stringified = !0, this.sync();
				let e = this.result.opts, s = up;
				e.syntax && (s = e.syntax.stringify), e.stringifier && (s = e.stringifier), s.stringify && (s = s.stringify);
				let r = this.result.root.source;
				if (e.map === void 0 && !(r && r.input && r.input.map)) {
					let o = "";
					return s(this.result.root, (u) => {
						o += u;
					}), this.result.css = o, this.result;
				}
				let i = new ip(s, this.result.root, this.result.opts).generate();
				return this.result.css = i[0], this.result.map = i[1], this.result;
			}
			sync() {
				if (this.error) throw this.error;
				if (this.processed) return this.result;
				if (this.processed = !0, this.processing) throw this.getAsyncError();
				for (let e of this.plugins) if (xt(this.runOnRoot(e))) throw this.getAsyncError();
				if (this.prepareVisitors(), this.hasListener) {
					let e = this.result.root;
					for (; !e[Z];) e[Z] = !0, this.walkSync(e);
					if (this.listeners.OnceExit) if (e.type === "document") for (let s of e.nodes) this.visitSync(this.listeners.OnceExit, s);
					else this.visitSync(this.listeners.OnceExit, e);
				}
				return this.result;
			}
			then(e, s) {
				return this.async().then(e, s);
			}
			toString() {
				return this.css;
			}
			visitSync(e, s) {
				for (let [r, n] of e) {
					this.result.lastPlugin = r;
					let i;
					try {
						i = n(s, this.helpers);
					} catch (o) {
						throw this.handleError(o, s.proxyOf);
					}
					if (s.type !== "root" && s.type !== "document" && !s.parent) return !0;
					if (xt(i)) throw this.getAsyncError();
				}
			}
			visitTick(e) {
				let s = e[e.length - 1], { node: r, visitors: n } = s;
				if (r.type !== "root" && r.type !== "document" && !r.parent) {
					e.pop();
					return;
				}
				if (n.length > 0 && s.visitorIndex < n.length) {
					let [o, u] = n[s.visitorIndex];
					s.visitorIndex += 1, s.visitorIndex === n.length && (s.visitors = [], s.visitorIndex = 0), this.result.lastPlugin = o;
					try {
						return u(r.toProxy(), this.helpers);
					} catch (a) {
						throw this.handleError(a, r);
					}
				}
				if (s.iterator !== 0) {
					let o = s.iterator, u;
					for (; u = r.nodes[r.indexes[o]];) if (r.indexes[o] += 1, !u[Z]) {
						u[Z] = !0, e.push(ua(u));
						return;
					}
					s.iterator = 0, delete r.indexes[o];
				}
				let i = s.events;
				for (; s.eventIndex < i.length;) {
					let o = i[s.eventIndex];
					if (s.eventIndex += 1, o === ze) {
						r.nodes && r.nodes.length && (r[Z] = !0, s.iterator = r.getIterator());
						return;
					} else if (this.listeners[o]) {
						s.visitors = this.listeners[o];
						return;
					}
				}
				e.pop();
			}
			walkSync(e) {
				e[Z] = !0;
				let s = la(e);
				for (let r of s) if (r === ze) e.nodes && e.each((n) => {
					n[Z] || this.walkSync(n);
				});
				else {
					let n = this.listeners[r];
					if (n && this.visitSync(n, e.toProxy())) return;
				}
			}
			warnings() {
				return this.sync().warnings();
			}
		};
		me.registerPostcss = (t) => {
			qs = t;
		};
		ca.exports = me;
		me.default = me;
		ap.registerLazyResult(me);
		np.registerLazyResult(me);
	});
	pa = w((A_, fa) => {
		"use strict";
		var hp = Ps(), mp = yt(), dp = ur(), yp = ut();
		Is();
		var _t = class {
			get content() {
				return this.result.css;
			}
			get css() {
				return this.result.css;
			}
			get map() {
				return this.result.map;
			}
			get messages() {
				return [];
			}
			get opts() {
				return this.result.opts;
			}
			get processor() {
				return this.result.processor;
			}
			get root() {
				if (this._root) return this._root;
				let e, s = mp;
				try {
					e = s(this._css, this._opts);
				} catch (r) {
					this.error = r;
				}
				if (this.error) throw this.error;
				return this._root = e, e;
			}
			get [Symbol.toStringTag]() {
				return "NoWorkResult";
			}
			constructor(e, s, r) {
				s = s.toString(), this.stringified = !1, this._processor = e, this._css = s, this._opts = r, this._map = void 0;
				let n = yp;
				this.result = new dp(this._processor, void 0, this._opts), this.result.css = s;
				let i = this;
				Object.defineProperty(this.result, "root", { get() {
					return i.root;
				} });
				let o = new hp(n, void 0, this._opts, s);
				if (o.isMap()) {
					let [u, a] = o.generate();
					u && (this.result.css = u), a && (this.result.map = a);
				} else o.clearAnnotation(), this.result.css = o.css;
			}
			async() {
				return this.error ? Promise.reject(this.error) : Promise.resolve(this.result);
			}
			catch(e) {
				return this.async().catch(e);
			}
			finally(e) {
				return this.async().then(e, e);
			}
			sync() {
				if (this.error) throw this.error;
				return this.result;
			}
			then(e, s) {
				return this.async().then(e, s);
			}
			toString() {
				return this._css;
			}
			warnings() {
				return [];
			}
		};
		fa.exports = _t;
		_t.default = _t;
	});
	ma = w((C_, ha) => {
		"use strict";
		var gp = ar(), wp = Ds(), vp = pa(), xp = Ye(), Oe = class {
			constructor(e = []) {
				this.version = "8.5.16", this.plugins = this.normalize(e);
			}
			normalize(e) {
				let s = [];
				for (let r of e) if (r.postcss === !0 ? r = r() : r.postcss && (r = r.postcss), typeof r == "object" && Array.isArray(r.plugins)) s = s.concat(r.plugins);
				else if (typeof r == "object" && r.postcssPlugin) s.push(r);
				else if (typeof r == "function") s.push(r);
				else if (!(typeof r == "object" && (r.parse || r.stringify))) throw new Error(r + " is not a PostCSS plugin");
				return s;
			}
			process(e, s = {}) {
				return !this.plugins.length && !s.parser && !s.stringifier && !s.syntax ? new vp(this, e, s) : new wp(this, e, s);
			}
			use(e) {
				return this.plugins = this.plugins.concat(this.normalize([e])), this;
			}
		};
		ha.exports = Oe;
		Oe.default = Oe;
		xp.registerProcessor(Oe);
		gp.registerProcessor(Oe);
	});
	lr = w((N_, _a) => {
		"use strict";
		var da = er(), ya = Fe(), _p = pe(), bp = Kt(), ga = mt(), wa = ar(), Ep = ta(), Sp = $e(), Tp = Ds(), kp = ks(), Op = ft(), Ap = yt(), Ms = ma(), Cp = ur(), va = Ye(), xa = tr(), Np = ut(), Pp = Rs();
		function E(...t) {
			return t.length === 1 && Array.isArray(t[0]) && (t = t[0]), new Ms(t);
		}
		E.plugin = function(e, s) {
			let r = !1;
			function n(...o) {
				console && console.warn && !r && (r = !0, console.warn(e + `: postcss.plugin was deprecated. Migration guide:
https://evilmartians.com/chronicles/postcss-8-plugin-migration`));
				let u = s(...o);
				return u.postcssPlugin = e, u.postcssVersion = new Ms().version, u;
			}
			let i;
			return Object.defineProperty(n, "postcss", { get() {
				return i || (i = n()), i;
			} }), n.process = function(o, u, a) {
				return E([n(a)]).process(o, u);
			}, n;
		};
		E.stringify = Np;
		E.parse = Ap;
		E.fromJSON = Ep;
		E.list = kp;
		E.comment = (t) => new ya(t);
		E.atRule = (t) => new da(t);
		E.decl = (t) => new ga(t);
		E.rule = (t) => new xa(t);
		E.root = (t) => new va(t);
		E.document = (t) => new wa(t);
		E.CssSyntaxError = bp;
		E.Declaration = ga;
		E.Container = _p;
		E.Processor = Ms;
		E.Document = wa;
		E.Comment = ya;
		E.Warning = Pp;
		E.AtRule = da;
		E.Result = Cp;
		E.Input = Sp;
		E.Rule = xa;
		E.Root = va;
		E.Node = Op;
		Tp.registerPostcss(E);
		_a.exports = E;
		E.default = E;
	});
	Ea = w((P_, ba) => {
		var { Container: Rp } = lr(), Bs = class extends Rp {
			constructor(e) {
				super(e), this.type = "decl", this.isNested = !0, this.nodes || (this.nodes = []);
			}
		};
		ba.exports = Bs;
	});
	ka = w((R_, Ta) => {
		"use strict";
		var cr = /[\t\n\f\r "#'()/;[\\\]{}]/g, fr = /[,\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g, Ip = /.[\r\n"'(/\\]/, Sa = /[\da-f]/i, pr = /[\n\f\r]/g;
		Ta.exports = function(e, s = {}) {
			let r = e.css.valueOf(), n = s.ignoreErrors, i, o, u, a, c, f, h, l, d, x = r.length, m = 0, p = [], y = [], g;
			function v() {
				return m;
			}
			function C(k) {
				throw e.error("Unclosed " + k, m);
			}
			function q() {
				return y.length === 0 && m >= x;
			}
			function W() {
				let k = 1, b = !1, S = !1;
				for (; k > 0;) o += 1, r.length <= o && C("interpolation"), i = r.charCodeAt(o), l = r.charCodeAt(o + 1), b ? !S && i === b ? (b = !1, S = !1) : i === 92 ? S = !S : S && (S = !1) : i === 39 || i === 34 ? b = i : i === 125 ? k -= 1 : i === 35 && l === 123 && (k += 1);
			}
			function se(k) {
				if (y.length) return y.pop();
				if (m >= x) return;
				let b = k ? k.ignoreUnclosed : !1;
				switch (i = r.charCodeAt(m), i) {
					case 10:
					case 32:
					case 9:
					case 13:
					case 12:
						o = m;
						do
							o += 1, i = r.charCodeAt(o);
						while (i === 32 || i === 10 || i === 9 || i === 13 || i === 12);
						d = ["space", r.slice(m, o)], m = o - 1;
						break;
					case 91:
					case 93:
					case 123:
					case 125:
					case 58:
					case 59:
					case 41: {
						let S = String.fromCharCode(i);
						d = [
							S,
							S,
							m
						];
						break;
					}
					case 44:
						d = [
							"word",
							",",
							m,
							m + 1
						];
						break;
					case 40:
						if (h = p.length ? p.pop()[1] : "", l = r.charCodeAt(m + 1), h === "url" && l !== 39 && l !== 34) {
							for (g = 1, f = !1, o = m + 1; o <= r.length - 1;) {
								if (l = r.charCodeAt(o), l === 92) f = !f;
								else if (l === 40) g += 1;
								else if (l === 41 && (g -= 1, g === 0)) break;
								o += 1;
							}
							a = r.slice(m, o + 1), d = [
								"brackets",
								a,
								m,
								o
							], m = o;
						} else o = r.indexOf(")", m + 1), a = r.slice(m, o + 1), o === -1 || Ip.test(a) ? d = [
							"(",
							"(",
							m
						] : (d = [
							"brackets",
							a,
							m,
							o
						], m = o);
						break;
					case 39:
					case 34:
						for (u = i, o = m, f = !1; o < x && (o++, o === x && C("string"), i = r.charCodeAt(o), l = r.charCodeAt(o + 1), !(!f && i === u));) i === 92 ? f = !f : f ? f = !1 : i === 35 && l === 123 && W();
						d = [
							"string",
							r.slice(m, o + 1),
							m,
							o
						], m = o;
						break;
					case 64:
						cr.lastIndex = m + 1, cr.test(r), cr.lastIndex === 0 ? o = r.length - 1 : o = cr.lastIndex - 2, d = [
							"at-word",
							r.slice(m, o + 1),
							m,
							o
						], m = o;
						break;
					case 92:
						for (o = m, c = !0; r.charCodeAt(o + 1) === 92;) o += 1, c = !c;
						if (i = r.charCodeAt(o + 1), c && i !== 47 && i !== 32 && i !== 10 && i !== 9 && i !== 13 && i !== 12 && (o += 1, Sa.test(r.charAt(o)))) {
							for (; Sa.test(r.charAt(o + 1));) o += 1;
							r.charCodeAt(o + 1) === 32 && (o += 1);
						}
						d = [
							"word",
							r.slice(m, o + 1),
							m,
							o
						], m = o;
						break;
					default:
						l = r.charCodeAt(m + 1), i === 35 && l === 123 ? (o = m, W(), a = r.slice(m, o + 1), d = [
							"word",
							a,
							m,
							o
						], m = o) : i === 47 && l === 42 ? (o = r.indexOf("*/", m + 2) + 1, o === 0 && (n || b ? o = r.length : C("comment")), d = [
							"comment",
							r.slice(m, o + 1),
							m,
							o
						], m = o) : i === 47 && l === 47 ? (pr.lastIndex = m + 1, pr.test(r), pr.lastIndex === 0 ? o = r.length - 1 : o = pr.lastIndex - 2, a = r.slice(m, o + 1), d = [
							"comment",
							a,
							m,
							o,
							"inline"
						], m = o) : (fr.lastIndex = m + 1, fr.test(r), fr.lastIndex === 0 ? o = r.length - 1 : o = fr.lastIndex - 2, d = [
							"word",
							r.slice(m, o + 1),
							m,
							o
						], p.push(d), m = o);
						break;
				}
				return m++, d;
			}
			function ye(k) {
				y.push(k);
			}
			return {
				back: ye,
				endOfFile: q,
				nextToken: se,
				position: v
			};
		};
	});
	Aa = w((I_, Oa) => {
		var { Comment: Lp } = lr(), qp = ir(), Dp = Ea(), Mp = ka(), Us = class extends qp {
			atrule(e) {
				let s = e[1], r = e;
				for (; !this.tokenizer.endOfFile();) {
					let n = this.tokenizer.nextToken();
					if (n[0] === "word" && n[2] === r[3] + 1) s += n[1], r = n;
					else {
						this.tokenizer.back(n);
						break;
					}
				}
				super.atrule([
					"at-word",
					s,
					e[2],
					r[3]
				]);
			}
			comment(e) {
				if (e[4] === "inline") {
					let s = new Lp();
					this.init(s, e[2]), s.raws.inline = !0;
					let r = this.input.fromOffset(e[3]);
					s.source.end = {
						column: r.col,
						line: r.line,
						offset: e[3] + 1
					};
					let n = e[1].slice(2);
					if (/^\s*$/.test(n)) s.text = "", s.raws.left = n, s.raws.right = "";
					else {
						let i = n.match(/^(\s*)([^]*\S)(\s*)$/);
						s.text = i[2].replace(/(\*\/|\/\*)/g, "*//*"), s.raws.left = i[1], s.raws.right = i[3], s.raws.text = i[2];
					}
				} else super.comment(e);
			}
			createTokenizer() {
				this.tokenizer = Mp(this.input);
			}
			raw(e, s, r, n) {
				if (super.raw(e, s, r, n), e.raws[s]) {
					let i = e.raws[s].raw;
					e.raws[s].raw = r.reduce((o, u) => {
						if (u[0] === "comment" && u[4] === "inline") {
							let a = u[1].slice(2).replace(/(\*\/|\/\*)/g, "*//*");
							return o + "/*" + a + "*/";
						} else return o + u[1];
					}, ""), i !== e.raws[s].raw && (e.raws[s].scss = i);
				}
			}
			rule(e) {
				let s = !1, r = 0, n = "";
				for (let i of e) if (s) i[0] !== "comment" && i[0] !== "{" && (n += i[1]);
				else {
					if (i[0] === "space" && i[1].includes(`
`)) break;
					i[0] === "(" ? r += 1 : i[0] === ")" ? r -= 1 : r === 0 && i[0] === ":" && (s = !0);
				}
				if (!s || n.trim() === "" || /^[#:A-Za-z-]/.test(n)) super.rule(e);
				else {
					e.pop();
					let i = new Dp();
					this.init(i, e[0][2]);
					let o;
					for (let a = e.length - 1; a >= 0; a--) if (e[a][0] !== "space") {
						o = e[a];
						break;
					}
					if (o[3]) {
						let a = this.input.fromOffset(o[3]);
						i.source.end = {
							column: a.col,
							line: a.line,
							offset: o[3] + 1
						};
					} else {
						let a = this.input.fromOffset(o[2]);
						i.source.end = {
							column: a.col,
							line: a.line,
							offset: o[2] + 1
						};
					}
					for (; e[0][0] !== "word";) i.raws.before += e.shift()[1];
					if (e[0][2]) {
						let a = this.input.fromOffset(e[0][2]);
						i.source.start = {
							column: a.col,
							line: a.line,
							offset: e[0][2]
						};
					}
					for (i.prop = ""; e.length;) {
						let a = e[0][0];
						if (a === ":" || a === "space" || a === "comment") break;
						i.prop += e.shift()[1];
					}
					i.raws.between = "";
					let u;
					for (; e.length;) if (u = e.shift(), u[0] === ":") {
						i.raws.between += u[1];
						break;
					} else i.raws.between += u[1];
					(i.prop[0] === "_" || i.prop[0] === "*") && (i.raws.before += i.prop[0], i.prop = i.prop.slice(1)), i.raws.between += this.spacesAndCommentsFromStart(e), this.precheckMissedSemicolon(e);
					for (let a = e.length - 1; a > 0; a--) {
						if (u = e[a], u[1] === "!important") {
							i.important = !0;
							let c = this.stringFrom(e, a);
							c = this.spacesFromEnd(e) + c, c !== " !important" && (i.raws.important = c);
							break;
						} else if (u[1] === "important") {
							let c = e.slice(0), f = "";
							for (let h = a; h > 0; h--) {
								let l = c[h][0];
								if (f.trim().indexOf("!") === 0 && l !== "space") break;
								f = c.pop()[1] + f;
							}
							f.trim().indexOf("!") === 0 && (i.important = !0, i.raws.important = f, e = c);
						}
						if (u[0] !== "space" && u[0] !== "comment") break;
					}
					this.raw(i, "value", e), i.value.includes(":") && this.checkMissedSemicolon(e), this.current = i;
				}
			}
		};
		Oa.exports = Us;
	});
	Na = w((L_, Ca) => {
		var { Input: Bp } = lr(), Up = Aa();
		Ca.exports = function(e, s) {
			let n = new Up(new Bp(e, s));
			return n.parse(), n.root;
		};
	});
	Ws = w((Fs) => {
		"use strict";
		Object.defineProperty(Fs, "__esModule", { value: !0 });
		function $p(t) {
			this.after = t.after, this.before = t.before, this.type = t.type, this.value = t.value, this.sourceIndex = t.sourceIndex;
		}
		Fs.default = $p;
	});
	Gs = w(($s) => {
		"use strict";
		Object.defineProperty($s, "__esModule", { value: !0 });
		var Ra = Yp(Ws());
		function Yp(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function bt(t) {
			var e = this;
			this.constructor(t), this.nodes = t.nodes, this.after === void 0 && (this.after = this.nodes.length > 0 ? this.nodes[this.nodes.length - 1].after : ""), this.before === void 0 && (this.before = this.nodes.length > 0 ? this.nodes[0].before : ""), this.sourceIndex === void 0 && (this.sourceIndex = this.before.length), this.nodes.forEach(function(s) {
				s.parent = e;
			});
		}
		bt.prototype = Object.create(Ra.default.prototype);
		bt.constructor = Ra.default;
		bt.prototype.walk = function(e, s) {
			for (var r = typeof e == "string" || e instanceof RegExp, n = r ? s : e, i = typeof e == "string" ? new RegExp(e) : e, o = 0; o < this.nodes.length; o++) {
				var u = this.nodes[o];
				if ((r ? i.test(u.type) : !0) && n && n(u, o, this.nodes) === !1 || u.nodes && u.walk(e, s) === !1) return !1;
			}
			return !0;
		};
		bt.prototype.each = function() {
			for (var e = arguments.length <= 0 || arguments[0] === void 0 ? function() {} : arguments[0], s = 0; s < this.nodes.length; s++) {
				var r = this.nodes[s];
				if (e(r, s, this.nodes) === !1) return !1;
			}
			return !0;
		};
		$s.default = bt;
	});
	Da = w((Et) => {
		"use strict";
		Object.defineProperty(Et, "__esModule", { value: !0 });
		Et.parseMediaFeature = qa;
		Et.parseMediaQuery = Vs;
		Et.parseMediaList = jp;
		var Ia = La(Ws()), Ys = La(Gs());
		function La(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function qa(t) {
			var e = arguments.length <= 1 || arguments[1] === void 0 ? 0 : arguments[1], s = [{
				mode: "normal",
				character: null
			}], r = [], n = 0, i = "", o = null, u = null, a = e, c = t;
			t[0] === "(" && t[t.length - 1] === ")" && (c = t.substring(1, t.length - 1), a++);
			for (var f = 0; f < c.length; f++) {
				var h = c[f];
				if ((h === "'" || h === "\"") && (s[n].isCalculationEnabled === !0 ? (s.push({
					mode: "string",
					isCalculationEnabled: !1,
					character: h
				}), n++) : s[n].mode === "string" && s[n].character === h && c[f - 1] !== "\\" && (s.pop(), n--)), h === "{" ? (s.push({
					mode: "interpolation",
					isCalculationEnabled: !0
				}), n++) : h === "}" && (s.pop(), n--), s[n].mode === "normal" && h === ":") {
					var l = c.substring(f + 1);
					u = {
						type: "value",
						before: /^(\s*)/.exec(l)[1],
						after: /(\s*)$/.exec(l)[1],
						value: l.trim()
					}, u.sourceIndex = u.before.length + f + 1 + a, o = {
						type: "colon",
						sourceIndex: f + a,
						after: u.before,
						value: ":"
					};
					break;
				}
				i += h;
			}
			return i = {
				type: "media-feature",
				before: /^(\s*)/.exec(i)[1],
				after: /(\s*)$/.exec(i)[1],
				value: i.trim()
			}, i.sourceIndex = i.before.length + a, r.push(i), o !== null && (o.before = i.after, r.push(o)), u !== null && r.push(u), r;
		}
		function Vs(t) {
			var e = arguments.length <= 1 || arguments[1] === void 0 ? 0 : arguments[1], s = [], r = 0, n = !1, i = void 0;
			function o() {
				return {
					before: "",
					after: "",
					value: ""
				};
			}
			i = o();
			for (var u = 0; u < t.length; u++) {
				var a = t[u];
				n ? (i.value += a, (a === "{" || a === "(") && r++, (a === ")" || a === "}") && r--) : a.search(/\s/) !== -1 ? i.before += a : (a === "(" && (i.type = "media-feature-expression", r++), i.value = a, i.sourceIndex = e + u, n = !0), n && r === 0 && (a === ")" || u === t.length - 1 || t[u + 1].search(/\s/) !== -1) && ([
					"not",
					"only",
					"and"
				].indexOf(i.value) !== -1 && (i.type = "keyword"), i.type === "media-feature-expression" && (i.nodes = qa(i.value, i.sourceIndex)), s.push(Array.isArray(i.nodes) ? new Ys.default(i) : new Ia.default(i)), i = o(), n = !1);
			}
			for (var c = 0; c < s.length; c++) if (i = s[c], c > 0 && (s[c - 1].after = i.before), i.type === void 0) {
				if (c > 0) {
					if (s[c - 1].type === "media-feature-expression") {
						i.type = "keyword";
						continue;
					}
					if (s[c - 1].value === "not" || s[c - 1].value === "only") {
						i.type = "media-type";
						continue;
					}
					if (s[c - 1].value === "and") {
						i.type = "media-feature-expression";
						continue;
					}
					s[c - 1].type === "media-type" && (s[c + 1] ? i.type = s[c + 1].type === "media-feature-expression" ? "keyword" : "media-feature-expression" : i.type = "media-feature-expression");
				}
				if (c === 0) {
					if (!s[c + 1]) {
						i.type = "media-type";
						continue;
					}
					if (s[c + 1] && (s[c + 1].type === "media-feature-expression" || s[c + 1].type === "keyword")) {
						i.type = "media-type";
						continue;
					}
					if (s[c + 2]) {
						if (s[c + 2].type === "media-feature-expression") {
							i.type = "media-type", s[c + 1].type = "keyword";
							continue;
						}
						if (s[c + 2].type === "keyword") {
							i.type = "keyword", s[c + 1].type = "media-type";
							continue;
						}
					}
					if (s[c + 3] && s[c + 3].type === "media-feature-expression") {
						i.type = "keyword", s[c + 1].type = "media-type", s[c + 2].type = "keyword";
						continue;
					}
				}
			}
			return s;
		}
		function jp(t) {
			var e = [], s = 0, r = 0, n = /^(\s*)url\s*\(/.exec(t);
			if (n !== null) {
				for (var i = n[0].length, o = 1; o > 0;) {
					var u = t[i];
					u === "(" && o++, u === ")" && o--, i++;
				}
				e.unshift(new Ia.default({
					type: "url",
					value: t.substring(0, i).trim(),
					sourceIndex: n[1].length,
					before: n[1],
					after: /^(\s*)/.exec(t.substring(i))[1]
				})), s = i;
			}
			for (var a = s; a < t.length; a++) {
				var c = t[a];
				if (c === "(" && r++, c === ")" && r--, r === 0 && c === ",") {
					var f = t.substring(s, a), h = /^(\s*)/.exec(f)[1];
					e.push(new Ys.default({
						type: "media-query",
						value: f.trim(),
						sourceIndex: s + h.length,
						nodes: Vs(f, s),
						before: h,
						after: /(\s*)$/.exec(f)[1]
					})), s = a + 1;
				}
			}
			var l = t.substring(s), d = /^(\s*)/.exec(l)[1];
			return e.push(new Ys.default({
				type: "media-query",
				value: l.trim(),
				sourceIndex: s + d.length,
				nodes: Vs(l, s),
				before: d,
				after: /(\s*)$/.exec(l)[1]
			})), e;
		}
	});
	Ma = w((zs) => {
		"use strict";
		Object.defineProperty(zs, "__esModule", { value: !0 });
		zs.default = Jp;
		var Qp = Xp(Gs()), Kp = Da();
		function Xp(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Jp(t) {
			return new Qp.default({
				nodes: (0, Kp.parseMediaList)(t),
				type: "media-query-list",
				value: t.trim()
			});
		}
	});
	Hs = w((V_, Fa) => {
		Fa.exports = function(e, s) {
			if (s = typeof s == "number" ? s : Infinity, !s) return Array.isArray(e) ? e.map(function(n) {
				return n;
			}) : e;
			return r(e, 1);
			function r(n, i) {
				return n.reduce(function(o, u) {
					return Array.isArray(u) && i < s ? o.concat(r(u, i + 1)) : o.concat(u);
				}, []);
			}
		};
	});
	Qs = w((z_, Wa) => {
		Wa.exports = function(t, e) {
			for (var s = -1, r = []; (s = t.indexOf(e, s + 1)) !== -1;) r.push(s);
			return r;
		};
	});
	Ks = w((j_, $a) => {
		"use strict";
		function th(t, e) {
			for (var s = 1, r = t.length, n = t[0], i = t[0], o = 1; o < r; ++o) if (i = n, n = t[o], e(n, i)) {
				if (o === s) {
					s++;
					continue;
				}
				t[s++] = n;
			}
			return t.length = s, t;
		}
		function rh(t) {
			for (var e = 1, s = t.length, r = t[0], n = t[0], i = 1; i < s; ++i, n = r) if (n = r, r = t[i], r !== n) {
				if (i === e) {
					e++;
					continue;
				}
				t[e++] = r;
			}
			return t.length = e, t;
		}
		function sh(t, e, s) {
			return t.length === 0 ? t : e ? (s || t.sort(e), th(t, e)) : (s || t.sort(), rh(t));
		}
		$a.exports = sh;
	});
	Ce = w((hr, Ya) => {
		"use strict";
		hr.__esModule = !0;
		var Ga = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
			return typeof t;
		} : function(t) {
			return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
		};
		function nh(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		var ih = function t(e, s) {
			if ((typeof e > "u" ? "undefined" : Ga(e)) !== "object") return e;
			var r = new e.constructor();
			for (var n in e) if (e.hasOwnProperty(n)) {
				var i = e[n], o = typeof i > "u" ? "undefined" : Ga(i);
				n === "parent" && o === "object" ? s && (r[n] = s) : i instanceof Array ? r[n] = i.map(function(u) {
					return t(u, r);
				}) : r[n] = t(i, r);
			}
			return r;
		};
		hr.default = (function() {
			function t() {
				var e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
				nh(this, t);
				for (var s in e) this[s] = e[s];
				var r = e.spaces;
				r = r === void 0 ? {} : r;
				var n = r.before, i = n === void 0 ? "" : n, o = r.after, u = o === void 0 ? "" : o;
				this.spaces = {
					before: i,
					after: u
				};
			}
			return t.prototype.remove = function() {
				return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
			}, t.prototype.replaceWith = function() {
				if (this.parent) {
					for (var s in arguments) this.parent.insertBefore(this, arguments[s]);
					this.remove();
				}
				return this;
			}, t.prototype.next = function() {
				return this.parent.at(this.parent.index(this) + 1);
			}, t.prototype.prev = function() {
				return this.parent.at(this.parent.index(this) - 1);
			}, t.prototype.clone = function() {
				var s = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, r = ih(this);
				for (var n in s) r[n] = s[n];
				return r;
			}, t.prototype.toString = function() {
				return [
					this.spaces.before,
					String(this.value),
					this.spaces.after
				].join("");
			}, t;
		})();
		Ya.exports = hr.default;
	});
	M = w((B) => {
		"use strict";
		B.__esModule = !0;
		B.TAG = "tag";
		B.STRING = "string";
		B.SELECTOR = "selector";
		B.ROOT = "root";
		B.PSEUDO = "pseudo";
		B.NESTING = "nesting";
		B.ID = "id";
		B.COMMENT = "comment";
		B.COMBINATOR = "combinator";
		B.CLASS = "class";
		B.ATTRIBUTE = "attribute";
		B.UNIVERSAL = "universal";
	});
	dr = w((mr, Va) => {
		"use strict";
		mr.__esModule = !0;
		var ah = (function() {
			function t(e, s) {
				for (var r = 0; r < s.length; r++) {
					var n = s[r];
					n.enumerable = n.enumerable || !1, n.configurable = !0, "value" in n && (n.writable = !0), Object.defineProperty(e, n.key, n);
				}
			}
			return function(e, s, r) {
				return s && t(e.prototype, s), r && t(e, r), e;
			};
		})(), lh = ph(Ce()), te = fh(M());
		function fh(t) {
			if (t && t.__esModule) return t;
			var e = {};
			if (t != null) for (var s in t) Object.prototype.hasOwnProperty.call(t, s) && (e[s] = t[s]);
			return e.default = t, e;
		}
		function ph(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function hh(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function mh(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function dh(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		mr.default = (function(t) {
			dh(e, t);
			function e(s) {
				hh(this, e);
				var r = mh(this, t.call(this, s));
				return r.nodes || (r.nodes = []), r;
			}
			return e.prototype.append = function(r) {
				return r.parent = this, this.nodes.push(r), this;
			}, e.prototype.prepend = function(r) {
				return r.parent = this, this.nodes.unshift(r), this;
			}, e.prototype.at = function(r) {
				return this.nodes[r];
			}, e.prototype.index = function(r) {
				return typeof r == "number" ? r : this.nodes.indexOf(r);
			}, e.prototype.removeChild = function(r) {
				r = this.index(r), this.at(r).parent = void 0, this.nodes.splice(r, 1);
				var n = void 0;
				for (var i in this.indexes) n = this.indexes[i], n >= r && (this.indexes[i] = n - 1);
				return this;
			}, e.prototype.removeAll = function() {
				for (var i = this.nodes, r = Array.isArray(i), n = 0, i = r ? i : i[Symbol.iterator]();;) {
					var o;
					if (r) {
						if (n >= i.length) break;
						o = i[n++];
					} else {
						if (n = i.next(), n.done) break;
						o = n.value;
					}
					var u = o;
					u.parent = void 0;
				}
				return this.nodes = [], this;
			}, e.prototype.empty = function() {
				return this.removeAll();
			}, e.prototype.insertAfter = function(r, n) {
				var i = this.index(r);
				this.nodes.splice(i + 1, 0, n);
				var o = void 0;
				for (var u in this.indexes) o = this.indexes[u], i <= o && (this.indexes[u] = o + this.nodes.length);
				return this;
			}, e.prototype.insertBefore = function(r, n) {
				var i = this.index(r);
				this.nodes.splice(i, 0, n);
				var o = void 0;
				for (var u in this.indexes) o = this.indexes[u], i <= o && (this.indexes[u] = o + this.nodes.length);
				return this;
			}, e.prototype.each = function(r) {
				this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach++;
				var n = this.lastEach;
				if (this.indexes[n] = 0, !!this.length) {
					for (var i = void 0, o = void 0; this.indexes[n] < this.length && (i = this.indexes[n], o = r(this.at(i), i), o !== !1);) this.indexes[n] += 1;
					if (delete this.indexes[n], o === !1) return !1;
				}
			}, e.prototype.walk = function(r) {
				return this.each(function(n, i) {
					var o = r(n, i);
					if (o !== !1 && n.length && (o = n.walk(r)), o === !1) return !1;
				});
			}, e.prototype.walkAttributes = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.ATTRIBUTE) return r.call(n, i);
				});
			}, e.prototype.walkClasses = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.CLASS) return r.call(n, i);
				});
			}, e.prototype.walkCombinators = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.COMBINATOR) return r.call(n, i);
				});
			}, e.prototype.walkComments = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.COMMENT) return r.call(n, i);
				});
			}, e.prototype.walkIds = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.ID) return r.call(n, i);
				});
			}, e.prototype.walkNesting = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.NESTING) return r.call(n, i);
				});
			}, e.prototype.walkPseudos = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.PSEUDO) return r.call(n, i);
				});
			}, e.prototype.walkTags = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.TAG) return r.call(n, i);
				});
			}, e.prototype.walkUniversals = function(r) {
				var n = this;
				return this.walk(function(i) {
					if (i.type === te.UNIVERSAL) return r.call(n, i);
				});
			}, e.prototype.split = function(r) {
				var n = this, i = [];
				return this.reduce(function(o, u, a) {
					var c = r.call(n, u);
					return i.push(u), c ? (o.push(i), i = []) : a === n.length - 1 && o.push(i), o;
				}, []);
			}, e.prototype.map = function(r) {
				return this.nodes.map(r);
			}, e.prototype.reduce = function(r, n) {
				return this.nodes.reduce(r, n);
			}, e.prototype.every = function(r) {
				return this.nodes.every(r);
			}, e.prototype.some = function(r) {
				return this.nodes.some(r);
			}, e.prototype.filter = function(r) {
				return this.nodes.filter(r);
			}, e.prototype.sort = function(r) {
				return this.nodes.sort(r);
			}, e.prototype.toString = function() {
				return this.map(String).join("");
			}, ah(e, [
				{
					key: "first",
					get: function() {
						return this.at(0);
					}
				},
				{
					key: "last",
					get: function() {
						return this.at(this.length - 1);
					}
				},
				{
					key: "length",
					get: function() {
						return this.nodes.length;
					}
				}
			]), e;
		})(lh.default);
		Va.exports = mr.default;
	});
	ja = w((yr, za) => {
		"use strict";
		yr.__esModule = !0;
		var wh = xh(dr()), vh = M();
		function xh(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function _h(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function bh(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Eh(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		yr.default = (function(t) {
			Eh(e, t);
			function e(s) {
				_h(this, e);
				var r = bh(this, t.call(this, s));
				return r.type = vh.ROOT, r;
			}
			return e.prototype.toString = function() {
				var r = this.reduce(function(n, i) {
					var o = String(i);
					return o ? n + o + "," : "";
				}, "").slice(0, -1);
				return this.trailingComma ? r + "," : r;
			}, e;
		})(wh.default);
		za.exports = yr.default;
	});
	Qa = w((gr, Ha) => {
		"use strict";
		gr.__esModule = !0;
		var kh = Ah(dr()), Oh = M();
		function Ah(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Ch(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Nh(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Ph(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		gr.default = (function(t) {
			Ph(e, t);
			function e(s) {
				Ch(this, e);
				var r = Nh(this, t.call(this, s));
				return r.type = Oh.SELECTOR, r;
			}
			return e;
		})(kh.default);
		Ha.exports = gr.default;
	});
	je = w((wr, Ka) => {
		"use strict";
		wr.__esModule = !0;
		var Ih = (function() {
			function t(e, s) {
				for (var r = 0; r < s.length; r++) {
					var n = s[r];
					n.enumerable = n.enumerable || !1, n.configurable = !0, "value" in n && (n.writable = !0), Object.defineProperty(e, n.key, n);
				}
			}
			return function(e, s, r) {
				return s && t(e.prototype, s), r && t(e, r), e;
			};
		})(), qh = Dh(Ce());
		function Dh(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Mh(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Bh(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Uh(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		wr.default = (function(t) {
			Uh(e, t);
			function e() {
				return Mh(this, e), Bh(this, t.apply(this, arguments));
			}
			return e.prototype.toString = function() {
				return [
					this.spaces.before,
					this.ns,
					String(this.value),
					this.spaces.after
				].join("");
			}, Ih(e, [{
				key: "ns",
				get: function() {
					var r = this.namespace;
					return r ? (typeof r == "string" ? r : "") + "|" : "";
				}
			}]), e;
		})(qh.default);
		Ka.exports = wr.default;
	});
	Ja = w((vr, Xa) => {
		"use strict";
		vr.__esModule = !0;
		var $h = Yh(je()), Gh = M();
		function Yh(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Vh(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function zh(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function jh(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		vr.default = (function(t) {
			jh(e, t);
			function e(s) {
				Vh(this, e);
				var r = zh(this, t.call(this, s));
				return r.type = Gh.CLASS, r;
			}
			return e.prototype.toString = function() {
				return [
					this.spaces.before,
					this.ns,
					"." + this.value,
					this.spaces.after
				].join("");
			}, e;
		})($h.default);
		Xa.exports = vr.default;
	});
	eu = w((xr, Za) => {
		"use strict";
		xr.__esModule = !0;
		var Kh = Jh(Ce()), Xh = M();
		function Jh(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Zh(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function em(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function tm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		xr.default = (function(t) {
			tm(e, t);
			function e(s) {
				Zh(this, e);
				var r = em(this, t.call(this, s));
				return r.type = Xh.COMMENT, r;
			}
			return e;
		})(Kh.default);
		Za.exports = xr.default;
	});
	ru = w((_r, tu) => {
		"use strict";
		_r.__esModule = !0;
		var nm = om(je()), im = M();
		function om(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function am(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function um(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function lm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		_r.default = (function(t) {
			lm(e, t);
			function e(s) {
				am(this, e);
				var r = um(this, t.call(this, s));
				return r.type = im.ID, r;
			}
			return e.prototype.toString = function() {
				return [
					this.spaces.before,
					this.ns,
					"#" + this.value,
					this.spaces.after
				].join("");
			}, e;
		})(nm.default);
		tu.exports = _r.default;
	});
	nu = w((br, su) => {
		"use strict";
		br.__esModule = !0;
		var pm = mm(je()), hm = M();
		function mm(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function dm(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function ym(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function gm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		br.default = (function(t) {
			gm(e, t);
			function e(s) {
				dm(this, e);
				var r = ym(this, t.call(this, s));
				return r.type = hm.TAG, r;
			}
			return e;
		})(pm.default);
		su.exports = br.default;
	});
	ou = w((Er, iu) => {
		"use strict";
		Er.__esModule = !0;
		var xm = bm(Ce()), _m = M();
		function bm(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Em(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Sm(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Tm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		Er.default = (function(t) {
			Tm(e, t);
			function e(s) {
				Em(this, e);
				var r = Sm(this, t.call(this, s));
				return r.type = _m.STRING, r;
			}
			return e;
		})(xm.default);
		iu.exports = Er.default;
	});
	uu = w((Sr, au) => {
		"use strict";
		Sr.__esModule = !0;
		var Am = Nm(dr()), Cm = M();
		function Nm(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Pm(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Rm(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Im(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		Sr.default = (function(t) {
			Im(e, t);
			function e(s) {
				Pm(this, e);
				var r = Rm(this, t.call(this, s));
				return r.type = Cm.PSEUDO, r;
			}
			return e.prototype.toString = function() {
				var r = this.length ? "(" + this.map(String).join(",") + ")" : "";
				return [
					this.spaces.before,
					String(this.value),
					r,
					this.spaces.after
				].join("");
			}, e;
		})(Am.default);
		au.exports = Sr.default;
	});
	cu = w((Tr, lu) => {
		"use strict";
		Tr.__esModule = !0;
		var Dm = Bm(je()), Mm = M();
		function Bm(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function Um(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Fm(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Wm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		Tr.default = (function(t) {
			Wm(e, t);
			function e(s) {
				Um(this, e);
				var r = Fm(this, t.call(this, s));
				return r.type = Mm.ATTRIBUTE, r.raws = {}, r;
			}
			return e.prototype.toString = function() {
				var r = [
					this.spaces.before,
					"[",
					this.ns,
					this.attribute
				];
				return this.operator && r.push(this.operator), this.value && r.push(this.value), this.raws.insensitive ? r.push(this.raws.insensitive) : this.insensitive && r.push(" i"), r.push("]"), r.concat(this.spaces.after).join("");
			}, e;
		})(Dm.default);
		lu.exports = Tr.default;
	});
	pu = w((kr, fu) => {
		"use strict";
		kr.__esModule = !0;
		var Ym = zm(je()), Vm = M();
		function zm(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function jm(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function Hm(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function Qm(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		kr.default = (function(t) {
			Qm(e, t);
			function e(s) {
				jm(this, e);
				var r = Hm(this, t.call(this, s));
				return r.type = Vm.UNIVERSAL, r.value = "*", r;
			}
			return e;
		})(Ym.default);
		fu.exports = kr.default;
	});
	mu = w((Or, hu) => {
		"use strict";
		Or.__esModule = !0;
		var Jm = ed(Ce()), Zm = M();
		function ed(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function td(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function rd(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function sd(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		Or.default = (function(t) {
			sd(e, t);
			function e(s) {
				td(this, e);
				var r = rd(this, t.call(this, s));
				return r.type = Zm.COMBINATOR, r;
			}
			return e;
		})(Jm.default);
		hu.exports = Or.default;
	});
	yu = w((Ar, du) => {
		"use strict";
		Ar.__esModule = !0;
		var od = ud(Ce()), ad = M();
		function ud(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function ld(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		function cd(t, e) {
			if (!t) throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
			return e && (typeof e == "object" || typeof e == "function") ? e : t;
		}
		function fd(t, e) {
			if (typeof e != "function" && e !== null) throw new TypeError("Super expression must either be null or a function, not " + typeof e);
			t.prototype = Object.create(e && e.prototype, { constructor: {
				value: t,
				enumerable: !1,
				writable: !0,
				configurable: !0
			} }), e && (Object.setPrototypeOf ? Object.setPrototypeOf(t, e) : t.__proto__ = e);
		}
		Ar.default = (function(t) {
			fd(e, t);
			function e(s) {
				ld(this, e);
				var r = cd(this, t.call(this, s));
				return r.type = ad.NESTING, r.value = "&", r;
			}
			return e;
		})(od.default);
		du.exports = Ar.default;
	});
	wu = w((Cr, gu) => {
		"use strict";
		Cr.__esModule = !0;
		Cr.default = hd;
		function hd(t) {
			return t.sort(function(e, s) {
				return e - s;
			});
		}
		gu.exports = Cr.default;
	});
	Ou = w((Rr, ku) => {
		"use strict";
		Rr.__esModule = !0;
		Rr.default = Sd;
		var vu = 39, md = 34, Xs = 92, xu = 47, St = 10, Js = 32, Zs = 12, en = 9, tn = 13, _u = 43, bu = 62, Eu = 126, Su = 124, dd = 44, yd = 40, gd = 41, wd = 91, vd = 93, xd = 59, Tu = 42, _d = 58, bd = 38, Ed = 64, Nr = /[ \n\t\r\{\(\)'"\\;/]/g, Pr = /[ \n\t\r\(\)\*:;@!&'"\+\|~>,\[\]\\]|\/(?=\*)/g;
		function Sd(t) {
			for (var e = [], s = t.css.valueOf(), r = void 0, n = void 0, i = void 0, o = void 0, u = void 0, a = void 0, c = void 0, f = void 0, h = void 0, l = void 0, d = void 0, x = s.length, m = -1, p = 1, y = 0, g = function(C, q) {
				if (t.safe) s += q, n = s.length - 1;
				else throw t.error("Unclosed " + C, p, y - m, y);
			}; y < x;) {
				switch (r = s.charCodeAt(y), r === St && (m = y, p += 1), r) {
					case St:
					case Js:
					case en:
					case tn:
					case Zs:
						n = y;
						do
							n += 1, r = s.charCodeAt(n), r === St && (m = n, p += 1);
						while (r === Js || r === St || r === en || r === tn || r === Zs);
						e.push([
							"space",
							s.slice(y, n),
							p,
							y - m,
							y
						]), y = n - 1;
						break;
					case _u:
					case bu:
					case Eu:
					case Su:
						n = y;
						do
							n += 1, r = s.charCodeAt(n);
						while (r === _u || r === bu || r === Eu || r === Su);
						e.push([
							"combinator",
							s.slice(y, n),
							p,
							y - m,
							y
						]), y = n - 1;
						break;
					case Tu:
						e.push([
							"*",
							"*",
							p,
							y - m,
							y
						]);
						break;
					case bd:
						e.push([
							"&",
							"&",
							p,
							y - m,
							y
						]);
						break;
					case dd:
						e.push([
							",",
							",",
							p,
							y - m,
							y
						]);
						break;
					case wd:
						e.push([
							"[",
							"[",
							p,
							y - m,
							y
						]);
						break;
					case vd:
						e.push([
							"]",
							"]",
							p,
							y - m,
							y
						]);
						break;
					case _d:
						e.push([
							":",
							":",
							p,
							y - m,
							y
						]);
						break;
					case xd:
						e.push([
							";",
							";",
							p,
							y - m,
							y
						]);
						break;
					case yd:
						e.push([
							"(",
							"(",
							p,
							y - m,
							y
						]);
						break;
					case gd:
						e.push([
							")",
							")",
							p,
							y - m,
							y
						]);
						break;
					case vu:
					case md:
						i = r === vu ? "'" : "\"", n = y;
						do
							for (l = !1, n = s.indexOf(i, n + 1), n === -1 && g("quote", i), d = n; s.charCodeAt(d - 1) === Xs;) d -= 1, l = !l;
						while (l);
						e.push([
							"string",
							s.slice(y, n + 1),
							p,
							y - m,
							p,
							n - m,
							y
						]), y = n;
						break;
					case Ed:
						Nr.lastIndex = y + 1, Nr.test(s), Nr.lastIndex === 0 ? n = s.length - 1 : n = Nr.lastIndex - 2, e.push([
							"at-word",
							s.slice(y, n + 1),
							p,
							y - m,
							p,
							n - m,
							y
						]), y = n;
						break;
					case Xs:
						for (n = y, c = !0; s.charCodeAt(n + 1) === Xs;) n += 1, c = !c;
						r = s.charCodeAt(n + 1), c && r !== xu && r !== Js && r !== St && r !== en && r !== tn && r !== Zs && (n += 1), e.push([
							"word",
							s.slice(y, n + 1),
							p,
							y - m,
							p,
							n - m,
							y
						]), y = n;
						break;
					default:
						r === xu && s.charCodeAt(y + 1) === Tu ? (n = s.indexOf("*/", y + 2) + 1, n === 0 && g("comment", "*/"), a = s.slice(y, n + 1), o = a.split(`
`), u = o.length - 1, u > 0 ? (f = p + u, h = n - o[u].length) : (f = p, h = m), e.push([
							"comment",
							a,
							p,
							y - m,
							f,
							n - h,
							y
						]), m = h, p = f, y = n) : (Pr.lastIndex = y + 1, Pr.test(s), Pr.lastIndex === 0 ? n = s.length - 1 : n = Pr.lastIndex - 2, e.push([
							"word",
							s.slice(y, n + 1),
							p,
							y - m,
							p,
							n - m,
							y
						]), y = n);
						break;
				}
				y++;
			}
			return e;
		}
		ku.exports = Rr.default;
	});
	Nu = w((Ir, Cu) => {
		"use strict";
		Ir.__esModule = !0;
		var Td = (function() {
			function t(e, s) {
				for (var r = 0; r < s.length; r++) {
					var n = s[r];
					n.enumerable = n.enumerable || !1, n.configurable = !0, "value" in n && (n.writable = !0), Object.defineProperty(e, n.key, n);
				}
			}
			return function(e, s, r) {
				return s && t(e.prototype, s), r && t(e, r), e;
			};
		})(), Od = L(Hs()), rn = L(Qs()), Nd = L(Ks()), Rd = L(ja()), sn = L(Qa()), qd = L(Ja()), Md = L(eu()), Ud = L(ru()), Wd = L(nu()), Gd = L(ou()), Vd = L(uu()), jd = L(cu()), Qd = L(pu()), Xd = L(mu()), Zd = L(yu()), ty = L(wu()), Au = L(Ou()), ny = iy(M());
		function iy(t) {
			if (t && t.__esModule) return t;
			var e = {};
			if (t != null) for (var s in t) Object.prototype.hasOwnProperty.call(t, s) && (e[s] = t[s]);
			return e.default = t, e;
		}
		function L(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function oy(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		Ir.default = (function() {
			function t(e) {
				oy(this, t), this.input = e, this.lossy = e.options.lossless === !1, this.position = 0, this.root = new Rd.default();
				var s = new sn.default();
				return this.root.append(s), this.current = s, this.lossy ? this.tokens = (0, Au.default)({
					safe: e.safe,
					css: e.css.trim()
				}) : this.tokens = (0, Au.default)(e), this.loop();
			}
			return t.prototype.attribute = function() {
				var s = "", r = void 0, n = this.currToken;
				for (this.position++; this.position < this.tokens.length && this.currToken[0] !== "]";) s += this.tokens[this.position][1], this.position++;
				this.position === this.tokens.length && !~s.indexOf("]") && this.error("Expected a closing square bracket.");
				var i = s.split(/((?:[*~^$|]?=))([^]*)/), o = i[0].split(/(\|)/g), u = {
					operator: i[1],
					value: i[2],
					source: {
						start: {
							line: n[2],
							column: n[3]
						},
						end: {
							line: this.currToken[2],
							column: this.currToken[3]
						}
					},
					sourceIndex: n[4]
				};
				if (o.length > 1 ? (o[0] === "" && (o[0] = !0), u.attribute = this.parseValue(o[2]), u.namespace = this.parseNamespace(o[0])) : u.attribute = this.parseValue(i[0]), r = new jd.default(u), i[2]) {
					var a = i[2].split(/(\s+i\s*?)$/), c = a[0].trim();
					r.value = this.lossy ? c : a[0], a[1] && (r.insensitive = !0, this.lossy || (r.raws.insensitive = a[1])), r.quoted = c[0] === "'" || c[0] === "\"", r.raws.unquoted = r.quoted ? c.slice(1, -1) : c;
				}
				this.newNode(r), this.position++;
			}, t.prototype.combinator = function() {
				if (this.currToken[1] === "|") return this.namespace();
				for (var s = new Xd.default({
					value: "",
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[2],
							column: this.currToken[3]
						}
					},
					sourceIndex: this.currToken[4]
				}); this.position < this.tokens.length && this.currToken && (this.currToken[0] === "space" || this.currToken[0] === "combinator");) this.nextToken && this.nextToken[0] === "combinator" ? (s.spaces.before = this.parseSpace(this.currToken[1]), s.source.start.line = this.nextToken[2], s.source.start.column = this.nextToken[3], s.source.end.column = this.nextToken[3], s.source.end.line = this.nextToken[2], s.sourceIndex = this.nextToken[4]) : this.prevToken && this.prevToken[0] === "combinator" ? s.spaces.after = this.parseSpace(this.currToken[1]) : this.currToken[0] === "combinator" ? s.value = this.currToken[1] : this.currToken[0] === "space" && (s.value = this.parseSpace(this.currToken[1], " ")), this.position++;
				return this.newNode(s);
			}, t.prototype.comma = function() {
				if (this.position === this.tokens.length - 1) {
					this.root.trailingComma = !0, this.position++;
					return;
				}
				var s = new sn.default();
				this.current.parent.append(s), this.current = s, this.position++;
			}, t.prototype.comment = function() {
				var s = new Md.default({
					value: this.currToken[1],
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[4],
							column: this.currToken[5]
						}
					},
					sourceIndex: this.currToken[6]
				});
				this.newNode(s), this.position++;
			}, t.prototype.error = function(s) {
				throw new this.input.error(s);
			}, t.prototype.missingBackslash = function() {
				return this.error("Expected a backslash preceding the semicolon.");
			}, t.prototype.missingParenthesis = function() {
				return this.error("Expected opening parenthesis.");
			}, t.prototype.missingSquareBracket = function() {
				return this.error("Expected opening square bracket.");
			}, t.prototype.namespace = function() {
				var s = this.prevToken && this.prevToken[1] || !0;
				if (this.nextToken[0] === "word") return this.position++, this.word(s);
				if (this.nextToken[0] === "*") return this.position++, this.universal(s);
			}, t.prototype.nesting = function() {
				this.newNode(new Zd.default({
					value: this.currToken[1],
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[2],
							column: this.currToken[3]
						}
					},
					sourceIndex: this.currToken[4]
				})), this.position++;
			}, t.prototype.parentheses = function() {
				var s = this.current.last;
				if (s && s.type === ny.PSEUDO) {
					var r = new sn.default(), n = this.current;
					s.append(r), this.current = r;
					var i = 1;
					for (this.position++; this.position < this.tokens.length && i;) this.currToken[0] === "(" && i++, this.currToken[0] === ")" && i--, i ? this.parse() : (r.parent.source.end.line = this.currToken[2], r.parent.source.end.column = this.currToken[3], this.position++);
					i && this.error("Expected closing parenthesis."), this.current = n;
				} else {
					var o = 1;
					for (this.position++, s.value += "("; this.position < this.tokens.length && o;) this.currToken[0] === "(" && o++, this.currToken[0] === ")" && o--, s.value += this.parseParenthesisToken(this.currToken), this.position++;
					o && this.error("Expected closing parenthesis.");
				}
			}, t.prototype.pseudo = function() {
				for (var s = this, r = "", n = this.currToken; this.currToken && this.currToken[0] === ":";) r += this.currToken[1], this.position++;
				if (!this.currToken) return this.error("Expected pseudo-class or pseudo-element");
				if (this.currToken[0] === "word") {
					var i = void 0;
					this.splitWord(!1, function(o, u) {
						r += o, i = new Vd.default({
							value: r,
							source: {
								start: {
									line: n[2],
									column: n[3]
								},
								end: {
									line: s.currToken[4],
									column: s.currToken[5]
								}
							},
							sourceIndex: n[4]
						}), s.newNode(i), u > 1 && s.nextToken && s.nextToken[0] === "(" && s.error("Misplaced parenthesis.");
					});
				} else this.error("Unexpected \"" + this.currToken[0] + "\" found.");
			}, t.prototype.space = function() {
				var s = this.currToken;
				this.position === 0 || this.prevToken[0] === "," || this.prevToken[0] === "(" ? (this.spaces = this.parseSpace(s[1]), this.position++) : this.position === this.tokens.length - 1 || this.nextToken[0] === "," || this.nextToken[0] === ")" ? (this.current.last.spaces.after = this.parseSpace(s[1]), this.position++) : this.combinator();
			}, t.prototype.string = function() {
				var s = this.currToken;
				this.newNode(new Gd.default({
					value: this.currToken[1],
					source: {
						start: {
							line: s[2],
							column: s[3]
						},
						end: {
							line: s[4],
							column: s[5]
						}
					},
					sourceIndex: s[6]
				})), this.position++;
			}, t.prototype.universal = function(s) {
				var r = this.nextToken;
				if (r && r[1] === "|") return this.position++, this.namespace();
				this.newNode(new Qd.default({
					value: this.currToken[1],
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[2],
							column: this.currToken[3]
						}
					},
					sourceIndex: this.currToken[4]
				}), s), this.position++;
			}, t.prototype.splitWord = function(s, r) {
				for (var n = this, i = this.nextToken, o = this.currToken[1]; i && i[0] === "word";) {
					this.position++;
					var u = this.currToken[1];
					if (o += u, u.lastIndexOf("\\") === u.length - 1) {
						var a = this.nextToken;
						a && a[0] === "space" && (o += this.parseSpace(a[1], " "), this.position++);
					}
					i = this.nextToken;
				}
				var c = (0, rn.default)(o, "."), f = (0, rn.default)(o, "#"), h = (0, rn.default)(o, "#{");
				h.length && (f = f.filter(function(d) {
					return !~h.indexOf(d);
				}));
				var l = (0, ty.default)((0, Nd.default)((0, Od.default)([
					[0],
					c,
					f
				])));
				l.forEach(function(d, x) {
					var m = l[x + 1] || o.length, p = o.slice(d, m);
					if (x === 0 && r) return r.call(n, p, l.length);
					var y = void 0;
					~c.indexOf(d) ? y = new qd.default({
						value: p.slice(1),
						source: {
							start: {
								line: n.currToken[2],
								column: n.currToken[3] + d
							},
							end: {
								line: n.currToken[4],
								column: n.currToken[3] + (m - 1)
							}
						},
						sourceIndex: n.currToken[6] + l[x]
					}) : ~f.indexOf(d) ? y = new Ud.default({
						value: p.slice(1),
						source: {
							start: {
								line: n.currToken[2],
								column: n.currToken[3] + d
							},
							end: {
								line: n.currToken[4],
								column: n.currToken[3] + (m - 1)
							}
						},
						sourceIndex: n.currToken[6] + l[x]
					}) : y = new Wd.default({
						value: p,
						source: {
							start: {
								line: n.currToken[2],
								column: n.currToken[3] + d
							},
							end: {
								line: n.currToken[4],
								column: n.currToken[3] + (m - 1)
							}
						},
						sourceIndex: n.currToken[6] + l[x]
					}), n.newNode(y, s);
				}), this.position++;
			}, t.prototype.word = function(s) {
				var r = this.nextToken;
				return r && r[1] === "|" ? (this.position++, this.namespace()) : this.splitWord(s);
			}, t.prototype.loop = function() {
				for (; this.position < this.tokens.length;) this.parse(!0);
				return this.root;
			}, t.prototype.parse = function(s) {
				switch (this.currToken[0]) {
					case "space":
						this.space();
						break;
					case "comment":
						this.comment();
						break;
					case "(":
						this.parentheses();
						break;
					case ")":
						s && this.missingParenthesis();
						break;
					case "[":
						this.attribute();
						break;
					case "]":
						this.missingSquareBracket();
						break;
					case "at-word":
					case "word":
						this.word();
						break;
					case ":":
						this.pseudo();
						break;
					case ";":
						this.missingBackslash();
						break;
					case ",":
						this.comma();
						break;
					case "*":
						this.universal();
						break;
					case "&":
						this.nesting();
						break;
					case "combinator":
						this.combinator();
						break;
					case "string":
						this.string();
						break;
				}
			}, t.prototype.parseNamespace = function(s) {
				if (this.lossy && typeof s == "string") {
					var r = s.trim();
					return r.length ? r : !0;
				}
				return s;
			}, t.prototype.parseSpace = function(s, r) {
				return this.lossy ? r || "" : s;
			}, t.prototype.parseValue = function(s) {
				return this.lossy && s && typeof s == "string" ? s.trim() : s;
			}, t.prototype.parseParenthesisToken = function(s) {
				return this.lossy ? s[0] === "space" ? this.parseSpace(s[1], " ") : this.parseValue(s[1]) : s[1];
			}, t.prototype.newNode = function(s, r) {
				return r && (s.namespace = this.parseNamespace(r)), this.spaces && (s.spaces.before = this.spaces, this.spaces = ""), this.current.append(s);
			}, Td(t, [
				{
					key: "currToken",
					get: function() {
						return this.tokens[this.position];
					}
				},
				{
					key: "nextToken",
					get: function() {
						return this.tokens[this.position + 1];
					}
				},
				{
					key: "prevToken",
					get: function() {
						return this.tokens[this.position - 1];
					}
				}
			]), t;
		})();
		Cu.exports = Ir.default;
	});
	Ru = w((Lr, Pu) => {
		"use strict";
		Lr.__esModule = !0;
		var uy = (function() {
			function t(e, s) {
				for (var r = 0; r < s.length; r++) {
					var n = s[r];
					n.enumerable = n.enumerable || !1, n.configurable = !0, "value" in n && (n.writable = !0), Object.defineProperty(e, n.key, n);
				}
			}
			return function(e, s, r) {
				return s && t(e.prototype, s), r && t(e, r), e;
			};
		})(), cy = fy(Nu());
		function fy(t) {
			return t && t.__esModule ? t : { default: t };
		}
		function py(t, e) {
			if (!(t instanceof e)) throw new TypeError("Cannot call a class as a function");
		}
		Lr.default = (function() {
			function t(e) {
				return py(this, t), this.func = e || function() {}, this;
			}
			return t.prototype.process = function(s) {
				var r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, n = new cy.default({
					css: s,
					error: function(o) {
						throw new Error(o);
					},
					options: r
				});
				return this.res = n, this.func(n), this;
			}, uy(t, [{
				key: "result",
				get: function() {
					return String(this.res);
				}
			}]), t;
		})();
		Pu.exports = Lr.default;
	});
	j = w((fb, Lu) => {
		"use strict";
		var nn = function(t, e) {
			let s = new t.constructor();
			for (let r in t) {
				if (!t.hasOwnProperty(r)) continue;
				let n = t[r], i = typeof n;
				r === "parent" && i === "object" ? e && (s[r] = e) : r === "source" ? s[r] = n : n instanceof Array ? s[r] = n.map((o) => nn(o, s)) : r !== "before" && r !== "after" && r !== "between" && r !== "semicolon" && (i === "object" && n !== null && (n = nn(n)), s[r] = n);
			}
			return s;
		};
		Lu.exports = class {
			constructor(e) {
				e = e || {}, this.raws = {
					before: "",
					after: ""
				};
				for (let s in e) this[s] = e[s];
			}
			remove() {
				return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
			}
			toString() {
				return [
					this.raws.before,
					String(this.value),
					this.raws.after
				].join("");
			}
			clone(e) {
				e = e || {};
				let s = nn(this);
				for (let r in e) s[r] = e[r];
				return s;
			}
			cloneBefore(e) {
				e = e || {};
				let s = this.clone(e);
				return this.parent.insertBefore(this, s), s;
			}
			cloneAfter(e) {
				e = e || {};
				let s = this.clone(e);
				return this.parent.insertAfter(this, s), s;
			}
			replaceWith() {
				let e = Array.prototype.slice.call(arguments);
				if (this.parent) {
					for (let s of e) this.parent.insertBefore(this, s);
					this.remove();
				}
				return this;
			}
			moveTo(e) {
				return this.cleanRaws(this.root() === e.root()), this.remove(), e.append(this), this;
			}
			moveBefore(e) {
				return this.cleanRaws(this.root() === e.root()), this.remove(), e.parent.insertBefore(e, this), this;
			}
			moveAfter(e) {
				return this.cleanRaws(this.root() === e.root()), this.remove(), e.parent.insertAfter(e, this), this;
			}
			next() {
				let e = this.parent.index(this);
				return this.parent.nodes[e + 1];
			}
			prev() {
				let e = this.parent.index(this);
				return this.parent.nodes[e - 1];
			}
			toJSON() {
				let e = {};
				for (let s in this) {
					if (!this.hasOwnProperty(s) || s === "parent") continue;
					let r = this[s];
					r instanceof Array ? e[s] = r.map((n) => typeof n == "object" && n.toJSON ? n.toJSON() : n) : typeof r == "object" && r.toJSON ? e[s] = r.toJSON() : e[s] = r;
				}
				return e;
			}
			root() {
				let e = this;
				for (; e.parent;) e = e.parent;
				return e;
			}
			cleanRaws(e) {
				delete this.raws.before, delete this.raws.after, e || delete this.raws.between;
			}
			positionInside(e) {
				let s = this.toString(), r = this.source.start.column, n = this.source.start.line;
				for (let i = 0; i < e; i++) s[i] === `
` ? (r = 1, n += 1) : r += 1;
				return {
					line: n,
					column: r
				};
			}
			positionBy(e) {
				let s = this.source.start;
				if (Object(e).index) s = this.positionInside(e.index);
				else if (Object(e).word) {
					let r = this.toString().indexOf(e.word);
					r !== -1 && (s = this.positionInside(r));
				}
				return s;
			}
		};
	});
	U = w((pb, qu) => {
		"use strict";
		var dy = j(), He = class extends dy {
			constructor(e) {
				super(e), this.nodes || (this.nodes = []);
			}
			push(e) {
				return e.parent = this, this.nodes.push(e), this;
			}
			each(e) {
				this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach += 1;
				let s = this.lastEach, r, n;
				if (this.indexes[s] = 0, !!this.nodes) {
					for (; this.indexes[s] < this.nodes.length && (r = this.indexes[s], n = e(this.nodes[r], r), n !== !1);) this.indexes[s] += 1;
					return delete this.indexes[s], n;
				}
			}
			walk(e) {
				return this.each((s, r) => {
					let n = e(s, r);
					return n !== !1 && s.walk && (n = s.walk(e)), n;
				});
			}
			walkType(e, s) {
				if (!e || !s) throw new Error("Parameters {type} and {callback} are required.");
				let r = typeof e == "function";
				return this.walk((n, i) => {
					if (r && n instanceof e || !r && n.type === e) return s.call(this, n, i);
				});
			}
			append(e) {
				return e.parent = this, this.nodes.push(e), this;
			}
			prepend(e) {
				return e.parent = this, this.nodes.unshift(e), this;
			}
			cleanRaws(e) {
				if (super.cleanRaws(e), this.nodes) for (let s of this.nodes) s.cleanRaws(e);
			}
			insertAfter(e, s) {
				let r = this.index(e), n;
				this.nodes.splice(r + 1, 0, s);
				for (let i in this.indexes) n = this.indexes[i], r <= n && (this.indexes[i] = n + this.nodes.length);
				return this;
			}
			insertBefore(e, s) {
				let r = this.index(e), n;
				this.nodes.splice(r, 0, s);
				for (let i in this.indexes) n = this.indexes[i], r <= n && (this.indexes[i] = n + this.nodes.length);
				return this;
			}
			removeChild(e) {
				e = this.index(e), this.nodes[e].parent = void 0, this.nodes.splice(e, 1);
				let s;
				for (let r in this.indexes) s = this.indexes[r], s >= e && (this.indexes[r] = s - 1);
				return this;
			}
			removeAll() {
				for (let e of this.nodes) e.parent = void 0;
				return this.nodes = [], this;
			}
			every(e) {
				return this.nodes.every(e);
			}
			some(e) {
				return this.nodes.some(e);
			}
			index(e) {
				return typeof e == "number" ? e : this.nodes.indexOf(e);
			}
			get first() {
				if (this.nodes) return this.nodes[0];
			}
			get last() {
				if (this.nodes) return this.nodes[this.nodes.length - 1];
			}
			toString() {
				let e = this.nodes.map(String).join("");
				return this.value && (e = this.value + e), this.raws.before && (e = this.raws.before + e), this.raws.after && (e += this.raws.after), e;
			}
		};
		He.registerWalker = (t) => {
			let e = "walk" + t.name;
			e.lastIndexOf("s") !== e.length - 1 && (e += "s"), !He.prototype[e] && (He.prototype[e] = function(s) {
				return this.walkType(t, s);
			});
		};
		qu.exports = He;
	});
	Mu = w((mb, Du) => {
		"use strict";
		var yy = U();
		Du.exports = class extends yy {
			constructor(e) {
				super(e), this.type = "root";
			}
		};
	});
	Uu = w((yb, Bu) => {
		"use strict";
		var gy = U();
		Bu.exports = class extends gy {
			constructor(e) {
				super(e), this.type = "value", this.unbalanced = 0;
			}
		};
	});
	$u = w((gb, Wu) => {
		"use strict";
		var Fu = U(), qr = class extends Fu {
			constructor(e) {
				super(e), this.type = "atword";
			}
			toString() {
				this.quoted && this.raws.quote;
				return [
					this.raws.before,
					"@",
					String.prototype.toString.call(this.value),
					this.raws.after
				].join("");
			}
		};
		Fu.registerWalker(qr);
		Wu.exports = qr;
	});
	Yu = w((wb, Gu) => {
		"use strict";
		var wy = U(), vy = j(), Dr = class extends vy {
			constructor(e) {
				super(e), this.type = "colon";
			}
		};
		wy.registerWalker(Dr);
		Gu.exports = Dr;
	});
	zu = w((vb, Vu) => {
		"use strict";
		var xy = U(), _y = j(), Mr = class extends _y {
			constructor(e) {
				super(e), this.type = "comma";
			}
		};
		xy.registerWalker(Mr);
		Vu.exports = Mr;
	});
	Hu = w((xb, ju) => {
		"use strict";
		var by = U(), Ey = j(), Br = class extends Ey {
			constructor(e) {
				super(e), this.type = "comment", this.inline = Object(e).inline || !1;
			}
			toString() {
				return [
					this.raws.before,
					this.inline ? "//" : "/*",
					String(this.value),
					this.inline ? "" : "*/",
					this.raws.after
				].join("");
			}
		};
		by.registerWalker(Br);
		ju.exports = Br;
	});
	Xu = w((_b, Ku) => {
		"use strict";
		var Qu = U(), Ur = class extends Qu {
			constructor(e) {
				super(e), this.type = "func", this.unbalanced = -1;
			}
		};
		Qu.registerWalker(Ur);
		Ku.exports = Ur;
	});
	Zu = w((bb, Ju) => {
		"use strict";
		var Sy = U(), Ty = j(), Fr = class extends Ty {
			constructor(e) {
				super(e), this.type = "number", this.unit = Object(e).unit || "";
			}
			toString() {
				return [
					this.raws.before,
					String(this.value),
					this.unit,
					this.raws.after
				].join("");
			}
		};
		Sy.registerWalker(Fr);
		Ju.exports = Fr;
	});
	tl = w((Eb, el) => {
		"use strict";
		var ky = U(), Oy = j(), Wr = class extends Oy {
			constructor(e) {
				super(e), this.type = "operator";
			}
		};
		ky.registerWalker(Wr);
		el.exports = Wr;
	});
	sl = w((Sb, rl) => {
		"use strict";
		var Ay = U(), Cy = j(), $r = class extends Cy {
			constructor(e) {
				super(e), this.type = "paren", this.parenType = "";
			}
		};
		Ay.registerWalker($r);
		rl.exports = $r;
	});
	il = w((Tb, nl) => {
		"use strict";
		var Ny = U(), Py = j(), Gr = class extends Py {
			constructor(e) {
				super(e), this.type = "string";
			}
			toString() {
				let e = this.quoted ? this.raws.quote : "";
				return [
					this.raws.before,
					e,
					this.value + "",
					e,
					this.raws.after
				].join("");
			}
		};
		Ny.registerWalker(Gr);
		nl.exports = Gr;
	});
	al = w((kb, ol) => {
		"use strict";
		var Ry = U(), Iy = j(), Yr = class extends Iy {
			constructor(e) {
				super(e), this.type = "word";
			}
		};
		Ry.registerWalker(Yr);
		ol.exports = Yr;
	});
	ll = w((Ob, ul) => {
		"use strict";
		var Ly = U(), qy = j(), Vr = class extends qy {
			constructor(e) {
				super(e), this.type = "unicode-range";
			}
		};
		Ly.registerWalker(Vr);
		ul.exports = Vr;
	});
	fl = w((Ab, cl) => {
		"use strict";
		var on = class extends Error {
			constructor(e) {
				super(e), this.name = this.constructor.name, this.message = e || "An error ocurred while tokzenizing.", typeof Error.captureStackTrace == "function" ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(e).stack;
			}
		};
		cl.exports = on;
	});
	ml = w((Cb, hl) => {
		"use strict";
		var zr = /[ \n\t\r\{\(\)'"\\;,/]/g, Dy = /[ \n\t\r\(\)\{\}\*:;@!&'"\+\|~>,\[\]\\]|\/(?=\*)/g, Qe = /[ \n\t\r\(\)\{\}\*:;@!&'"\-\+\|~>,\[\]\\]|\//g, My = /^[a-z0-9]/i, By = /^[a-f0-9?\-]/i, pl = fl();
		hl.exports = function(e, s) {
			s = s || {};
			let r = [], n = e.valueOf(), i = n.length, o = -1, u = 1, a = 0, c = 0, f = null, h, l, d, x, m, p, g, v, C, q, W;
			function se(k) {
				throw new pl(`Unclosed ${k} at line: ${u}, column: ${a - o}, token: ${a}`);
			}
			for (; a < i;) {
				switch (h = n.charCodeAt(a), h === 10 && (o = a, u += 1), h) {
					case 10:
					case 32:
					case 9:
					case 13:
					case 12:
						l = a;
						do
							l += 1, h = n.charCodeAt(l), h === 10 && (o = l, u += 1);
						while (h === 32 || h === 10 || h === 9 || h === 13 || h === 12);
						r.push([
							"space",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						break;
					case 58:
						l = a + 1, r.push([
							"colon",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						break;
					case 44:
						l = a + 1, r.push([
							"comma",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						break;
					case 123:
						r.push([
							"{",
							"{",
							u,
							a - o,
							u,
							l - o,
							a
						]);
						break;
					case 125:
						r.push([
							"}",
							"}",
							u,
							a - o,
							u,
							l - o,
							a
						]);
						break;
					case 40:
						c++, f = !f && c === 1 && r.length > 0 && r[r.length - 1][0] === "word" && r[r.length - 1][1] === "url", r.push([
							"(",
							"(",
							u,
							a - o,
							u,
							l - o,
							a
						]);
						break;
					case 41:
						c--, f = f && c > 0, r.push([
							")",
							")",
							u,
							a - o,
							u,
							l - o,
							a
						]);
						break;
					case 39:
					case 34:
						d = h === 39 ? "'" : "\"", l = a;
						do
							for (C = !1, l = n.indexOf(d, l + 1), l === -1 && se("quote", d), q = l; n.charCodeAt(q - 1) === 92;) q -= 1, C = !C;
						while (C);
						r.push([
							"string",
							n.slice(a, l + 1),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l;
						break;
					case 64:
						zr.lastIndex = a + 1, zr.test(n), zr.lastIndex === 0 ? l = n.length - 1 : l = zr.lastIndex - 2, r.push([
							"atword",
							n.slice(a, l + 1),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l;
						break;
					case 92:
						l = a, h = n.charCodeAt(l + 1), r.push([
							"word",
							n.slice(a, l + 1),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l;
						break;
					case 43:
					case 45:
					case 42:
						l = a + 1, W = n.slice(a + 1, l + 1);
						n.slice(a - 1, a);
						if (h === 45 && W.charCodeAt(0) === 45) {
							l++, r.push([
								"word",
								n.slice(a, l),
								u,
								a - o,
								u,
								l - o,
								a
							]), a = l - 1;
							break;
						}
						r.push([
							"operator",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						break;
					default:
						if (h === 47 && (n.charCodeAt(a + 1) === 42 || s.loose && !f && n.charCodeAt(a + 1) === 47)) {
							if (n.charCodeAt(a + 1) === 42) l = n.indexOf("*/", a + 2) + 1, l === 0 && se("comment", "*/");
							else {
								let S = n.indexOf(`
`, a + 2);
								l = S !== -1 ? S - 1 : i;
							}
							p = n.slice(a, l + 1), x = p.split(`
`), m = x.length - 1, m > 0 ? (g = u + m, v = l - x[m].length) : (g = u, v = o), r.push([
								"comment",
								p,
								u,
								a - o,
								g,
								l - v,
								a
							]), o = v, u = g, a = l;
						} else if (h === 35 && !My.test(n.slice(a + 1, a + 2))) l = a + 1, r.push([
							"#",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						else if ((h === 117 || h === 85) && n.charCodeAt(a + 1) === 43) {
							l = a + 2;
							do
								l += 1, h = n.charCodeAt(l);
							while (l < i && By.test(n.slice(l, l + 1)));
							r.push([
								"unicoderange",
								n.slice(a, l),
								u,
								a - o,
								u,
								l - o,
								a
							]), a = l - 1;
						} else if (h === 47) l = a + 1, r.push([
							"operator",
							n.slice(a, l),
							u,
							a - o,
							u,
							l - o,
							a
						]), a = l - 1;
						else {
							let b = Dy;
							if (h >= 48 && h <= 57 && (b = Qe), b.lastIndex = a + 1, b.test(n), b.lastIndex === 0 ? l = n.length - 1 : l = b.lastIndex - 2, b === Qe || h === 46) {
								let S = n.charCodeAt(l), fn = n.charCodeAt(l + 1), pn = n.charCodeAt(l + 2);
								(S === 101 || S === 69) && (fn === 45 || fn === 43) && pn >= 48 && pn <= 57 && (Qe.lastIndex = l + 2, Qe.test(n), Qe.lastIndex === 0 ? l = n.length - 1 : l = Qe.lastIndex - 2);
							}
							r.push([
								"word",
								n.slice(a, l + 1),
								u,
								a - o,
								u,
								l - o,
								a
							]), a = l;
						}
						break;
				}
				a++;
			}
			return r;
		};
	});
	yl = w((Nb, dl) => {
		"use strict";
		var an = class extends Error {
			constructor(e) {
				super(e), this.name = this.constructor.name, this.message = e || "An error ocurred while parsing.", typeof Error.captureStackTrace == "function" ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(e).stack;
			}
		};
		dl.exports = an;
	});
	xl = w((Rb, vl) => {
		"use strict";
		var Uy = Mu(), Fy = Uu(), Wy = $u(), $y = Yu(), Gy = zu(), Yy = Hu(), Vy = Xu(), zy = Zu(), jy = tl(), gl = sl(), Hy = il(), wl = al(), Qy = ll(), Ky = ml(), Xy = Hs(), Jy = Qs(), Zy = Ks(), eg = yl();
		function tg(t) {
			return t.sort((e, s) => e - s);
		}
		vl.exports = class {
			constructor(e, s) {
				let r = { loose: !1 };
				this.cache = [], this.input = e, this.options = Object.assign({}, r, s), this.position = 0, this.unbalanced = 0, this.root = new Uy();
				let n = new Fy();
				this.root.append(n), this.current = n, this.tokens = Ky(e, this.options);
			}
			parse() {
				return this.loop();
			}
			colon() {
				let e = this.currToken;
				this.newNode(new $y({
					value: e[1],
					source: {
						start: {
							line: e[2],
							column: e[3]
						},
						end: {
							line: e[4],
							column: e[5]
						}
					},
					sourceIndex: e[6]
				})), this.position++;
			}
			comma() {
				let e = this.currToken;
				this.newNode(new Gy({
					value: e[1],
					source: {
						start: {
							line: e[2],
							column: e[3]
						},
						end: {
							line: e[4],
							column: e[5]
						}
					},
					sourceIndex: e[6]
				})), this.position++;
			}
			comment() {
				let e = !1, s = this.currToken[1].replace(/\/\*|\*\//g, ""), r;
				this.options.loose && s.startsWith("//") && (s = s.substring(2), e = !0), r = new Yy({
					value: s,
					inline: e,
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[4],
							column: this.currToken[5]
						}
					},
					sourceIndex: this.currToken[6]
				}), this.newNode(r), this.position++;
			}
			error(e, s) {
				throw new eg(e + ` at line: ${s[2]}, column ${s[3]}`);
			}
			loop() {
				for (; this.position < this.tokens.length;) this.parseTokens();
				return !this.current.last && this.spaces ? this.current.raws.before += this.spaces : this.spaces && (this.current.last.raws.after += this.spaces), this.spaces = "", this.root;
			}
			operator() {
				let e = this.currToken[1], s;
				if (e === "+" || e === "-") {
					if (this.options.loose || this.position > 0 && (this.current.type === "func" && this.current.value === "calc" ? this.prevToken[0] !== "space" && this.prevToken[0] !== "(" ? this.error("Syntax Error", this.currToken) : this.nextToken[0] !== "space" && this.nextToken[0] !== "word" ? this.error("Syntax Error", this.currToken) : this.nextToken[0] === "word" && this.current.last.type !== "operator" && this.current.last.value !== "(" && this.error("Syntax Error", this.currToken) : (this.nextToken[0] === "space" || this.nextToken[0] === "operator" || this.prevToken[0] === "operator") && this.error("Syntax Error", this.currToken)), this.options.loose) {
						if ((!this.current.nodes.length || this.current.last && this.current.last.type === "operator") && this.nextToken[0] === "word") return this.word();
					} else if (this.nextToken[0] === "word") return this.word();
				}
				return s = new jy({
					value: this.currToken[1],
					source: {
						start: {
							line: this.currToken[2],
							column: this.currToken[3]
						},
						end: {
							line: this.currToken[2],
							column: this.currToken[3]
						}
					},
					sourceIndex: this.currToken[4]
				}), this.position++, this.newNode(s);
			}
			parseTokens() {
				switch (this.currToken[0]) {
					case "space":
						this.space();
						break;
					case "colon":
						this.colon();
						break;
					case "comma":
						this.comma();
						break;
					case "comment":
						this.comment();
						break;
					case "(":
						this.parenOpen();
						break;
					case ")":
						this.parenClose();
						break;
					case "atword":
					case "word":
						this.word();
						break;
					case "operator":
						this.operator();
						break;
					case "string":
						this.string();
						break;
					case "unicoderange":
						this.unicodeRange();
						break;
					default:
						this.word();
						break;
				}
			}
			parenOpen() {
				let e = 1, s = this.position + 1, r = this.currToken, n;
				for (; s < this.tokens.length && e;) {
					let i = this.tokens[s];
					i[0] === "(" && e++, i[0] === ")" && e--, s++;
				}
				if (e && this.error("Expected closing parenthesis", r), n = this.current.last, n && n.type === "func" && n.unbalanced < 0 && (n.unbalanced = 0, this.current = n), this.current.unbalanced++, this.newNode(new gl({
					value: r[1],
					source: {
						start: {
							line: r[2],
							column: r[3]
						},
						end: {
							line: r[4],
							column: r[5]
						}
					},
					sourceIndex: r[6]
				})), this.position++, this.current.type === "func" && this.current.unbalanced && this.current.value === "url" && this.currToken[0] !== "string" && this.currToken[0] !== ")" && !this.options.loose) {
					let i = this.nextToken, o = this.currToken[1], u = {
						line: this.currToken[2],
						column: this.currToken[3]
					};
					for (; i && i[0] !== ")" && this.current.unbalanced;) this.position++, o += this.currToken[1], i = this.nextToken;
					this.position !== this.tokens.length - 1 && (this.position++, this.newNode(new wl({
						value: o,
						source: {
							start: u,
							end: {
								line: this.currToken[4],
								column: this.currToken[5]
							}
						},
						sourceIndex: this.currToken[6]
					})));
				}
			}
			parenClose() {
				let e = this.currToken;
				this.newNode(new gl({
					value: e[1],
					source: {
						start: {
							line: e[2],
							column: e[3]
						},
						end: {
							line: e[4],
							column: e[5]
						}
					},
					sourceIndex: e[6]
				})), this.position++, !(this.position >= this.tokens.length - 1 && !this.current.unbalanced) && (this.current.unbalanced--, this.current.unbalanced < 0 && this.error("Expected opening parenthesis", e), !this.current.unbalanced && this.cache.length && (this.current = this.cache.pop()));
			}
			space() {
				let e = this.currToken;
				this.position === this.tokens.length - 1 || this.nextToken[0] === "," || this.nextToken[0] === ")" ? (this.current.last.raws.after += e[1], this.position++) : (this.spaces = e[1], this.position++);
			}
			unicodeRange() {
				let e = this.currToken;
				this.newNode(new Qy({
					value: e[1],
					source: {
						start: {
							line: e[2],
							column: e[3]
						},
						end: {
							line: e[4],
							column: e[5]
						}
					},
					sourceIndex: e[6]
				})), this.position++;
			}
			splitWord() {
				let e = this.nextToken, s = this.currToken[1], r = /^[\+\-]?((\d+(\.\d*)?)|(\.\d+))([eE][\+\-]?\d+)?/, n = /^(?!\#([a-z0-9]+))[\#\{\}]/gi, i, o;
				if (!n.test(s)) for (; e && e[0] === "word";) {
					this.position++;
					let u = this.currToken[1];
					s += u, e = this.nextToken;
				}
				i = Jy(s, "@"), o = tg(Zy(Xy([[0], i]))), o.forEach((u, a) => {
					let c = o[a + 1] || s.length, f = s.slice(u, c), h;
					if (~i.indexOf(u)) h = new Wy({
						value: f.slice(1),
						source: {
							start: {
								line: this.currToken[2],
								column: this.currToken[3] + u
							},
							end: {
								line: this.currToken[4],
								column: this.currToken[3] + (c - 1)
							}
						},
						sourceIndex: this.currToken[6] + o[a]
					});
					else if (r.test(this.currToken[1])) {
						let l = f.replace(r, "");
						h = new zy({
							value: f.replace(l, ""),
							source: {
								start: {
									line: this.currToken[2],
									column: this.currToken[3] + u
								},
								end: {
									line: this.currToken[4],
									column: this.currToken[3] + (c - 1)
								}
							},
							sourceIndex: this.currToken[6] + o[a],
							unit: l
						});
					} else h = new (e && e[0] === "(" ? Vy : wl)({
						value: f,
						source: {
							start: {
								line: this.currToken[2],
								column: this.currToken[3] + u
							},
							end: {
								line: this.currToken[4],
								column: this.currToken[3] + (c - 1)
							}
						},
						sourceIndex: this.currToken[6] + o[a]
					}), h.type === "word" ? (h.isHex = /^#(.+)/.test(f), h.isColor = /^#([0-9a-f]{3}|[0-9a-f]{4}|[0-9a-f]{6}|[0-9a-f]{8})$/i.test(f)) : this.cache.push(this.current);
					this.newNode(h);
				}), this.position++;
			}
			string() {
				let e = this.currToken, s = this.currToken[1], r = /^(\"|\')/, n = r.test(s), i = "", o;
				n && (i = s.match(r)[0], s = s.slice(1, s.length - 1)), o = new Hy({
					value: s,
					source: {
						start: {
							line: e[2],
							column: e[3]
						},
						end: {
							line: e[4],
							column: e[5]
						}
					},
					sourceIndex: e[6],
					quoted: n
				}), o.raws.quote = i, this.newNode(o), this.position++;
			}
			word() {
				return this.splitWord();
			}
			newNode(e) {
				return this.spaces && (e.raws.before += this.spaces, this.spaces = ""), this.current.append(e);
			}
			get currToken() {
				return this.tokens[this.position];
			}
			get nextToken() {
				return this.tokens[this.position + 1];
			}
			get prevToken() {
				return this.tokens[this.position - 1];
			}
		};
	});
	Ml = {};
	hn(Ml, {
		languages: () => Fi,
		options: () => $i,
		parsers: () => cn,
		printers: () => gg
	});
	Tt = (t, e) => (s, r, ...n) => s | 1 && r == null ? void 0 : (e.call(r) ?? r[t]).apply(r, n);
	Yl = String.prototype.replaceAll ?? function(t, e) {
		return t.global ? this.replace(t, e) : this.split(t).join(e);
	};
	T = Tt("replaceAll", function() {
		if (typeof this == "string") return Yl;
	});
	$ = Tt("at", function() {
		if (Array.isArray(this) || typeof this == "string") return zl;
	});
	Hl = () => {};
	G = Hl;
	Ke = "string";
	Xe = "array";
	kt = "cursor";
	ne = "indent";
	Pe = "align";
	Ot = "trim";
	ie = "group";
	oe = "fill";
	ge = "if-break";
	At = "indent-if-break";
	Re = "line-suffix";
	Ie = "line-suffix-boundary";
	H = "line";
	Ct = "label";
	Le = "break-parent";
	Nt = /* @__PURE__ */ new Set([
		kt,
		ne,
		Pe,
		Ot,
		ie,
		oe,
		ge,
		At,
		Re,
		Ie,
		H,
		Ct,
		Le
	]);
	ae = Ql;
	Kl = (t) => new Intl.ListFormat("en-US", { type: "disjunction" }).format(t);
	Kr = class extends Error {
		name = "InvalidDocError";
		constructor(e) {
			super(Xl(e)), this.doc = e;
		}
	};
	dn = Kr;
	F = G;
	we = G;
	xn = G;
	_n = G;
	ve = { type: Le };
	A = { type: H };
	I = {
		type: H,
		soft: !0
	};
	O = [{
		type: H,
		hard: !0
	}, ve];
	Xr = {
		type: H,
		hard: !0,
		literal: !0
	};
	vn = [Xr, ve];
	It = { type: Ie };
	le = tc;
	En = Object.freeze({
		character: "'",
		codePoint: 39
	});
	Sn = Object.freeze({
		character: "\"",
		codePoint: 34
	});
	rc = Object.freeze({
		preferred: En,
		alternate: Sn
	});
	sc = Object.freeze({
		preferred: Sn,
		alternate: En
	});
	nc = /\\(["'\\])|(["'])/g;
	On = ic;
	Lt = oc;
	Zr = class extends Error {
		name = "UnexpectedNodeError";
		constructor(e, s, r = "type") {
			super(`Unexpected ${s} node ${r}: ${JSON.stringify(e[r])}.`), this.node = e;
		}
	};
	An = Zr;
	Cn.getVisitorKeys = (t) => t.type === "css-root" ? ["frontMatter"] : [];
	Nn = Cn;
	Je = null;
	ac = 10;
	for (let t = 0; t <= ac; t++) Ze();
	Pn = uc;
	Q = [["nodes"], ["group"]];
	In = Pn({
		"css-root": ["frontMatter", "nodes"],
		"css-comment": [],
		"css-rule": ["selector", "nodes"],
		"css-decl": [
			"value",
			"selector",
			"nodes"
		],
		"css-atrule": [
			"selector",
			"params",
			"value",
			"nodes"
		],
		"media-query-list": Q[0],
		"media-query": Q[0],
		"media-type": [],
		"media-feature-expression": Q[0],
		"media-feature": [],
		"media-colon": [],
		"media-value": [],
		"media-keyword": [],
		"media-url": [],
		"media-unknown": [],
		"selector-root": Q[0],
		"selector-selector": Q[0],
		"selector-comment": [],
		"selector-string": [],
		"selector-tag": [],
		"selector-id": [],
		"selector-class": [],
		"selector-attribute": [],
		"selector-combinator": Q[0],
		"selector-universal": [],
		"selector-pseudo": Q[0],
		"selector-nesting": [],
		"selector-unknown": [],
		"value-value": Q[1],
		"value-root": Q[1],
		"value-comment": [],
		"value-comma_group": ["groups"],
		"value-paren_group": [
			"open",
			"groups",
			"close"
		],
		"value-func": Q[1],
		"value-paren": [],
		"value-number": [],
		"value-operator": [],
		"value-word": [],
		"value-colon": [],
		"value-comma": [],
		"value-string": [],
		"value-atword": [],
		"value-unicode-range": [],
		"value-unknown": []
	});
	ts = cc;
	Dt = qt(" 	");
	Ln = qt(",; 	");
	Mt = qt(/[^\n\r]/);
	N = (t) => t.source.startOffset;
	P = (t) => t.source.endOffset;
	Bt = Symbol.for("PRETTIER_IS_FRONT_MATTER");
	De = gc;
	Ut = wc;
	et = 3;
	xe = xc;
	_c = /* @__PURE__ */ new Set([
		"raw",
		"raws",
		"sourceIndex",
		"source",
		"before",
		"after",
		"trailingComma",
		"spaces"
	]);
	ns.ignoredProperties = _c;
	is = Object.hasOwn ?? Function.prototype.call.bind(Object.prototype.hasOwnProperty);
	Tc = /\*\/$/;
	kc = /^\/\*\*?/;
	zn = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/;
	Oc = /(^|\s+)\/\/([^\n\r]*)/g;
	Gn = /^(\r?\n)+/;
	Ac = /(?:^|\r?\n) *(@[^\n\r]*?) *\r?\n *(?![^\n\r@]*\/\/[^]*)([^\s@][^\n\r@]+?) *\r?\n/g;
	Yn = /(?:^|\r?\n) *@(\S+) *([^\n\r]*)/g;
	Cc = /(\r?\n|^) *\* ?/g;
	jn = [];
	Jn = ["noformat", "noprettier"];
	Zn = ["format", "prettier"];
	ei = "format";
	ti = Nc;
	ii = (t) => ri(xe(t).content);
	oi = (t) => si(xe(t).content);
	ai = (t) => {
		let { frontMatter: e, content: s } = xe(t);
		return (e ? e.raw + `

` : "") + ni(s);
	};
	Pc = /* @__PURE__ */ new Set([
		"red",
		"green",
		"blue",
		"alpha",
		"a",
		"rgb",
		"hue",
		"h",
		"saturation",
		"s",
		"lightness",
		"l",
		"whiteness",
		"w",
		"blackness",
		"b",
		"tint",
		"shade",
		"blend",
		"blenda",
		"contrast",
		"hsl",
		"hsla",
		"hwb",
		"hwba"
	]);
	Rc = /* @__PURE__ */ new Set([
		"initial",
		"inherit",
		"unset",
		"revert"
	]);
	Ni = Lc;
	Pi = qc;
	zt = /* @__PURE__ */ new Map([
		["em", "em"],
		["rem", "rem"],
		["ex", "ex"],
		["rex", "rex"],
		["cap", "cap"],
		["rcap", "rcap"],
		["ch", "ch"],
		["rch", "rch"],
		["ic", "ic"],
		["ric", "ric"],
		["lh", "lh"],
		["rlh", "rlh"],
		["vw", "vw"],
		["svw", "svw"],
		["lvw", "lvw"],
		["dvw", "dvw"],
		["vh", "vh"],
		["svh", "svh"],
		["lvh", "lvh"],
		["dvh", "dvh"],
		["vi", "vi"],
		["svi", "svi"],
		["lvi", "lvi"],
		["dvi", "dvi"],
		["vb", "vb"],
		["svb", "svb"],
		["lvb", "lvb"],
		["dvb", "dvb"],
		["vmin", "vmin"],
		["svmin", "svmin"],
		["lvmin", "lvmin"],
		["dvmin", "dvmin"],
		["vmax", "vmax"],
		["svmax", "svmax"],
		["lvmax", "lvmax"],
		["dvmax", "dvmax"],
		["cm", "cm"],
		["mm", "mm"],
		["q", "Q"],
		["in", "in"],
		["pt", "pt"],
		["pc", "pc"],
		["px", "px"],
		["deg", "deg"],
		["grad", "grad"],
		["rad", "rad"],
		["turn", "turn"],
		["s", "s"],
		["ms", "ms"],
		["hz", "Hz"],
		["khz", "kHz"],
		["dpi", "dpi"],
		["dpcm", "dpcm"],
		["dppx", "dppx"],
		["x", "x"],
		["cqw", "cqw"],
		["cqh", "cqh"],
		["cqi", "cqi"],
		["cqb", "cqb"],
		["cqmin", "cqmin"],
		["cqmax", "cqmax"],
		["fr", "fr"]
	]);
	Ri = /(["'])(?:(?!\1)[^\\]|\\.)*\1/gs;
	Uc = new RegExp(Ri.source + `|(${/[$@]?[_a-z\u0080-\uFFFF][\w\u0080-\uFFFF-]*/gi.source})?(${/(?:\d*\.\d+|\d+\.?)(?:e[+-]?\d+)?/gi.source})(${/[a-z]+/gi.source})?`, "gi");
	qi = (t) => t === `
` || t === "\r" || t === "\u2028" || t === "\u2029";
	jt = Fc;
	Ht = Wc;
	Di = $c;
	Mi = Gc;
	Qt = Yc;
	Ue = Qc;
	Ui = {
		features: { experimental_frontMatterSupport: {
			massageAstNode: !0,
			embed: !0,
			print: !0
		} },
		print: Kc,
		embed: Nn,
		insertPragma: ai,
		massageAstNode: ns,
		getVisitorKeys: In
	};
	Fi = [
		{
			name: "CSS",
			type: "markup",
			aceMode: "css",
			extensions: [".css", ".wxss"],
			tmScope: "source.css",
			codemirrorMode: "css",
			codemirrorMimeType: "text/css",
			parsers: ["css"],
			vscodeLanguageIds: ["css"],
			linguistLanguageId: 50
		},
		{
			name: "PostCSS",
			type: "markup",
			aceMode: "text",
			extensions: [".pcss", ".postcss"],
			tmScope: "source.postcss",
			group: "CSS",
			parsers: ["css"],
			vscodeLanguageIds: ["postcss"],
			linguistLanguageId: 262764437
		},
		{
			name: "Less",
			type: "markup",
			aceMode: "less",
			extensions: [".less"],
			tmScope: "source.css.less",
			aliases: ["less-css"],
			codemirrorMode: "css",
			codemirrorMimeType: "text/x-less",
			parsers: ["less"],
			vscodeLanguageIds: ["less"],
			linguistLanguageId: 198
		},
		{
			name: "SCSS",
			type: "markup",
			aceMode: "scss",
			extensions: [".scss"],
			tmScope: "source.css.scss",
			codemirrorMode: "css",
			codemirrorMimeType: "text/x-scss",
			parsers: ["scss"],
			vscodeLanguageIds: ["scss"],
			linguistLanguageId: 329
		}
	];
	$i = { singleQuote: {
		bracketSpacing: {
			category: "Common",
			type: "boolean",
			default: !0,
			description: "Print spaces between brackets.",
			oppositeDescription: "Do not print spaces between brackets."
		},
		objectWrap: {
			category: "Common",
			type: "choice",
			default: "preserve",
			description: "How to wrap object literals.",
			choices: [{
				value: "preserve",
				description: "Keep as multi-line, if there is a newline between the opening brace and first property."
			}, {
				value: "collapse",
				description: "Fit to a single line when possible."
			}]
		},
		singleQuote: {
			category: "Common",
			type: "boolean",
			default: !1,
			description: "Use single quotes instead of double quotes."
		},
		proseWrap: {
			category: "Common",
			type: "choice",
			default: "preserve",
			description: "How to wrap prose.",
			choices: [
				{
					value: "always",
					description: "Wrap prose if it exceeds the print width."
				},
				{
					value: "never",
					description: "Do not wrap prose."
				},
				{
					value: "preserve",
					description: "Wrap prose as-is."
				}
			]
		},
		bracketSameLine: {
			category: "Common",
			type: "boolean",
			default: !1,
			description: "Put > of opening tags on the last line instead of on a new line."
		},
		singleAttributePerLine: {
			category: "Common",
			type: "boolean",
			default: !1,
			description: "Enforce single attribute per line in HTML, Vue and JSX."
		}
	}.singleQuote };
	cn = {};
	hn(cn, {
		css: () => mg,
		less: () => dg,
		scss: () => yg
	});
	Nl = Ne(yt(), 1);
	Pl = Ne(Ko(), 1);
	Rl = Ne(Na(), 1);
	Pa = Fp;
	Ae = Wp;
	Ba = Ne(Ma(), 1);
	Zp = Ba.default.default;
	Ua = eh;
	Iu = Ne(Ru(), 1);
	re = my;
	kl = Ne(xl(), 1);
	rg = (t) => {
		for (; t.parent;) t = t.parent;
		return t;
	};
	jr = rg;
	_l = sg;
	bl = ng;
	El = ig;
	Sl = og;
	Tl = (t) => t.type === "paren" && t.value === ")";
	de = ug;
	lg = /* @__PURE__ */ new Set([
		"import",
		"use",
		"forward"
	]);
	Al = cg;
	Cl = fg;
	pg = /(\s*)(!default).*$/;
	hg = /(\s*)(!global).*$/;
	ln = {
		astFormat: "postcss",
		hasPragma: ii,
		hasIgnorePragma: oi,
		locStart: N,
		locEnd: P
	};
	mg = {
		...ln,
		parse: Ll
	};
	dg = {
		...ln,
		parse: ql
	};
	yg = {
		...ln,
		parse: Dl
	};
	gg = { postcss: Ui };
}));
//#endregion
init_postcss();
export { Ml as default, Fi as languages, postcss_exports as n, $i as options, cn as parsers, gg as printers, init_postcss as t };
